# -*- rpm-spec -*-

%define do_check 0

# This spec file assumes you are building on a Fedora or RHEL version
# that's still supported by the vendor. It may work on other distros
# or versions, but no effort will be made to ensure that going forward.
%define min_rhel 7
%define min_fedora 31

%if (0%{?fedora} && 0%{?fedora} >= %{min_fedora}) || (0%{?rhel} && 0%{?rhel} >= %{min_rhel})
    %define supported_platform 1
%else
    %define supported_platform 0
%endif

# Default to skipping autoreconf.  Distros can change just this one line
# (or provide a command-line override) if they backport any patches that
# touch configure.ac or Makefile.am.
# Always run autoreconf
%{!?enable_autotools:%global enable_autotools 1}

# The hypervisor drivers that run in libvirtd
%define with_qemu          0%{!?_without_qemu:1}
%define with_lxc           0%{!?_without_lxc:1}
%define with_libxl         0%{!?_without_libxl:1}
%define with_vbox          0%{!?_without_vbox:1}

%define with_qemu_tcg      %{with_qemu}

%define qemu_kvm_arches %{ix86} x86_64

%if 0%{?fedora}
    %define qemu_kvm_arches %{ix86} x86_64 %{power64} s390x %{arm} aarch64
%endif

%if 0%{?rhel}
    %define with_qemu_tcg 0
    %define qemu_kvm_arches x86_64 %{power64} aarch64 s390x
%endif

# On RHEL 7 and older macro _vpath_builddir is not defined.
%if 0%{?rhel} <= 7
    %define _vpath_builddir %{_target_platform}
%endif

%ifarch %{qemu_kvm_arches}
    %define with_qemu_kvm      %{with_qemu}
%else
    %define with_qemu_kvm      0
%endif

%if ! %{with_qemu_tcg} && ! %{with_qemu_kvm}
    %define with_qemu 0
%endif

# Then the hypervisor drivers that run outside libvirtd, in libvirt.so
%define with_openvz        0%{!?_without_openvz:1}
%define with_vmware        0%{!?_without_vmware:1}
%define with_esx           0%{!?_without_esx:1}
%define with_hyperv        0%{!?_without_hyperv:1}

# Then the secondary host drivers, which run inside libvirtd
%define with_storage_rbd      0%{!?_without_storage_rbd:1}
%if 0%{?fedora}
    %define with_storage_sheepdog 0%{!?_without_storage_sheepdog:1}
%else
    %define with_storage_sheepdog 0
%endif

%define with_storage_gluster 0%{!?_without_storage_gluster:1}
%ifnarch %{qemu_kvm_arches}
    # gluster is only built where qemu driver is enabled on RHEL 8
    %if 0%{?rhel} >= 8
        %define with_storage_gluster 0
    %endif
%endif

%define with_numactl          0%{!?_without_numactl:1}

# F25+ has zfs-fuse
%if 0%{?fedora}
    %define with_storage_zfs      0%{!?_without_storage_zfs:1}
%else
    %define with_storage_zfs      0
%endif

# We need a recent enough libiscsi (>= 1.18.0)
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_storage_iscsi_direct 0%{!?_without_storage_iscsi_direct:1}
%else
    %define with_storage_iscsi_direct 0
%endif

# A few optional bits off by default, we enable later
%define with_fuse          0%{!?_without_fuse:0}
%define with_sanlock       0%{!?_without_sanlock:0}
%define with_numad         0%{!?_without_numad:0}
%define with_firewalld     0%{!?_without_firewalld:0}
%define with_firewalld_zone 0%{!?_without_firewalld_zone:0}
%define with_libssh2       0%{!?_without_libssh2:0}
%define with_wireshark     0%{!?_without_wireshark:0}
%define with_libssh        0%{!?_without_libssh:0}
%define with_bash_completion  0%{!?_without_bash_completion:0}

# Finally set the OS / architecture specific special cases

# Xen is available only on i386 x86_64 ia64
%ifnarch %{ix86} x86_64 ia64
    %define with_libxl 0
%endif

# vbox is available only on i386 x86_64
%ifnarch %{ix86} x86_64
    %define with_vbox 0
%endif

# Numactl is not available on many non-x86 archs
%ifarch s390 s390x %{arm} riscv64
    %define with_numactl 0
%endif

# zfs-fuse is not available on some architectures
%ifarch s390 s390x aarch64 riscv64
    %define with_storage_zfs 0
%endif

# Ceph dropping support for 32-bit hosts
%if 0%{?fedora} >= 30
    %ifarch %{arm} %{ix86}
        %define with_storage_rbd 0
    %endif
%endif

# RHEL doesn't ship OpenVZ, VBox, PowerHypervisor,
# VMware, libxenlight (Xen 4.1 and newer),
# or HyperV.
%if 0%{?rhel}
    %define with_openvz 0
    %define with_vbox 0
    %define with_vmware 0
    %define with_libxl 0
    %define with_hyperv 0
    %define with_vz 0

    %if 0%{?rhel} > 7
        %define with_lxc 0
    %endif
%endif

# Virtuozzo configuration
%if 0%{?_aci_build:1}
    %define with_vz 0
    %define with_vzct 0
    %define with_docker 0
    %define with_vcmmd 0
    %define with_storage_vstorage 0
    %define with_secret 0
    %define with_storage_misc 0
    %define with_lxc 0
    %define with_storage_rbd 0
    %define with_storage_gluster 0
    %define with_storage_zfs 0
    %define with_storage_sheepdog 0
    %define with_storage_iscsi_direct  0
%else
    %define with_vz 1
    %define with_vzct 1
    %define with_docker 1
    %define with_vcmmd 1
    %define with_storage_vstorage 1
    %define with_secret 1
    %define with_storage_misc 1
    %define with_lxc 1
%endif

%define with_firewalld 1

%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_firewalld_zone 0%{!?_without_firewalld_zone:1}
%endif


# fuse is used to provide virtualized /proc for LXC
%if %{with_lxc}
    %define with_fuse      0%{!?_without_fuse:1}
%endif

# Enable sanlock library for lock management with QEMU
# Sanlock is available only on arches where kvm is available for RHEL
%if 0%{?fedora}
    %define with_sanlock 0%{!?_without_sanlock:1}
%endif
%if 0%{?rhel}
    %ifarch %{qemu_kvm_arches}
        %define with_sanlock 0%{!?_without_sanlock:1}
    %endif
%endif

%if 0%{?_aci_build:1}
    %define with_sanlock 0
%endif

# Enable libssh2 transport for new enough distros
%if 0%{?fedora}
    %define with_libssh2 0%{!?_without_libssh2:1}
%endif

# Enable wireshark plugins for all distros shipping libvirt 1.2.2 or newer
%if 0%{?fedora}
    %define with_wireshark 0%{!?_without_wireshark:1}
    %define wireshark_plugindir %(pkg-config --variable plugindir wireshark)/epan
%endif

# Enable libssh transport for new enough distros
%if 0%{?fedora} || 0%{?rhel} > 7
    %define with_libssh 0%{!?_without_libssh:1}
%endif

%define with_bash_completion  0%{!?_without_bash_completion:1}

%if %{with_qemu} || %{with_lxc}
# numad is used to manage the CPU and memory placement dynamically,
# it's not available on many non-x86 architectures.
    %ifnarch s390 s390x %{arm} riscv64
        %define with_numad    0%{!?_without_numad:1}
    %endif
%endif

# Force QEMU to run as non-root
%define qemu_user  qemu
%define qemu_group  qemu


# RHEL releases provide stable tool chains and so it is safe to turn
# compiler warning into errors without being worried about frequent
# changes in reported warnings
%if 0%{?rhel}
    %define enable_werror --enable-werror
%else
    %define enable_werror --disable-werror
%endif

%if 0%{?rhel} == 7
    %define tls_priority "NORMAL"
%else
    %define tls_priority "@LIBVIRT,SYSTEM"
%endif


Summary: Library providing a simple virtualization API
Name: libvirt
Version: 6.6.0
Release: 13.2%{?dist}.16
License: LGPLv2+
URL: https://libvirt.org/
ExclusiveArch: x86_64

%if %(echo %{version} | grep -q "\.0$"; echo $?) == 1
    %define mainturl stable_updates/
%endif
Source: libvirt-%{version}-13.2.tar.xz
Source1: symlinks

# Vz patches
Patch10000: 10000-src-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10001: 10001-libxl-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10002: 10002-qemu-adopt-to-VIR_DRV_SUPPORTS_FEATURE-return-1.patch
Patch10003: 10003-src-don-t-hide-error-in-VIR_DRV_SUPPORTS_FEATURE.patch
Patch10004: 10004-qemu-build-fix-for-910b94df.patch
Patch10005: 10005-src-fix-resource-leak-introduced-in-d4439a6b8.patch
Patch10006: 10006-vz-fixes-after-renaming-Parallels-to-Virtuozzo-in-s.patch
Patch10007: 10007-backport-fixup-remote-implement-virDomainGetGuestIn.patch
Patch10008: 10008-make-check-fix-when-lxc-is-turned-off.patch
Patch10009: 10009-iohelper-truncate-large-chunks-on-write-PSBM-70840.patch
Patch10010: 10010-Added-new-flag-VIR_DOMAIN_CREATE_USER.patch
Patch10011: 10011-conf-tune-connection-parameters-for-Virtuozzo-PSBM-.patch
Patch10012: 10012-Set-LimitCORE-infinity-in-libvirtd.service.patch
Patch10013: 10013-conf-add-format-attribute-to-domain-os-nvram-elemen.patch
Patch10014: 10014-qemu-don-t-pause-vm-when-creating-internal-snapshot.patch
Patch10015: 10015-vz-use-etc-machine-id-as-host-uuid.patch
Patch10016: 10016-qemu-log-log-monitor-events-by-default.patch
Patch10017: 10017-relax-network-adapter-config-checking-bug-PSBM-5459.patch
Patch10018: 10018-qemu-v2-fix-reboot-scenario-bugs-PSBM-41956-PSBM-54.patch
Patch10019: 10019-vz-set-virtio-as-default-network-model.patch
Patch10020: 10020-qemu-fix-crash-on-getting-block-stats-for-empty-cdr.patch
Patch10021: 10021-vz-rework-the-way-we-get-perfomance-counters.patch
Patch10022: 10022-vz-use-cached-statistics-for-a-predefined-period.patch
Patch10023: 10023-vz-don-t-subscribe-to-perfomance-counters.patch
Patch10024: 10024-vz-cleanup-delete-unused-constant-definition.patch
Patch10025: 10025-vz-don-t-create-driver-object-during-daemon-initial.patch
Patch10026: 10026-conf-qemu-add-hv-scsi-model-to-scsi-controllers.patch
Patch10027: 10027-vz-add-domain-name-info-in-error-message.patch
Patch10028: 10028-qemu-simplify-graphics-port-releasing.patch
Patch10029: 10029-upgrade-support-local-p2p-migration.patch
Patch10030: 10030-object-add-shared-lock-option-to-lockable.patch
Patch10031: 10031-upgrade-initial-implementation.patch
Patch10032: 10032-upgrade-don-t-show-events-from-not-face-process.patch
Patch10033: 10033-upgrade-start-target-domain-with-source-id.patch
Patch10034: 10034-cgroup-use-id-generation-for-machine-cgroup-name-if.patch
Patch10035: 10035-upgrade-fix-id-clashes-for-domain-private-paths-etc.patch
Patch10036: 10036-conf-accept-path-in-virDomainSaveXML.patch
Patch10037: 10037-upgrade-store-generation-in-status-file.patch
Patch10038: 10038-dom-list-refactor-reuse-code-in-find-functions.patch
Patch10039: 10039-upgrade-return-face-domain-from-domlist.patch
Patch10040: 10040-migration-support-release-ram.patch
Patch10041: 10041-migration-add-postcopy-start-to-start-postcopy-imme.patch
Patch10042: 10042-upgrade-virtlogd-handle-output-for-one-path-from-2-.patch
Patch10043: 10043-upgrade-pass-live-config-to-target.patch
Patch10044: 10044-upgrade-don-t-generate-seclabel-again-on-upgrade.patch
Patch10045: 10045-upgrade-handle-auto-generated-char-dev-unix-paths.patch
Patch10046: 10046-upgrade-vnc-do-not-regenerate-graphics-for-target-p.patch
Patch10047: 10047-upgrade-vnc-factor-out-building-vnc-opts.patch
Patch10048: 10048-upgrade-vnc-make-vnc-upgrade-possible.patch
Patch10049: 10049-upgrade-vnc-keep-vnc-state-across-upgrade.patch
Patch10050: 10050-upgrade-tap-use-multiqueue-to-make-upgrade-possible.patch
Patch10051: 10051-upgrade-tap-don-t-regenerate-name-on-upgrade.patch
Patch10052: 10052-upgrade-network-iface-keep-actual-net.patch
Patch10053: 10053-upgrade-snapshots-support-snapshots.patch
Patch10054: 10054-upgrade-don-t-assign-dev-aliases-on-upgrade.patch
Patch10055: 10055-qemu-drop-acquiring-job-condition-on-removing-vm-fr.patch
Patch10056: 10056-qemu-fix-one-more-race-on-undefining-and-create.patch
Patch10057: 10057-upgrade-restart-pending-jobs-after-upgrade.patch
Patch10058: 10058-upgrade-fix-domain-lookup-in-old-face-removing-phas.patch
Patch10059: 10059-upgrade-make-correct-reconnection-of-upgrade.patch
Patch10060: 10060-upgrade-set-used-ports-only-for-face.patch
Patch10061: 10061-upgrade-support-for-server-backends-for-serial-char.patch
Patch10062: 10062-qemu.conf-set-upper-limit-for-vnc-spice-ports-to-69.patch
Patch10063: 10063-upgrade-don-t-reject-upgrade-if-hostname-is-localho.patch
Patch10064: 10064-qemu-wait-indefinetly-when-acquiring-job-condition-.patch
Patch10065: 10065-upgrade-close-agent-channel-befor-postcopy-with-rel.patch
Patch10066: 10066-upgrade-use-unique-name-for-pidfiles-across-upgrade.patch
Patch10067: 10067-qemu-remove-time-limit-on-waiting-qemu-disappearenc.patch
Patch10068: 10068-qemu-add-vmbus-bridge-device-if-hv-scsi-present.patch
Patch10069: 10069-qemu-agent-stop-io-loop-effectively-on-eof-or-error.patch
Patch10070: 10070-upgrade-fix-crash-if-vm-newdef-is-empty.patch
Patch10071: 10071-libvirtd-tune-OOMScoreAdjust.patch
Patch10072: 10072-qemu-revert-fb2cd32c.patch
Patch10073: 10073-daemon-finish-threads-on-close.patch
Patch10074: 10074-qemu-monitor-check-monitor-not-closed-on-send.patch
Patch10075: 10075-qemu-implement-state-driver-shutdown-function.patch
Patch10076: 10076-vz-remove-domain-uuid-check-on-migration-PSBM-43767.patch
Patch10077: 10077-qemu-support-hv-net-interface-models.patch
Patch10078: 10078-nwfilter-fix-deadlock-on-firewalld-restart-reload.patch
Patch10079: 10079-vz-allow-to-start-vz-driver-without-host-cache-info.patch
Patch10080: 10080-qemu-snapshot-revert-upstream-9e2465834-PSBM-76749.patch
Patch10081: 10081-api-qemu-add-block-pull-compress-option-PSBM-73618.patch
Patch10082: 10082-qemu-include-nvram-into-offline-snapshots.patch
Patch10083: 10083-qemu-fail-making-internal-snapshots-with-non-qcow2-.patch
Patch10084: 10084-util-virFDStreamConnectUNIX-add-missing-error-repor.patch
Patch10085: 10085-util-add-30s-connection-timeout-to-virFDStreamConne.patch
Patch10086: 10086-qemu-use-job-to-make-domain-responsive-on-qemuDomai.patch
Patch10087: 10087-qemu-wait-qemu-death-indefinetely-on-domain-stop-PS.patch
Patch10088: 10088-pull-api-add-API-for-pull-external-backups.patch
Patch10089: 10089-pull-api-add-driver-based-implementation.patch
Patch10090: 10090-pull-remote-add-pull-backup-API-implementation.patch
Patch10091: 10091-pull-qemu-monitor-add-commands-for-backup.patch
Patch10092: 10092-pull-conf-add-block-snapshot-format-parse.patch
Patch10093: 10093-pull-virsh-add-block-snapshot-create-delete.patch
Patch10094: 10094-qemu-store-guest-visible-disk-size-from-qemu-monito.patch
Patch10095: 10095-qemu-add-option-to-handle-inactive-blockjobs-to-can.patch
Patch10096: 10096-util-hash-add-misc-functions.patch
Patch10097: 10097-pull-conf-add-block-snaphots-to-status-file.patch
Patch10098: 10098-pull-qemu-block-snapshots-basic-implementation.patch
Patch10099: 10099-pull-qemu-support-disks-quiesce.patch
Patch10100: 10100-pull-qemu-add-block-snapshots-listing.patch
Patch10101: 10101-pull-qemu-support-block-snapshot-dumpxml.patch
Patch10102: 10102-pull-qemu-monitor-add-cmd-to-delete-nbd-export.patch
Patch10103: 10103-pull-conf-add-export-conf-def-parsing.patch
Patch10104: 10104-pull-qemu-implement-export-start-stop.patch
Patch10105: 10105-pull-qemu-don-t-delete-snapshot-while-disks-are-exp.patch
Patch10106: 10106-util-hash-remove-const-from-value-in-kv-pair-type.patch
Patch10107: 10107-pull-add-autodelete-option-for-creating-block-snaps.patch
Patch10108: 10108-pull-stop-exporting-snapshot-on-snapshot-autodelete.patch
Patch10109: 10109-pull-add-backcompat-capabilities.patch
Patch10110: 10110-pull-qemu-monitor-add-bitmap-commands.patch
Patch10111: 10111-pull-pull-add-dirty-bitmap-on-creating-snapshot.patch
Patch10112: 10112-pull-add-command-to-remove-checkpoint.patch
Patch10113: 10113-pull-qemu-remove-checkpoint-on-autodelete.patch
Patch10114: 10114-pull-qemu-load-bitmaps-on-domain-start.patch
Patch10115: 10115-pull-qemu-monitor-add-command-to-export-bitmap.patch
Patch10116: 10116-pull-export-bitmap.patch
Patch10117: 10117-pull-migrate-checkpoints.patch
Patch10118: 10118-pull-qemu-validate-snapshot-name.patch
Patch10119: 10119-pull-qemu-add-exportable-paused-start.patch
Patch10120: 10120-pull-add-TLS-to-block-export.patch
Patch10121: 10121-pull-add-relaxng.patch
Patch10122: 10122-pull-add-autoport-on-export.patch
Patch10123: 10123-qemu-add-unmap-stats-to-all-domain-stats.patch
Patch10124: 10124-api-qemu-add-latency-histogram.patch
Patch10125: 10125-hubapi-remote-implement-listing-domains.patch
Patch10126: 10126-hubapi-remote-support-domain-API-calls.patch
Patch10127: 10127-hubapi-remote-support-domain-lookup-functions.patch
Patch10128: 10128-hubapi-remote-support-create-define-xml-API.patch
Patch10129: 10129-hubapi-remote-support-domain-events.patch
Patch10130: 10130-hubapi-remote-support-virConnectGetCapabilities.patch
Patch10131: 10131-hubapi-remote-return-vz-connection-type-if-vz-is-in.patch
Patch10132: 10132-hubapi-remote-return-vz-connection-type-if-vzct-is-.patch
Patch10133: 10133-hubapi-find-appropriate-connection-for-domain-xml-V.patch
Patch10134: 10134-vz-add-option-to-resize-filesystems-thur-virDomainB.patch
Patch10135: 10135-vz-support-virDomainGetBlockInfo-in-driver.patch
Patch10136: 10136-api-qemu-introduce-hv-vss-freeze-thaw.patch
Patch10137: 10137-pull-disable-risky-cases-with-RW-NBD-exports.patch
Patch10138: 10138-qemu-fix-attach-detach-char-devices-to-use-guest-de.patch
Patch10139: 10139-conf-remove-none-console-target-type-check-from-vir.patch
Patch10140: 10140-conf-remove-none-console-target-type-check-from-vir.patch
Patch10141: 10141-conf-remove-none-console-target-type-check-from-vir.patch
Patch10142: 10142-qemu-update-compat-console-on-attach-first-serial-d.patch
Patch10143: 10143-qemu-support-updating-backend-of-serial-device.patch
Patch10144: 10144-pull-qemu-add-option-to-export-last-checkpoint.patch
Patch10145: 10145-portallocator-print-warn-on-releasing-not-used-port.patch
Patch10146: 10146-netlink-remove-watch-before-closing-fd.patch
Patch10147: 10147-qemu-monitor-set-error-flag-even-in-OOM-conditions.patch
Patch10148: 10148-utils-export-virCopyError.patch
Patch10149: 10149-qemu-fix-domain-object-wait-to-handle-monitor-error.patch
Patch10150: 10150-qemu-fix-races-in-beingDestroyed-usage.patch
Patch10151: 10151-lib-provide-error-message-in-new-blockjob-event.patch
Patch10152: 10152-qemu-agent-incapsulate-vm-reference-management.patch
Patch10153: 10153-qemu-agent-remove-unconvinient-destroy-callback.patch
Patch10154: 10154-qemu-agent-factor-out-code-to-open-channel.patch
Patch10155: 10155-qemu-agent-remove-useless-signalling.patch
Patch10156: 10156-qemu-agent-do-not-take-moninor-ref-in-IO-callback.patch
Patch10157: 10157-qemu-agent-remove-qemuAgentNotifyCloseLocked.patch
Patch10158: 10158-qemu-agent-don-t-retry-first-sync-message-if-monito.patch
Patch10159: 10159-qemu-agent-better-error-message-for-disconnected-ag.patch
Patch10160: 10160-qemu-agent-give-same-message-on-monitor-errors.patch
Patch10161: 10161-qemu-agent-move-monitor-error-check-to-better-place.patch
Patch10162: 10162-qemu-domain-add-name-arg-to-qemuFindAgentConfig.patch
Patch10163: 10163-qemu-agent-prepare-serial-event-handler-for-aux-cha.patch
Patch10164: 10164-rpc-support-multiple-streams-on-client-side.patch
Patch10165: 10165-rpc-fix-to-support-multiple-streams.patch
Patch10166: 10166-rpc-close-stream-on-receive-errors.patch
Patch10167: 10167-rpc-pass-original-stream-recv-send-error.patch
Patch10168: 10168-qemu-add-exec-with-true-streams.patch
Patch10169: 10169-tools-stop-event-loop-before-closing-connection.patch
Patch10170: 10170-virsh-don-t-print-n-footer-for-x-exec.patch
Patch10171: 10171-pull-fix-visible-NULL-entries-in-block-snapshot-has.patch
Patch10172: 10172-misc-remove-some-invalid-G_GNUC_WARN_UNUSED_RESULT.patch
Patch10173: 10173-nwfilter-use-vfork-to-fasten-spawn-of-ip-eb-tables-.patch
Patch10174: 10174-pci-more-verbose-error-in-virPCIGetDeviceAddressFro.patch
Patch10175: 10175-daemon-purge-logs-for-domains-removed-more-than-mon.patch
Patch10176: 10176-remote-fix-SIGSEGV-on-closing-client-connection.patch
Patch10177: 10177-pull-don-t-destroy-vm-if-it-has-block-snapshots-or-.patch
Patch10178: 10178-qemu-destroy-domain-on-monitor-EOF-anyway.patch
Patch10179: 10179-pull-log-merge-rename-bitmap-operations.patch
Patch10180: 10180-api-qemu-add-move-nvram-API.patch
Patch10181: 10181-qemu-add-option-to-update-disk-copy_on_read-live-VS.patch
Patch10182: 10182-qemu-add-qcow2-cache-size-policy.patch
Patch10183: 10183-tools-move-virshGetEscapeChar-to-utils.patch
Patch10184: 10184-syms-add-virStringListCopy-to-private-syms.patch
Patch10185: 10185-virsh-support-in-err-out-as-regular-files.patch
Patch10186: 10186-qemu-support-interactive-exec-PSBM-91739.patch
Patch10187: 10187-qemu-remove-sanity-check-in-qemuMonitorJSONDiskName.patch
Patch10188: 10188-exec-provide-tty-params-on-exec-when-possible.patch
Patch10189: 10189-rpc-allow-comments-in-prototol-description.patch
Patch10190: 10190-remote-leave-stub-comment-for-16-virDomainGetOSInfo.patch
Patch10191: 10191-libvirt-add-new-virDomainCommandXSetParams-API.patch
Patch10192: 10192-exec-handle-client-window-size-change-when-interact.patch
Patch10193: 10193-qemu-add-hci-value-128MiB-to-qcow2-disk-cache-polic.patch
Patch10194: 10194-upgrade-handle-firewall-rules-PSBM-90137.patch
Patch10195: 10195-qemu-caps-invalidate-kvm-capable-qemu-binaries-on-e.patch
Patch10196: 10196-cgroup-blacklist-criu-temporary-mounts-PSBM-90471.patch
Patch10197: 10197-qemu-imply-qcow2-format-for-backing-store-if-not-se.patch
Patch10198: 10198-rpc-client-fix-race-on-stream-error-and-stream-crea.patch
Patch10199: 10199-exec-virsh-support-redirection-to-special-chardevs-.patch
Patch10200: 10200-exec-restore-std-streams-flags-on-become-foreground.patch
Patch10201: 10201-rpc-client-stream-notify-streams-of-closing-connect.patch
Patch10202: 10202-Revert-log-actually-do-substring-matches-with-fnmat.patch
Patch10203: 10203-pull-clean-autodelete-snapshots-on-daemon-restart.patch
Patch10204: 10204-qemu-agent-add-code-2-when-guest-exec-pid-not-found.patch
Patch10205: 10205-qemu-don-t-wait-job-in-cleanup-thread.patch
Patch10206: 10206-exec-kill-orphans-on-client-disconnect-PSBM-91329-V.patch
Patch10207: 10207-exec-kill-orphans-on-migration-destination-PSBM-913.patch
Patch10208: 10208-qemu-seccomp-don-t-turn-it-on-by-default-PSBM-93004.patch
Patch10209: 10209-qemu-ignore-disabled-arch-facilities-in-configs-PSB.patch
Patch10210: 10210-qemu-support-explicit-disk-backing-in-input-VSTOR-2.patch
Patch10211: 10211-logging-remove-watch-before-closing-fd-in-virLogHan.patch
Patch10212: 10212-qemu-don-t-log-error-for-disk-sources-not-supportin.patch
Patch10213: 10213-qemu-don-t-log-error-when-monitor-EOF-is-expected-P.patch
Patch10214: 10214-qemu-agent-don-t-log-error-when-monitor-EOF-is-expe.patch
Patch10215: 10215-qemu-agent-aux-don-t-log-error-when-monitor-EOF-is-.patch
Patch10216: 10216-qemu-qemuBlockDiskDetectNodes-get-name-if-one-is-kn.patch
Patch10217: 10217-backup-copy-bitmaps-to-top-image-on-snapshot.patch
Patch10218: 10218-virDomainObjListAddObjLocked-Don-t-expect-vm-def-to.patch
Patch10219: 10219-virDomainObjListAddLocked-Set-vm-def-only-in-succes.patch
Patch10220: 10220-virDomainObjListAdd-Leave-def-assigning-as-an-exerc.patch
Patch10221: 10221-virDomainObjListAdd-Remove-unused-flag.patch
Patch10222: 10222-qemu-Grab-modify-job-for-changing-domain-XML.patch
Patch10223: 10223-qemu_domain-Allow-qemuDomainObjListAdd-to-keep-job-.patch
Patch10224: 10224-qemu-release-job-on-cleanup-path.patch
Patch10225: 10225-qemu-snapshot-revert-reuse-common-cleanup-code.patch
Patch10226: 10226-qemu-support-snapshots-done-with-Vz-downstream-patc.patch
Patch10227: 10227-schema-snapshot-add-persistent-domain-config.patch
Patch10228: 10228-docs-add-persistent-config-to-snapshot-xml-descript.patch
Patch10229: 10229-conf-snapshot-check-domain-name-on-redefine.patch
Patch10230: 10230-conf-snapshot-support-persistent-config-on-redefine.patch
Patch10231: 10231-qemu-add-option-to-close-cdrom-tray-PSBM-95870.patch
Patch10232: 10232-conf-remove-features-unknown-to-qemu-related-to-PSB.patch
Patch10233: 10233-agent-increase-default-timeout-from-5s-to-30s-PSBM-.patch
Patch10234: 10234-qemu-introduce-qemuDomainChrSerialTargetModel.patch
Patch10235: 10235-conf-add-debugcon-chardev-guest-interface.patch
Patch10236: 10236-qemu-make-irq-optional-when-formatting-the-ISA-addr.patch
Patch10237: 10237-qemu-implement-debugcon-chardev.patch
Patch10238: 10238-qemu-autoadd-iobase-to-debugcon-chardev.patch
Patch10239: 10239-api-qemu-add-pause-resume-for-blockjobs.patch
Patch10240: 10240-qemu-agent-log-total-tx-rx-for-streams.patch
Patch10241: 10241-debug-print-thr-a-a-bt-in-log-when-taking-some-mute.patch
Patch10242: 10242-qemu-monitor-throttle-logging-BLOCK_IO_ERROR-events.patch
Patch10243: 10243-qemu-ignore-delayed-EOF-events-from-previous-VM-inc.patch
Patch10244: 10244-qemu-don-t-fail-pausing-block-job-if-it-is-missing-.patch
Patch10245: 10245-qemu-migration-implement-shared-workaround-VSTOR-11.patch
Patch10246: 10246-conf-handle-empty-string-in-interface-target-name-P.patch
Patch10247: 10247-conf-add-replug-option-for-usb-hostdev.patch
Patch10248: 10248-qemu-track-hostdev-delete-intention.patch
Patch10249: 10249-qemu-support-host-usb-device-unplug.patch
Patch10250: 10250-qemu-support-usb-hostdev-plugging-back.patch
Patch10251: 10251-qemu-handle-host-usb-device-add-del-udev-events.patch
Patch10252: 10252-qemu-handle-libvirtd-restart-after-host-usb-device-.patch
Patch10253: 10253-qemu-handle-race-on-device-deletion-and-usb-host-de.patch
Patch10254: 10254-qemu-hotplug-update-device-list-on-device-deleted-e.patch
Patch10255: 10255-qemu-handle-host-usb-device-plug-unplug-when-libvir.patch
Patch10256: 10256-qemu-don-t-mess-with-non-mandatory-hostdevs-on-reat.patch
Patch10257: 10257-qemu-handle-detaching-of-unplugged-hostdev.patch
Patch10258: 10258-conf-parse-hostdev-missing-flag.patch
Patch10259: 10259-backup-don-t-keep-bitmaps-in-base-image-on-snapshot.patch
Patch10260: 10260-backup-copy-bitmaps-down-on-active-block-commit-VST.patch
Patch10261: 10261-qemu-support-new-qemu-without-nbd-server-add-bitmap.patch
Patch10262: 10262-fix-for-virDomainObjListAdd-Leave-def-assigning-as-.patch
Patch10263: 10263-qemu-handle-storage-virtlogd-hanging-VSTOR-27947.patch
Patch10264: 10264-qemu-add-option-to-process-offloaded-legacy-blockjo.patch
Patch10265: 10265-qemu-reconnect-precreate-legacy-blockjobs.patch
Patch10266: 10266-qemu-remove-extra-block-job-finalize-on-reconnect.patch
Patch10267: 10267-qemu-remove-stale-cleanup-in-qemuProcessRefreshLega.patch
Patch10268: 10268-qemu-add-note-for-outdated-legacy-block-job-events.patch
Patch10269: 10269-qemu-use-autoptr-in-qemuProcessRefreshLegacyBlockjo.patch
Patch10270: 10270-qemu-refresh-backing-chain-after-block-job-reconnec.patch
Patch10271: 10271-qemu-move-code-that-depends-on-backing-chain-approp.patch
Patch10272: 10272-qemu-fix-race-on-legacy-block-completion-and-querin.patch
Patch10273: 10273-qemu-sync-backing-chain-update-and-completed-blockj.patch
Patch10274: 10274-qemu-support-preserve-option-for-on_poweroff.patch
Patch10275: 10275-qemu-add-reconnect-params-for-nbd-network-disks-VST.patch
Patch10276: 10276-netdaemon-fix-deadlock-on-stopping-libvirtd-when-VM.patch
Patch10277: 10277-qemu-kill-partially-started-domain-immediately-on-r.patch
Patch10278: 10278-qemu-migration-log-keep-alive-message-during-migrat.patch
Patch10279: 10279-qemu-disable-snapshot-explicitly-when-block-snapsho.patch
Patch10280: 10280-make-add-flags-to-configure-sanitizer.patch
Patch10281: 10281-asan-workaround-sanitizer-issues-with-clone-2.patch
Patch10282: 10282-asan-configure-to-coredump-on-signals.patch
Patch10283: 10283-hubapi-workaround-virURIFormat-degradation-in-vz8.patch
Patch10284: 10284-qemu-adopt-nodename-detection-to-backup-filter-node.patch
Patch10285: 10285-qemu-adopt-latency-impl-to-new-qemu-PSBM-97535.patch
Patch10286: 10286-qemu-turn-on-keep-alive-for-nbd-disk-migration-PSBM.patch
Patch10287: 10287-docker-First-implementation-of-libvirt-Docker-drive.patch
Patch10288: 10288-conf-add-more-options-to-save-config-filename.patch
Patch10289: 10289-conf-allow-NULL-callback-in-virDomainObjListRename.patch
Patch10290: 10290-conf-support-extra-id-in-domain-list.patch
Patch10291: 10291-vzct-2-add-basic-structure-and-listing.patch
Patch10292: 10292-virsystemd-workaround-race-on-systemd-machined-idle.patch
Patch10293: 10293-rpc-add-timeout-on-connection-VSTOR-32643.patch
Patch10294: 10294-docker-add-lookup-API-impl-PSBM-102978.patch
Patch10295: 10295-docker-implementation-control-methods-for-domain-PS.patch
Patch10296: 10296-docker-extend-types-of-HTTP-request-PSBM-103311.patch
Patch10297: 10297-docker-correct-POST-HTTP-request-PSBM-103381.patch
Patch10298: 10298-docker-add-special-label-with-libvirt-uuid-in-conta.patch
Patch10299: 10299-conf-support-light-vcpus-and-unlimitied-number.patch
Patch10300: 10300-vzct-2-support-dumpxml.patch
Patch10301: 10301-docker-add-template-source-type-PSBM-103381.patch
Patch10302: 10302-vzct-2-implement-define.patch
Patch10303: 10303-vzct-2-implement-start-stop.patch
Patch10304: 10304-docker-implementation-of-XML-methods-for-libvirt-dr.patch
Patch10305: 10305-docker-cleanup-code-for-hypervisor-driver-PSBM-1040.patch
Patch10306: 10306-hasfix-docker-look-up-by-hash-id-with-leading-zero-.patch
Patch10307: 10307-docker-implementation-of-stats-methods-PSBM-104003.patch
Patch10308: 10308-hasfix-docker-look-up-by-name-PSBM-104003.patch
Patch10309: 10309-docker-cleanup-code-PSBM-104003.patch
Patch10310: 10310-vzct-2-support-vnc-PSBM-104068.patch
Patch10311: 10311-vzct-2-support-cloud-init-cdrom-PSBM-104067.patch
Patch10312: 10312-vzct-2-add-vzctDomainHasManagedSaveImage-stub.patch
Patch10313: 10313-vzct-2-support-iolimits-PSBM-104069.patch
Patch10314: 10314-vzct-2-add-misc-API.patch
Patch10315: 10315-docker-implementation-of-connectGetAllDomainStats-m.patch
Patch10316: 10316-docker-cleanup-code-PSBM-104537.patch
Patch10317: 10317-docker-changing-of-type-of-some-objects-in-XML-mode.patch
Patch10318: 10318-vzct-2-make-disk-names-stable-PSBM-104105.patch
Patch10319: 10319-hasfix-docker-simplification-of-existing-code-PSBM-.patch
Patch10320: 10320-vzct-2-support-stats-API-PSBM-104070.patch
Patch10321: 10321-docker-implementation-of-network-driver-PSBM-104537.patch
Patch10322: 10322-qemu-bring-back-capabilities-from-update-14-PSBM-10.patch
Patch10323: 10323-docker-Added-support-for-mounting-volumes-or-FSs-PS.patch
Patch10324: 10324-qemu-use-explicit-backing-mode-only-if-there-is-nbd.patch
Patch10325: 10325-qemu-optimize-qemuOpenFileAs-for-reads-VSTOR-34701.patch
Patch10326: 10326-Add-qemu-hook-suitable-to-handle-device-hotplug-hot.patch
Patch10327: 10327-util-add-virFileRead-function.patch
Patch10328: 10328-conf-moment-remember-if-name-is-autogenerated.patch
Patch10329: 10329-vzct-2-support-snapshots.patch
Patch10330: 10330-docker-Offline-migration-of-windows-container-PSBM-.patch
Patch10331: 10331-hasfix-Changes-for-using-define-instead-of-several-.patch
Patch10332: 10332-docker-Added-rename-method-for-driver.patch
Patch10333: 10333-xml-add-venet0-network-interface-type.patch
Patch10334: 10334-vzct-2-support-venet0-network-interface-PSBM-105548.patch
Patch10335: 10335-qemu-ignore-allow_disk_format_probing-PSBM-105558.patch
Patch10336: 10336-upgrade-don-t-mess-with-security-labels-PSBM-105674.patch
Patch10337: 10337-qemu-pass-rememberOwner-during-update-PSBM-105674.patch
Patch10338: 10338-docker-Add-some-configuration-features-for-driver-P.patch
Patch10339: 10339-qemu-auto-load-vhost-vsock-module-PSBM-106171.patch
Patch10340: 10340-qemu-make-latency-work-with-legacy-interface-PSBM-1.patch
Patch10341: 10341-virsh-handle-snapshots-with-domain-state-unknown.patch
Patch10342: 10342-util-add-means-to-detect-vstorage-filesystem.patch
Patch10343: 10343-security-exclude-vstorage-from-labelling-PSBM-10598.patch
Patch10344: 10344-vzct-2-don-t-try-virDomainLookupByID.patch
Patch10345: 10345-qemu-caps-use-more-precise-condition-when-to-use-CA.patch
Patch10346: 10346-doc-adopt-README.md-for-Virtuozzo.patch
Patch10347: 10347-docker-first-implementation-of-winrs-transport-to-w.patch
Patch10348: 10348-docker-basic-implementation-of-storage-driver-for-W.patch
Patch10349: 10349-Add-new-type-of-storage-pool-for-Windows-Storage-Sp.patch
Patch10350: 10350-docker-full-implementation-of-storage-driver-for-Wi.patch
Patch10351: 10351-docker-add-method-for-cloning-volume-PSBM-106275.patch
Patch10352: 10352-docker-using-common-CA-certificate-for-docker-and-w.patch
Patch10353: 10353-docker-reuse-winrm-coonnection-PSBM-106278.patch
Patch10354: 10354-docker-forbid-access-to-primordial-storage-pools-PS.patch
Patch10355: 10355-virsh-don-t-shout-if-virDomainGetJobInfo-is-not-sup.patch
Patch10356: 10356-vzct-2-save-disks-uuid-in-config-status-files.patch
Patch10357: 10357-vzct-2-intoduce-migration.patch
Patch10358: 10358-conf-add-auto-mininal-memory-guarantee-mode.patch
Patch10359: 10359-vzct-2-support-memory-guarantees-PSBM-106482.patch
Patch10360: 10360-docker-unification-of-source-code-PSBM-106989.patch
Patch10361: 10361-docker-common-auth-certificate-for-docker-and-winrm.patch
Patch10362: 10362-hasfix-docker-use-more-correct-powershell-expressio.patch
Patch10363: 10363-vzct-2-mark-supported-xml-parts-in-domain-snapshot-.patch
Patch10364: 10364-hasfix-docker-use-correct-timeouts-and-subnet-value.patch
Patch10365: 10365-docker-add-support-for-static-IP-address-PSBM-10677.patch
Patch10366: 10366-qemu-add-vcmmd-support-PSBM-106483.patch
Patch10367: 10367-hasfix-using-vars-for-compacting-code-PSBM-106778.patch
Patch10368: 10368-qemu-agent-disable-blocking-calls-to-agent-PSBM-107.patch
Patch10369: 10369-vzct-2-add-jobs-support-for-everything-except-migra.patch
Patch10370: 10370-vzct-2-support-jobs-during-migration-PSBM-107444.patch
Patch10371: 10371-vzct-2-drop-job-on-client-disconnection-during-migr.patch
Patch10372: 10372-Changes-for-support-DNS-configuration-PSBM-106778.patch
Patch10373: 10373-docker-support-DNS-configuration-PSBM-106778.patch
Patch10374: 10374-hasfix-Changes-for-support-DNS-configuration-PSBM-1.patch
Patch10375: 10375-docker-rename-CA-certificate-file-to-ca.pem.patch
Patch10376: 10376-qemu-fix-concurrency-crash-bug-in-force-snapshot-re.patch
Patch10377: 10377-vzct-2-add-lifecycle-events-PSBM-107730.patch
Patch10378: 10378-vzct-2-support-getting-stats-for-migration-PSBM-107.patch
Patch10379: 10379-vzct-2-support-aborting-domain-job-API-PSBM-107446.patch
Patch10380: 10380-Fixes-for-support-creation-of-docker-container-PSBM.patch
Patch10381: 10381-logging-read-all-bytes-on-EOF-in-event-handler.patch
Patch10382: 10382-logging-fix-endless-loop-on-EOF.patch
Patch10383: 10383-docker-Support-CPU-limits-PSBM-107960.patch
Patch10384: 10384-docker-support-wss-storage-pool-for-connection-capa.patch
Patch10385: 10385-docker-support-wss-volume-resizing-PSBM-108203.patch
Patch10386: 10386-vstorage-migration-execute-src-migration-cleanup-in.patch
Patch10387: 10387-qemu-fix-qemuMigrationSrcCleanup-to-use-qemuMigrati.patch
Patch10388: 10388-qemu-monitor-bring-add-remove-fd-commands-back.patch
Patch10389: 10389-qemu-monitor-add-qemuMonitorQueryFdsets-function.patch
Patch10390: 10390-qemu-don-t-leave-descriptors-in-fdsets-after-proces.patch
Patch10391: 10391-qemu-support-file-chardev-append-option-on-hotplug-.patch
Patch10392: 10392-qemu-support-logfile-option-on-chardev-hotplug-chan.patch
Patch10393: 10393-qemu-migration-add-cookie-parts-for-vstorage-charde.patch
Patch10394: 10394-logging-close-backing-file-on-eof-on-drain.patch
Patch10395: 10395-qemu-monitor-add-option-to-override-backend-in-qemu.patch
Patch10396: 10396-qemu-migration-support-changing-chardev-backend-wit.patch
Patch10397: 10397-logging-handle-race-on-drain-and-closing-in-event-l.patch
Patch10398: 10398-logging-allow-NULL-to-inode-and-offset-out-args-on-.patch
Patch10399: 10399-qemu-migration-detect-shared-vstorage-chardevs.patch
Patch10400: 10400-vstorage-support-migrating-with-chardevs-on-vstorag.patch
Patch10401: 10401-qemu-add-vstorage-chardev-tmpfile-names-to-status-f.patch
Patch10402: 10402-qemu-sync-chardevs-unplugged-status-on-reconnect.patch
Patch10403: 10403-qemu-cleanup-up-vstorage-chardevs-after-libvirtd-cr.patch
Patch10404: 10404-qemu-drain-file-chardevs-on-domain-process-stop.patch
Patch10405: 10405-Support-resources-change-for-libvirt-docker-driver-.patch
Patch10406: 10406-vstorage-migration-introduce-virDomainMigrateVstora.patch
Patch10407: 10407-vstorage-migration-add-vstorage-snapshot-commit-pha.patch
Patch10408: 10408-vstorage-migration-add-vstorage-disks-info-to-cooki.patch
Patch10409: 10409-vstorage-migration-add-vstorage-nvram-info-to-cooki.patch
Patch10410: 10410-qemu-add-nvram-block-job-support.patch
Patch10411: 10411-qemu-add-vstorage-snapshot-utility-functions.patch
Patch10412: 10412-vstorage-migration-add-vstorage-snapshot-commit.patch
Patch10413: 10413-vstorage-migration-main-patch-PSBM-106202.patch
Patch10414: 10414-vstorage-migration-support-p2p.patch
Patch10415: 10415-vstorage-load-bitmaps-from-base-image-for-tmp-snaps.patch
Patch10416: 10416-vstorage-migration-track-valid-temporary-snapshot.patch
Patch10417: 10417-vstorage-migration-resolve-valid-tmp-snapshot-on-do.patch
Patch10418: 10418-qemu-move-restoring-after-failure-to-cleanup-in-qem.patch
Patch10419: 10419-vstorage-migration-disable-API-that-can-clash-with-.patch
Patch10420: 10420-vstorage-migration-keep-snapshot-info-in-status.patch
Patch10421: 10421-vstorage-migration-add-dst-cleanup-after-disconnect.patch
Patch10422: 10422-vstorage-migration-determine-valid-snapshot-on-cras.patch
Patch10423: 10423-qemu-migration-fix-missing-owner-on-disconnection-c.patch
Patch10424: 10424-qemu-cleanup-tmp-snapshot-PSBM-106875.patch
Patch10425: 10425-logging-allow-max_len-0-to-disable-log-rollover-PSB.patch
Patch10426: 10426-qemu-support-nvram-block-job-on-reconnect.patch
Patch10427: 10427-vstorage-migration-handle-ready-state-on-reconnect-.patch
Patch10428: 10428-qemu-add-filename-to-qemuMonitorGetBlockInfo.patch
Patch10429: 10429-vstorage-migration-handle-completed-tmp-snapshot-co.patch
Patch10430: 10430-example-fix-typo-and-formatting.patch
Patch10431: 10431-example-add-ipv6-filters-examples.patch
Patch10432: 10432-doc-document-new-filters-and-not-documented-ones.patch
Patch10433: 10433-nwfilter-add-vz-specific-filters-PSBM-121477.patch
Patch10434: 10434-docker-add-compatibility-of-validation-with-current.patch
Patch10435: 10435-vstorage-migration-keep-nvram-tmp-snapshot-in-statu.patch
Patch10436: 10436-vstorage-migration-adopt-qemuDomainGetStatsOneBlock.patch
Patch10437: 10437-vstorage-migration-fix-active-block-stats-with-tmp-.patch
Patch10438: 10438-vstorage-migration-fix-inactive-block-stats-with-tm.patch
Patch10439: 10439-docker-fix-condition-for-list-of-storage-pools-PSBM.patch
Patch10440: 10440-vstorage-migration-handle-short-time-EBUSY-on-commi.patch
Patch10441: 10441-qemu-qemuDomainRenameCallback-fix-sending-false-und.patch
Patch10442: 10442-qemu-rename-send-events-only-on-success.patch
Patch10443: 10443-qemu-rename-return-instead-of-goto-if-no-cleanup-re.patch
Patch10444: 10444-qemu-remove-duplicate-code-for-removing-remnant-fil.patch
Patch10445: 10445-qemu-rename-support-renaming-snapshots-directory-PS.patch
Patch10446: 10446-qemu-rename-support-renaming-checkpoints-directory.patch
Patch10447: 10447-qemu-update-name-on-reverting-from-snapshot.patch
Patch10448: 10448-qemu-rename-remove-snapshot-checkpoint-restriction.patch
Patch10449: 10449-qemu-remove-possible-garbage-left-from-previous-ren.patch
Patch10450: 10450-docker-Add-support-autostart-feature-PSBM-122024.patch
Patch10451: 10451-docker-Refactoring-for-future-changes-PSBM-122024.patch
Patch10452: 10452-docker-Get-list-for-autostart-domains-PSBM-122024.patch
Patch10453: 10453-docker-Set-domain-as-not-autostart-by-default-PSBM-.patch
Patch10454: 10454-docker-Add-virDomainHasManagedSaveImage-method-and-.patch
Patch10455: 10455-api-add-stub-for-virDomainBlockCheckpointXSwitch.patch
Patch10456: 10456-api-add-VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO.patch
Patch10457: 10457-tools-support-memtune-min-guarantee-auto-vz.patch
Patch10458: 10458-qemu-support-min_gurantee-in-virDomain-Set-Get-Memo.patch
Patch10459: 10459-Fix-for-possibility-to-use-inituser-without-initgro.patch
Patch10460: 10460-docker-Fix-adding-of-restart-policy-PSBM-122225.patch
Patch10461: 10461-docker-Revert-possibility-to-use-cpushares-0-PSBM-1.patch
Patch10462: 10462-docker-Fix-for-correct-work-with-process-id-PSBM-12.patch
Patch10463: 10463-docker-Style-fix-PSBM-122225.patch
Patch10464: 10464-docker-Split-dockerContainerUpdate-to-dockerContain.patch
Patch10465: 10465-docker-Add-compatibility-with-virtsh-edit-command-P.patch
Patch10466: 10466-vzct-2-support-autostarting-domains-PSBM-121587.patch
Patch10467: 10467-docker-Don-t-use-case-sensitive-comparison-PSBM-122.patch
Patch10468: 10468-docker-Optimization-powershell-scripts-PSBM-122944.patch
Patch10469: 10469-docker-Using-sscanf-with-string-memory-allocation-P.patch
Patch10470: 10470-docker-Fix-some-error-msgs-PSBM-122944.patch
Patch10471: 10471-docker-Add-storagePoolLookupByVolume-method-PSBM-12.patch
Patch10472: 10472-docker-Add-real-refresh-metadata-for-storage-pool-P.patch
Patch10473: 10473-qemu-turn-on-postcopy-to-migrate-bitmaps-PSBM-10017.patch
Patch10474: 10474-qemu-fix-guest-visible-disk-id-if-serial-is-long-VS.patch
Patch10475: 10475-docker-Refactoring-code-with-default-cert-path-PSBM.patch
Patch10476: 10476-qemu-fix-managed-pr-helper-tear-down-on-chaning-dev.patch
Patch10477: 10477-docker-Check-existence-of-image-for-domain-definiti.patch
Patch10478: 10478-docker-Support-network-bandwidth-limits-for-contain.patch
Patch10479: 10479-docker-Use-negative-value-for-removing-network-band.patch
Patch10480: 10480-docker-Will-set-negative-value-only-if-it-needs-PSB.patch
Patch10481: 10481-forfix-docker-Set-correct-type-of-memory-var-PSBM-1.patch
Patch10482: 10482-docker-We-cannot-create-second-network-with-driver-.patch
Patch10483: 10483-docker-Connection-docker-network-to-selected-window.patch
Patch10484: 10484-doc-document-virsh-commands-for-block-snaphots-expo.patch
Patch10485: 10485-vz-fix-after-Parallels-to-Virtuozzo-rename-PSBM-124.patch
Patch10486: 10486-vstorage-remove-build-time-checks-for-runtime-binar.patch
Patch10487: 10487-virsh-fix-Vstorage-support-reporting.patch
Patch10488: 10488-exec-don-t-print-errors-to-stderr-PSBM-124629.patch
Patch10489: 10489-vzct-2-implement-exec-API-PSBM-106206.patch
Patch10490: 10490-virsh-don-t-call-virDomainGetGuestInfo-for-vzct-int.patch
Patch10491: 10491-daemon-switch-off-autoshutdown-VSTOR-40335.patch
Patch10492: 10492-api-fix-documentation-typo.patch
Patch10493: 10493-misc-add-bypass-cache-flag-for-block-snapshot-creat.patch
Patch10494: 10494-vzct-Support-setting-memory-for-active-CT-PSBM-1224.patch
Patch10495: 10495-vzct-Support-setting-cpu-num-for-active-CT-PSBM-122.patch
Patch10496: 10496-docs-document-backup-API-PSBM-124261.patch
Patch10497: 10497-vzct-Support-setting-memory-guarantee-for-active-CT.patch
Patch10498: 10498-vzct-Support-setting-IO-limits-for-active-CT-PSBM-1.patch
Patch10499: 10499-tools-treat-in-shutdown-etc-as-shutdown-finished-VS.patch
Patch10500: 10500-qemu-don-t-error-if-cannot-find-disk-by-alias-PSBM-.patch
Patch10501: 10501-qemu-vcmmd-support-for-setting-balloon-PSBM-123145.patch
Patch10502: 10502-qemu-better-cluster-size-for-tmp-deltas-on-vstorage.patch
Patch10503: 10503-util-add-hanging-process-debugging-PSBM-126062.patch
Patch10504: 10504-vzct-Support-disk-resize-for-active-CT-PSBM-122525.patch
Patch10505: 10505-qemu-detect-block-node-names-after-attaching-a-disk.patch
Patch10506: 10506-qemu-api-support-min_guarantee-as-fraction-of-ballo.patch
Patch10507: 10507-security-don-t-restore-labels-for-readonly-and-shar.patch
Patch10508: 10508-qemu-fix-noisy-error-for-domain-with-image-on-reado.patch
Patch10509: 10509-misc-add-blockjob-type-for-block-snapshot-job-PSBM-.patch
Patch10510: 10510-qemu-monitor-add-qemuMonitorBlockDirtyBitmapRemoveB.patch
Patch10511: 10511-util-add-virTimeBackOffWaitUnlocked.patch
Patch10512: 10512-backup-qemu-retry-bitmap-deletion-while-it-is-used-.patch
Patch10513: 10513-qemu-add-qemuMonitorJSONBlockdevDelBusy.patch
Patch10514: 10514-backup-qemu-retry-fleece-node-deletion-while-it-is-.patch
Patch10515: 10515-vstorage-migration-cleanup-precreated-src-tmp-delta.patch
Patch10516: 10516-upgrade-drain-chardev-s-pipes-PSBM-108071.patch
Patch10517: 10517-remote-remove-unused-daemonConfigLoadData.patch
Patch10518: 10518-util-move-virConf-definition-to-header.patch
Patch10519: 10519-util-make-conf-a-linked-list-of-configs.patch
Patch10520: 10520-util-add-virConfReadDir-to-read-dir-of-configs.patch
Patch10521: 10521-util-add-virConfCheckDuplicates-to-check-for-duplic.patch
Patch10522: 10522-remote-remove-filename-from-config-error-reporting.patch
Patch10523: 10523-remote-read-config-from-libvirtd.d-too-PSBM-127469.patch
Patch10524: 10524-qemu-read-config-from-qemu.d-too-PSBM-127469.patch
Patch10525: 10525-security-handle-chown-EACCES-on-readonly-cifs-mount.patch
Patch10526: 10526-vzct-add-ip-address-to-venet0-schema.patch
Patch10527: 10527-vzct-dump-ip-info-for-interfaces-PSBM-106470.patch
Patch10528: 10528-vzct-support-setting-net-interface-ips-on-define.patch
Patch10529: 10529-upgrade-support-ethernet-net-type-PSBM-127606.patch
Patch10530: 10530-qemu-acquire-job-to-handle-agent-disconnection-PSBM.patch
Patch10531: 10531-nwfilter-don-t-add-symmetric-record-for-policy-rule.patch
Patch10532: 10532-qemu-notify-vcmmd-of-node-vcpu-pinning-PSBM-126679.patch
Patch10533: 10533-qemu-fix-restoring-label-if-usb-hostdev-is-detached.patch
Patch10534: 10534-qemu-handle-usb-hostdev-on-qemu-update-PSBM-97288.patch
Patch10535: 10535-qemu-handle-timeout-on-unplugging-device-on-qemu-up.patch
Patch10536: 10536-storage-open-code-storageBackendRedoPloopUpdate.patch
Patch10537: 10537-storage-fix-refreshing-ploop-volumes-PSBM-128810.patch
Patch10538: 10538-forfix-docker-build-fix-on-rebase-5.6.0-6.6.0.patch
Patch10539: 10539-qemu-don-t-access-vm-without-lock.patch
Patch10540: 10540-qemu-request-flat-block-graph-output-when-possible.patch
Patch10541: 10541-FIXUP-pull-conf-add-export-conf-def-parsing.patch
Patch10542: 10542-TMP-temporary-fixes-to-unblock-most-of-cases.patch
Patch10543: 10543-FIXME-update-README.patch
Patch10544: 10544-vzct-support-cpumask-configuration-PSBM-107822.patch
Patch10545: 10545-vzct-support-numatune-nodeset-configuration-PSBM-10.patch
Patch10546: 10546-vstorage-pools-detect-vstorage.patch
Patch10547: 10547-vstorage-pools-use-external-metadata-on-pool-refres.patch
Patch10548: 10548-vstorage-pools-use-external-metadata-on-volume-refr.patch
Patch10549: 10549-vstorage-pools-save-metadata-on-creating-volume.patch
Patch10550: 10550-vstorage-pools-update-metadata-on-resizing-volume.patch
Patch10551: 10551-vstorage-volume-delete-metadata-on-deleting-volume.patch
Patch10552: 10552-vstorage-pools-cleanup-outdated-metadata.patch
Patch10553: 10553-FIXUP-vstorage-pools-use-external-metadata-on-volum.patch
Patch10554: 10554-qemu-capabilities-Add-capability-for-the-copy-mode-.patch
Patch10555: 10555-qemu-use-write-blocking-copy-mode-for-mirror-comman.patch
Patch10556: 10556-FIXUP-qemu-update-drive-mirror-and-blockdev-mirror-.patch
Patch10557: 10557-FIXUP-qemu-don-t-access-vcmmd-in-session-driver-PSB.patch
Patch10558: 10558-qemu-don-t-prohibit-of-cdrom-floppy-hot-attach-deta.patch
Patch10559: 10559-FIXUP-fix-privileged-vcmmd-patch-to-build-without-v.patch
Patch10560: 10560-vzct-support-user-alias-for-devices-PSBM-130985.patch
Patch10561: 10561-FIXUP-qemu-handle-host-usb-device-add-del-udev-even.patch
Patch10562: 10562-security-fix-compiler-warning.patch
Patch10563: 10563-FIXUP-vzct-support-user-alias-for-devices.patch
Patch10564: 10564-MERGE-schema-snapshot-add-persistent-domain-config.patch
Patch10565: 10565-conf-remove-static-from-virDomainDefSetMetadata.patch
Patch10566: 10566-FIXUP-vzct-Support-disk-resize-for-active-CT.patch
Patch10567: 10567-vzct-support-getting-setting-metadata-PSBM-131257.patch
Patch10568: 10568-FIXUP-nwfilter-add-vz-specific-filters-PSBM-131286.patch
Patch10569: 10569-FIXUP-example-add-ipv6-filters-examples.patch
Patch10570: 10570-FIXUP-qemu-wait-indefinetly-when-acquiring-job-cond.patch
Patch10571: 10571-qemu-add-hook-on-define-PSBM-130792.patch
Patch10572: 10572-qemu-add-virtuozzo-specific-hook-on-define.patch
Patch10573: 10573-qemu-vz-hook-set-machine-type-q35.patch
Patch10574: 10574-vzct-support-rename-PSBM-131350.patch
Patch10575: 10575-FIXUP-mark-explicit-backing-more-generically-VSTOR-.patch
Patch10576: 10576-FIXUP-fix-resetting-explicit-backing-whithout-persi.patch
Patch10577: 10577-vstorage-migration-support-explicit-backing.patch
Patch10578: 10578-FIXUP-allow-migration-with-explicit-backing.patch
Patch10579: 10579-FIXUP-remove-virDomainDefMarkExplicitBacking-symbol.patch
Patch10580: 10580-FIXUP-api-qemu-introduce-hv-vss-freeze-thaw-PSBM-13.patch
Patch10581: 10581-FIXUP-qemu-extract-private-exec-commands-PSBM-12974.patch
Patch10582: 10582-conf-add-vz-dhcp-parameter-to-xml-PSBM-129743.patch
Patch10583: 10583-qemu-support-setting-net-params-thru-prl_nettool-PS.patch
Patch10584: 10584-qemu-keep-netConfigApplied-in-status-file-PSBM-1297.patch
Patch10585: 10585-qemu-validate-that-route-is-default-gateway-PSBM-12.patch
Patch10586: 10586-FIXUP-vzct-2-add-basic-structure-and-listing-PSBM-1.patch
Patch10587: 10587-FIXUP-conf-add-format-attribute-to-domain-os-nvram-.patch
Patch10588: 10588-PSBM-130505-enable-hv-evmcs-hv-stimer-direct-in-dom.patch
Patch10589: 10589-qemu-introduce-qemuDomainCreateImage.patch
Patch10590: 10590-FIXUP-vstorage-migration-main-patch-PSBM-106202.patch
Patch10591: 10591-FIXUP-api-qemu-add-move-nvram-API.patch
Patch10592: 10592-FIXUP-vstorage-migration.patch
Patch10593: 10593-FIXUP-moving-bitmaps-on-snapshot.patch
Patch10594: 10594-FIXUP-qemu-support-setting-net-params-thru-prl_nett.patch
Patch10595: 10595-qemu-support-changing-net-params-PSBM-129743.patch
Patch10596: 10596-FIXUP-qemu-setting-q35-in-hook.patch
Patch10597: 10597-FIXUP-setting-misc-win-features.patch
Patch10598: 10598-FIXUP-enhance-error-message-macros.patch
Patch10599: 10599-vzct-2-support-volumes-in-define-undefine-stats-PSB.patch
Patch10600: 10600-vzct-2-support-volumes-on-start-stop-PSBM-128811.patch
Patch10601: 10601-FIXUP-vzct-2-intoroduce-vzctDomainDefCopy.patch
Patch10602: 10602-vzct-2-store-disk-uuids-in-snapshot-metadata.patch
Patch10603: 10603-conf-virDomainSnapshotDefParse-allow-NULL-current.patch
Patch10604: 10604-vzct-2-support-volumes-for-snapshot-API-PSBM-128811.patch
Patch10605: 10605-FIXUP-vzct-2-prepare-cookie-to-add-more-parts.patch
Patch10606: 10606-vzct-2-add-destination-pool-info-to-migration-cooki.patch
Patch10607: 10607-vzct-2-migration-check-storage-pool-alignment-on-sr.patch
Patch10608: 10608-vzct-2-support-volumes-on-migration-PSBM-128811.patch
Patch10609: 10609-vzct-2-skip-actions-on-libvzctl-config-after-migrat.patch
Patch10610: 10610-Save-state-of-guest-tools-autoupdate-in-domain-meta.patch
Patch10611: 10611-FIXUP-qemu-use-def-arg-in-qemuDomainTmpSnapshotFind.patch
Patch10612: 10612-FIXUP-qemu-factor-out-qemuDomainTmpSnapshotIsPresen.patch
Patch10613: 10613-FIXUP-allow-non-disk-changes-on-defineXML-with-tmp-.patch
Patch10614: 10614-qemu-fix-refreshing-of-restored-VM-PSBM-132173-upst.patch

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-config-network = %{version}-%{release}
Requires: libvirt-daemon-config-nwfilter = %{version}-%{release}
%if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
%endif
%if %{with_qemu}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
%endif
%if %{with_vzct}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
%endif
# We had UML driver, but we've removed it.
Obsoletes: libvirt-daemon-driver-uml <= 5.0.0
Obsoletes: libvirt-daemon-uml <= 5.0.0
%if %{with_vbox}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

Requires: libvirt-daemon-driver-interface = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-client = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

# All build-time requirements. Run-time requirements are
# listed against each sub-RPM
%if 0%{?enable_autotools}
BuildRequires: autoconf
BuildRequires: automake
BuildRequires: gettext-devel
BuildRequires: libtool
%endif
%if 0%{?rhel} == 7
BuildRequires: python36-docutils
%else
BuildRequires: python3-docutils
%endif
BuildRequires: gcc
BuildRequires: make
BuildRequires: git
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: perl-interpreter
%else
BuildRequires: perl
%endif
%if 0%{?rhel} > 7
BuildRequires: python3-devel
%else
BuildRequires: python3
%endif
BuildRequires: systemd-units
%if %{with_libxl}
BuildRequires: xen-devel
%endif
BuildRequires: glib2-devel >= 2.48
BuildRequires: libxml2-devel
BuildRequires: libxslt
BuildRequires: readline-devel
%if %{with_bash_completion}
BuildRequires: bash-completion >= 2.0
%endif
BuildRequires: gettext
BuildRequires: libtasn1-devel
BuildRequires: gnutls-devel
BuildRequires: libattr-devel
# For pool-build probing for existing pools
BuildRequires: libblkid-devel >= 2.17
# for augparse, optionally used in testing
BuildRequires: augeas
BuildRequires: systemd-devel >= 185
BuildRequires: libpciaccess-devel >= 0.10.9
BuildRequires: yajl-devel
%if %{with_sanlock}
BuildRequires: sanlock-devel >= 2.4
%endif
BuildRequires: libpcap-devel >= 1.5.0
BuildRequires: libnl3-devel
BuildRequires: libselinux-devel
BuildRequires: dnsmasq >= 2.41
BuildRequires: iptables
BuildRequires: radvd
BuildRequires: ebtables
BuildRequires: module-init-tools
BuildRequires: cyrus-sasl-devel
BuildRequires: polkit >= 0.112
BuildRequires: patch
# For mount/umount in FS driver
BuildRequires: util-linux
%if %{with_qemu}
# For managing ACLs
BuildRequires: libacl-devel
# From QEMU RPMs
BuildRequires: /usr/bin/qemu-img
%endif
# For LVM drivers
BuildRequires: lvm2
# For pool type=iscsi
BuildRequires: iscsi-initiator-utils
%if %{with_storage_iscsi_direct}
# For pool type=iscsi-direct
BuildRequires: libiscsi-devel
%endif
# For disk driver
BuildRequires: parted-devel
# For Multipath support
BuildRequires: device-mapper-devel
# For XFS reflink clone support
BuildRequires: xfsprogs-devel
%if %{with_storage_rbd}
    %if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: librados-devel
BuildRequires: librbd-devel
    %else
BuildRequires: librados2-devel
BuildRequires: librbd1-devel
    %endif
%endif
%if %{with_storage_gluster}
BuildRequires: glusterfs-api-devel >= 3.4.1
BuildRequires: glusterfs-devel >= 3.4.1
%endif
%if %{with_storage_sheepdog}
BuildRequires: sheepdog
%endif
%if %{with_storage_zfs}
# Support any conforming implementation of zfs. On stock Fedora
# this is zfs-fuse, but could be zfsonlinux upstream RPMs
BuildRequires: /sbin/zfs
BuildRequires: /sbin/zpool
%endif
%if %{with_numactl}
# For QEMU/LXC numa info
BuildRequires: numactl-devel
%endif
BuildRequires: libcap-ng-devel >= 0.5.0
%if %{with_fuse}
BuildRequires: fuse-devel >= 2.8.6
%endif
%if %{with_libssh2}
BuildRequires: libssh2-devel >= 1.3.0
%endif

BuildRequires: netcf-devel >= 0.2.2
%if %{with_esx}
BuildRequires: libcurl-devel
%endif
%if %{with_hyperv}
BuildRequires: libwsman-devel >= 2.2.3
%endif
BuildRequires: audit-libs-devel
# we need /usr/sbin/dtrace
BuildRequires: systemtap-sdt-devel

# For mount/umount in FS driver
BuildRequires: util-linux
# For showmount in FS driver (netfs discovery)
BuildRequires: nfs-utils

# Communication with the firewall and polkit daemons use DBus
BuildRequires: dbus-devel

# Fedora build root suckage
BuildRequires: gawk

# For storage wiping with different algorithms
BuildRequires: scrub

%if %{with_numad}
BuildRequires: numad
%endif

%if %{with_wireshark}
BuildRequires: wireshark-devel >= 2.4.0
%endif

%if %{with_libssh}
BuildRequires: libssh-devel >= 0.7.0
%endif

%if %{with_vz}
BuildRequires: libprlsdk-devel
%endif

%if %{with_vzct}
BuildRequires: libprlsdk-devel
BuildRequires: ploop-devel
BuildRequires: libvzctl-devel >= 7.0.655
BuildRequires: libvcmmd-devel
BuildRequires: libvzevent-devel
%if 0%{?rhel} > 7
BuildRequires: kernel-headers
%else
BuildRequires: vzkernel-headers
%endif
BuildRequires: perl-XML-XPath
%endif

# On RHEL-7 rpcgen is still part of glibc-common package
%if 0%{?fedora} || 0%{?rhel} > 7
BuildRequires: rpcgen
%endif

BuildRequires: libtirpc-devel

%if %{with_firewalld_zone}
BuildRequires: firewalld-filesystem
%endif

%if %{with_docker}
BuildRequires: libcurl-devel
BuildRequires: libwsman-devel
%endif

%if %{with_vcmmd}
BuildRequires: libvcmmd-devel
%endif

%description
Libvirt is a C toolkit to interact with the virtualization capabilities
of recent versions of Linux (and other OSes). The main package includes
the libvirtd server exporting the virtualization support.

%package docs
Summary: API reference and website documentation

%description docs
Includes the API reference for the libvirt C library, and a complete
copy of the libvirt.org website documentation.

%package daemon
Summary: Server side daemon and supporting files for libvirt library

# All runtime requirements for the libvirt package (runtime requrements
# for subpackages are listed later in those subpackages)

# The client side, i.e. shared libs are in a subpackage
Requires: %{name}-libs = %{version}-%{release}

# (client invokes 'nc' against the UNIX socket on the server)
Requires: /usr/bin/nc

# for modprobe of pci devices
Requires: module-init-tools

# for /sbin/ip & /sbin/tc
Requires: iproute
# tc is provided by iproute-tc since at least Fedora 26
%if 0%{?fedora} || 0%{?rhel} > 7
Requires: iproute-tc
%endif

Requires: polkit >= 0.112
%ifarch %{ix86} x86_64 ia64
# For virConnectGetSysinfo
Requires: dmidecode
%endif
# For service management
Requires(post): systemd-units
Requires(post): systemd-sysv
Requires(preun): systemd-units
Requires(postun): systemd-units
%if %{with_numad}
Requires: numad
%endif
# libvirtd depends on 'messagebus' service
Requires: dbus
# For uid creation during pre
Requires(pre): shadow-utils

%description daemon
Server side daemon required to manage the virtualization capabilities
of recent versions of Linux. Requires a hypervisor specific sub-RPM
for specific drivers.

%package daemon-config-network
Summary: Default configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description daemon-config-network
Default configuration files for setting up NAT based networking

%package daemon-config-nwfilter
Summary: Network filter configuration files for the libvirtd daemon

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}

%description daemon-config-nwfilter
Network filter configuration files for cleaning guest traffic

%package daemon-driver-network
Summary: Network driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: dnsmasq >= 2.41
Requires: radvd
Requires: iptables

%description daemon-driver-network
The network driver plugin for the libvirtd daemon, providing
an implementation of the virtual network APIs using the Linux
bridge capabilities.


%package daemon-driver-nwfilter
Summary: Nwfilter driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iptables
Requires: ebtables

%description daemon-driver-nwfilter
The nwfilter driver plugin for the libvirtd daemon, providing
an implementation of the firewall APIs using the ebtables,
iptables and ip6tables capabilities


%package daemon-driver-nodedev
Summary: Nodedev driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# needed for device enumeration
Requires: systemd >= 185
# For managing persistent mediated devices
%if 0%{?fedora} || 0%{?rhel} > 7
Requires: mdevctl
%endif

%description daemon-driver-nodedev
The nodedev driver plugin for the libvirtd daemon, providing
an implementation of the node device APIs using the udev
capabilities.


%package daemon-driver-interface
Summary: Interface driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: netcf-libs >= 0.2.2

%description daemon-driver-interface
The interface driver plugin for the libvirtd daemon, providing
an implementation of the network interface APIs using the
netcf library


%if %{with_secret}
%package daemon-driver-secret
Summary: Secret driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-secret
The secret driver plugin for the libvirtd daemon, providing
an implementation of the secret key APIs.
%endif

%package daemon-driver-storage-core
Summary: Storage driver plugin including base backends for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: nfs-utils
# For mkfs
Requires: util-linux
%if %{with_qemu}
# From QEMU RPMs
Requires: /usr/bin/qemu-img
%endif
%if !%{with_storage_rbd}
Obsoletes: libvirt-daemon-driver-storage-rbd < %{version}-%{release}
%endif

%description daemon-driver-storage-core
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using files, local disks, LVM, SCSI,
iSCSI, and multipath storage.

%if %{with_storage_misc}
%package daemon-driver-storage-logical
Summary: Storage driver plugin for lvm volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: lvm2

%description daemon-driver-storage-logical
The storage driver backend adding implementation of the storage APIs for block
volumes using lvm.


%package daemon-driver-storage-disk
Summary: Storage driver plugin for disk
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: parted
Requires: device-mapper

%description daemon-driver-storage-disk
The storage driver backend adding implementation of the storage APIs for block
volumes using the host disks.


%package daemon-driver-storage-scsi
Summary: Storage driver plugin for local scsi devices
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-scsi
The storage driver backend adding implementation of the storage APIs for scsi
host devices.


%package daemon-driver-storage-iscsi
Summary: Storage driver plugin for iscsi
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: iscsi-initiator-utils

%description daemon-driver-storage-iscsi
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using the host iscsi stack.
%endif


%if %{with_storage_iscsi_direct}
%package daemon-driver-storage-iscsi-direct
Summary: Storage driver plugin for iscsi-direct
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: libiscsi

%description daemon-driver-storage-iscsi-direct
The storage driver backend adding implementation of the storage APIs for iscsi
volumes using libiscsi direct connection.
%endif


%if %{with_storage_misc}
%package daemon-driver-storage-mpath
Summary: Storage driver plugin for multipath volumes
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: device-mapper

%description daemon-driver-storage-mpath
The storage driver backend adding implementation of the storage APIs for
multipath storage using device mapper.
%endif


%if %{with_storage_gluster}
%package daemon-driver-storage-gluster
Summary: Storage driver plugin for gluster
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
    %if 0%{?fedora}
Requires: glusterfs-client >= 2.0.1
    %endif
    %if (0%{?fedora} || 0%{?with_storage_gluster})
Requires: /usr/sbin/gluster
    %endif

%description daemon-driver-storage-gluster
The storage driver backend adding implementation of the storage APIs for gluster
volumes using libgfapi.
%endif


%if %{with_storage_rbd}
%package daemon-driver-storage-rbd
Summary: Storage driver plugin for rbd
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-storage-rbd
The storage driver backend adding implementation of the storage APIs for rbd
volumes using the ceph protocol.
%endif


%if %{with_storage_sheepdog}
%package daemon-driver-storage-sheepdog
Summary: Storage driver plugin for sheepdog
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: sheepdog

%description daemon-driver-storage-sheepdog
The storage driver backend adding implementation of the storage APIs for
sheepdog volumes using.
%endif


%if %{with_storage_zfs}
%package daemon-driver-storage-zfs
Summary: Storage driver plugin for ZFS
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# Support any conforming implementation of zfs
Requires: /sbin/zfs
Requires: /sbin/zpool

%description daemon-driver-storage-zfs
The storage driver backend adding implementation of the storage APIs for
ZFS volumes.
%endif

%if %{with_storage_vstorage}
%package daemon-driver-storage-vstorage
Summary: Storage driver plugin for Vstorage
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: vstorage-client

%description daemon-driver-storage-vstorage
The storage driver backend adding implementation of the storage APIs for
Vstorage volumes.
%endif


%package daemon-driver-storage
Summary: Storage driver plugin including all backends for the libvirtd daemon
Requires: libvirt-daemon-driver-storage-core = %{version}-%{release}

%description daemon-driver-storage
The storage driver plugin for the libvirtd daemon, providing
an implementation of the storage APIs using LVM, iSCSI,
parted and more.


%if %{with_qemu}
%package daemon-driver-qemu
Summary: QEMU driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Requires: /usr/bin/qemu-img
# For image compression
Requires: gzip
Requires: bzip2
Requires: lzop
Requires: xz
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif
%if %{with_vcmmd}
Requires: libvcmmd
%endif

%description daemon-driver-qemu
The qemu driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
QEMU
%endif


%if %{with_lxc}
%package daemon-driver-lxc
Summary: LXC driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
# There really is a hard cross-driver dependency here
Requires: libvirt-daemon-driver-network = %{version}-%{release}
    %if 0%{?fedora} || 0%{?rhel} > 7
Requires: systemd-container
    %endif

%description daemon-driver-lxc
The LXC driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
the Linux kernel
%endif


%if %{with_vbox}
%package daemon-driver-vbox
Summary: VirtualBox driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}

%description daemon-driver-vbox
The vbox driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
VirtualBox
%endif


%if %{with_libxl}
%package daemon-driver-libxl
Summary: Libxl driver plugin for the libvirtd daemon
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-libs = %{version}-%{release}
Obsoletes: libvirt-daemon-driver-xen < 4.3.0

%description daemon-driver-libxl
The Libxl driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Libxl
%endif

%if %{with_vz}
%package daemon-driver-vz
Summary: Virtuozzo driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}

%description daemon-driver-vz
The vz driver plugin for the libvirtd daemon, providing
an implementation of the hypervisor driver APIs using
Virtuozzo
%endif


%if %{with_vzct}
%package daemon-driver-vzct
Summary: Virtuozzo Containers driver plugin for the libvirtd daemon
Group: Development/Libraries
Requires: libvirt-daemon = %{version}-%{release}
Requires: libvzctl
Requires: ploop-lib
Requires: ploop
Requires: vzctl

%description daemon-driver-vzct
The libvirt hypervisor driver which provides access to Virtuozzo
containers
%endif


%if %{with_qemu_tcg}
%package daemon-qemu
Summary: Server side daemon & driver required to run QEMU guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu

%description daemon-qemu
Server side daemon and driver required to manage the virtualization
capabilities of the QEMU TCG emulators
%endif


%if %{with_qemu_kvm}
%package daemon-kvm
Summary: Server side daemon & driver required to run KVM guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-qemu = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
%if %{with_secret}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
%endif
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: qemu-kvm

%description daemon-kvm
Server side daemon and driver required to manage the virtualization
capabilities of the KVM hypervisor
%endif


%if %{with_lxc}
%package daemon-lxc
Summary: Server side daemon & driver required to run LXC guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-lxc = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-lxc
Server side daemon and driver required to manage the virtualization
capabilities of LXC
%endif


%if %{with_libxl}
%package daemon-xen
Summary: Server side daemon & driver required to run XEN guests

Requires: libvirt-daemon = %{version}-%{release}
    %if %{with_libxl}
Requires: libvirt-daemon-driver-libxl = %{version}-%{release}
    %endif
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}
Requires: xen

%description daemon-xen
Server side daemon and driver required to manage the virtualization
capabilities of XEN
%endif

%if %{with_vbox}
%package daemon-vbox
Summary: Server side daemon & driver required to run VirtualBox guests

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vbox = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-secret = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vbox
Server side daemon and driver required to manage the virtualization
capabilities of VirtualBox
%endif

%if %{with_vz}
%package daemon-vz
Summary: Server side daemon & driver required to run Virtuozzo guests
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vz = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vz
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo
%endif

%if %{with_vzct}
%package daemon-vzct
Summary: Server side daemon & driver required to run Virtuozzo containers
Group: Development/Libraries

Requires: libvirt-daemon = %{version}-%{release}
Requires: libvirt-daemon-driver-vzct = %{version}-%{release}
Requires: libvirt-daemon-driver-interface = %{version}-%{release}
Requires: libvirt-daemon-driver-network = %{version}-%{release}
Requires: libvirt-daemon-driver-nodedev = %{version}-%{release}
Requires: libvirt-daemon-driver-nwfilter = %{version}-%{release}
Requires: libvirt-daemon-driver-storage = %{version}-%{release}

%description daemon-vzct
Server side daemon and driver required to manage the virtualization
capabilities of Virtuozzo containers
%endif

%package client
Summary: Client side utilities of the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
# Needed by /usr/libexec/libvirt-guests.sh script.
Requires: gettext
# Needed by virt-pki-validate script.
Requires: gnutls-utils
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description client
The client binaries needed to access the virtualization
capabilities of recent versions of Linux (and other OSes).

%package libs
Summary: Client side libraries
# So remote clients can access libvirt over SSH tunnel
Requires: cyrus-sasl
# Needed by default sasl.conf - no onerous extra deps, since
# 100's of other things on a system already pull in krb5-libs
Requires: cyrus-sasl-gssapi

%description libs
Shared libraries for accessing the libvirt daemon.

%package admin
Summary: Set of tools to control libvirt daemon
Requires: %{name}-libs = %{version}-%{release}
Requires: readline
%if %{with_bash_completion}
Requires: %{name}-bash-completion = %{version}-%{release}
%endif

%description admin
The client side utilities to control the libvirt daemon.

%if %{with_bash_completion}
%package bash-completion
Summary: Bash completion script

%description bash-completion
Bash completion script stub.
%endif

%if %{with_wireshark}
%package wireshark
Summary: Wireshark dissector plugin for libvirt RPC transactions
Requires: wireshark >= 2.4.0
Requires: %{name}-libs = %{version}-%{release}

%description wireshark
Wireshark dissector plugin for better analysis of libvirt RPC traffic.
%endif

%if %{with_lxc}
%package login-shell
Summary: Login shell for connecting users to an LXC container
Requires: %{name}-libs = %{version}-%{release}

%description login-shell
Provides the set-uid virt-login-shell binary that is used to
connect a user to an LXC container when they login, by switching
namespaces.
%endif

%package devel
Summary: Libraries, includes, etc. to compile with the libvirt library
Requires: %{name}-libs = %{version}-%{release}
Requires: pkgconfig

%description devel
Include header files & development libraries for the libvirt C library.

%if %{with_sanlock}
%package lock-sanlock
Summary: Sanlock lock manager plugin for QEMU driver
Requires: sanlock >= 2.4
#for virt-sanlock-cleanup require augeas
Requires: augeas
Requires: %{name}-daemon = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}

%description lock-sanlock
Includes the Sanlock lock manager plugin for the QEMU
driver
%endif

%package nss
Summary: Libvirt plugin for Name Service Switch
Requires: libvirt-daemon-driver-network = %{version}-%{release}

%description nss
Libvirt plugin for NSS for translating domain names into IP addresses.


%prep

%autosetup -S git_am -N

# "make dist" replaces all symlinks with a copy of the linked files;
# we need to replace all of them with the original symlinks
echo "Restoring symlinks"
while read lnk target; do
    if [ -e $lnk ]; then
        rm -rf $lnk
        ln -s $target $lnk
    fi
done <%{_sourcedir}/symlinks || exit 1
git add .
git commit -q -a --author 'rpm-build <rpm-build>' -m symlinks


git config gc.auto 0

%autopatch

%build
%if ! %{supported_platform}
echo "This RPM requires either Fedora >= %{min_fedora} or RHEL >= %{min_rhel}"
exit 1
%endif

%if %{with_qemu}
    %define arg_qemu --with-qemu
%else
    %define arg_qemu --without-qemu
%endif

%if %{with_openvz}
    %define arg_openvz --with-openvz
%else
    %define arg_openvz --without-openvz
%endif

%if %{with_lxc}
    %define arg_lxc --with-lxc
    %define arg_login_shell --with-login-shell
%else
    %define arg_lxc --without-lxc
    %define arg_login_shell --without-login-shell
%endif

%if %{with_vbox}
    %define arg_vbox --with-vbox
%else
    %define arg_vbox --without-vbox
%endif

%if %{with_libxl}
    %define arg_libxl --with-libxl
%else
    %define arg_libxl --without-libxl
%endif

%if %{with_esx}
    %define arg_esx --with-esx
%else
    %define arg_esx --without-esx
%endif

%if %{with_hyperv}
    %define arg_hyperv --with-hyperv
%else
    %define arg_hyperv --without-hyperv
%endif

%if %{with_vmware}
    %define arg_vmware --with-vmware
%else
    %define arg_vmware --without-vmware
%endif

%if %{with_storage_rbd}
    %define arg_storage_rbd --with-storage-rbd
%else
    %define arg_storage_rbd --without-storage-rbd
%endif

%if %{with_storage_sheepdog}
    %define arg_storage_sheepdog --with-storage-sheepdog
%else
    %define arg_storage_sheepdog --without-storage-sheepdog
%endif

%if %{with_storage_gluster}
    %define arg_storage_gluster --with-storage-gluster
%else
    %define arg_storage_gluster --without-storage-gluster
%endif

%if %{with_storage_zfs}
    %define arg_storage_zfs --with-storage-zfs
%else
    %define arg_storage_zfs --without-storage-zfs
%endif

%if %{with_storage_vstorage}
    %define arg_storage_vstorage --with-storage-vstorage
%else
    %define arg_storage_vstorage --without-storage-vstorage
%endif

%if %{with_numactl}
    %define arg_numactl --with-numactl
%else
    %define arg_numactl --without-numactl
%endif

%if %{with_numad}
    %define arg_numad --with-numad
%else
    %define arg_numad --without-numad
%endif

%if %{with_fuse}
    %define arg_fuse --with-fuse
%else
    %define arg_fuse --without-fuse
%endif

%if %{with_sanlock}
    %define arg_sanlock --with-sanlock
%else
    %define arg_sanlock --without-sanlock
%endif

%if %{with_firewalld}
    %define arg_firewalld --with-firewalld
%else
    %define arg_firewalld --without-firewalld
%endif

%if %{with_firewalld_zone}
    %define arg_firewalld_zone --with-firewalld-zone
%else
    %define arg_firewalld_zone --without-firewalld-zone
%endif

%if %{with_wireshark}
    %define arg_wireshark --with-wireshark-dissector
%else
    %define arg_wireshark --without-wireshark-dissector
%endif

%if %{with_storage_iscsi_direct}
    %define arg_storage_iscsi_direct --with-storage-iscsi-direct
%else
    %define arg_storage_iscsi_direct --without-storage-iscsi-direct
%endif

%if %{with_secret}
    %define arg_secret --with-secrets
%else
    %define arg_secret --without-secrets
%endif

%if %{with_storage_misc}
    %define arg_storage_misc --with-storage-lvm --with-storage-iscsi --with-storage-scsi --with-storage-disk --with-storage-mpath
%else
    %define arg_storage_misc --without-storage-lvm --without-storage-iscsi --without-storage-scsi --without-storage-disk --without-storage-mpath
%endif

%if %{with_vz}
    %define arg_vz --with-vz
%else
    %define arg_vz --without-vz
%endif

%if %{with_vzct}
    %define arg_vzct --with-vzct
%else
    %define arg_vzct --without-vzct
%endif

%if %{with_docker}
    %define arg_docker --with-docker
%else
    %define arg_docker --without-docker
%endif

%if %{with_vcmmd}
    %define arg_vcmmd --with-vcmmd
%else
    %define arg_vcmmd --without-vcmmd
%endif

%define when  %(date +"%%F-%%T")
%define where %(hostname)
%define who   %{?packager}%{!?packager:Unknown}
%define arg_packager --with-packager="%{who}, %{when}, %{where}"
%define arg_packager_version --with-packager-version="%{release}"

%define arg_selinux_mount --with-selinux-mount="/sys/fs/selinux"

# place macros above and build commands below this comment

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

%if 0%{?enable_autotools}
 autoreconf -if
%endif

rm -f po/stamp-po

%define _configure ../configure
mkdir %{_vpath_builddir}
cd %{_vpath_builddir}

%configure --enable-dependency-tracking \
           --with-runstatedir=%{_rundir} \
           %{?arg_qemu} \
           %{?arg_openvz} \
           %{?arg_lxc} \
           %{?arg_vbox} \
           %{?arg_libxl} \
           --with-sasl \
           --with-polkit \
           --with-libvirtd \
           %{?arg_esx} \
           %{?arg_hyperv} \
           %{?arg_vmware} \
           %{?arg_vz} \
           %{?arg_vzct} \
           %{?arg_docker} \
           --without-bhyve \
           --with-remote-default-mode=legacy \
           --with-interface \
           --with-network \
           --with-storage-fs \
           %{?arg_storage_iscsi_direct} \
           %{?arg_storage_misc} \
           %{?arg_storage_rbd} \
           %{?arg_storage_sheepdog} \
           %{?arg_storage_gluster} \
           %{?arg_storage_zfs} \
           %{?arg_storage_vstorage} \
           %{?arg_numactl} \
           %{?arg_numad} \
           --with-capng \
           %{?arg_fuse} \
           --with-netcf \
           %{?arg_vcmmd} \
           --with-selinux \
           %{?arg_selinux_mount} \
           --without-apparmor \
           --without-hal \
           --with-udev \
           --with-yajl \
           %{?arg_sanlock} \
           --with-libpcap \
           --with-macvtap \
           --with-audit \
           --with-dtrace \
           --with-driver-modules \
           %{?arg_firewalld} \
           %{?arg_firewalld_zone} \
           %{?arg_wireshark} \
           --without-pm-utils \
           --with-nss-plugin \
           %{arg_packager} \
           %{arg_packager_version} \
           --with-qemu-user=%{qemu_user} \
           --with-qemu-group=%{qemu_group} \
           --with-tls-priority=%{tls_priority} \
           %{?enable_werror} \
           --enable-expensive-tests \
           --with-init-script=systemd \
           %{?arg_secret} \
           %{?arg_login_shell}
make %{?_smp_mflags} V=1

%install
rm -fr %{buildroot}

export SOURCE_DATE_EPOCH=$(stat --printf='%Y' %{_specdir}/%{name}.spec)

cd %{_vpath_builddir}
%make_install %{?_smp_mflags} SYSTEMD_UNIT_DIR=%{_unitdir} V=1

rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/lock-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/connection-driver/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-backend/*.a
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.la
rm -f $RPM_BUILD_ROOT%{_libdir}/libvirt/storage-file/*.a
%if %{with_wireshark}
rm -f $RPM_BUILD_ROOT%{wireshark_plugindir}/libvirt.la
%endif

install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/lib/libvirt/dnsmasq/
# We don't want to install /etc/libvirt/qemu/networks in the main %files list
# because if the admin wants to delete the default network completely, we don't
# want to end up re-incarnating it on every RPM upgrade.
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/
cp $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml \
   $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
# libvirt saves this file with mode 0600
chmod 0600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu/networks/default.xml

# nwfilter files are installed in /usr/share/libvirt and copied to /etc in %post
# to avoid verification errors on changed files in /etc
install -d -m 0755 $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
cp -a $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml \
    $RPM_BUILD_ROOT%{_datadir}/libvirt/nwfilter/
# libvirt saves these files with mode 600
chmod 600 $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/nwfilter/*.xml

# Strip auto-generated UUID - we need it generated per-install
sed -i -e "/<uuid>/d" $RPM_BUILD_ROOT%{_datadir}/libvirt/networks/default.xml
%if ! %{with_qemu}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_qemu.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%endif
%find_lang %{name}

%if ! %{with_sanlock}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirt_sanlock.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%endif

%if ! %{with_lxc}
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_lxc.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%endif

%if ! %{with_qemu}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/qemu.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.qemu
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%endif
%if ! %{with_lxc}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/lxc.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.lxc
%endif
%if ! %{with_libxl}
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/libvirt/libxl.conf
rm -rf $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/libvirtd.libxl
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/libvirtd_libxl.aug
rm -f $RPM_BUILD_ROOT%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%endif

# Copied into libvirt-docs subpackage eventually
mv $RPM_BUILD_ROOT%{_datadir}/doc/libvirt libvirt-docs

%ifarch %{power64} s390x x86_64 ia64 alpha sparc64
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_probes-64.stp

    %if %{with_qemu}
mv $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes.stp \
   $RPM_BUILD_ROOT%{_datadir}/systemtap/tapset/libvirt_qemu_probes-64.stp
    %endif
%endif

%check
%if %do_check
cd %{_vpath_builddir}
if ! make %{?_smp_mflags} check VIR_TEST_DEBUG=1
then
  cat tests/test-suite.log || true
  exit 1
fi
%endif

%post libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%postun libs
%if 0%{?rhel} == 7
/sbin/ldconfig
%endif

%pre daemon
# 'libvirt' group is just to allow password-less polkit access to
# libvirtd. The uid number is irrelevant, so we use dynamic allocation
# described at the above link.
getent group libvirt >/dev/null || groupadd -r libvirt

exit 0

%post daemon

%systemd_post virtlockd.socket virtlockd-admin.socket
%systemd_post virtlogd.socket virtlogd-admin.socket
%systemd_post libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_post libvirtd-tcp.socket libvirtd-tls.socket
%systemd_post libvirtd.service

# request daemon restart in posttrans
mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :

%preun daemon
%systemd_preun libvirtd.service
%systemd_preun libvirtd-tcp.socket libvirtd-tls.socket
%systemd_preun libvirtd.socket libvirtd-ro.socket libvirtd-admin.socket
%systemd_preun virtlogd.socket virtlogd-admin.socket virtlogd.service
%systemd_preun virtlockd.socket virtlockd-admin.socket virtlockd.service

%postun daemon
/bin/systemctl daemon-reload >/dev/null 2>&1 || :
if [ $1 -ge 1 ] ; then
    /bin/systemctl reload-or-try-restart virtlockd.service >/dev/null 2>&1 || :
    /bin/systemctl reload-or-try-restart virtlogd.service >/dev/null 2>&1 || :
fi

# In upgrade scenario we must explicitly enable virtlockd/virtlogd
# sockets, if libvirtd is already enabled and start them if
# libvirtd is running, otherwise you'll get failures to start
# guests
%triggerpostun daemon -- libvirt-daemon < 1.3.0
if [ $1 -ge 1 ] ; then
    /bin/systemctl is-enabled libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl enable virtlogd.socket virtlogd-admin.socket || :
    /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1 &&
        /bin/systemctl start virtlogd.socket virtlogd-admin.socket || :
fi

%posttrans daemon
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    # See if user has previously modified their install to
    # tell libvirtd to use --listen
    grep -E '^LIBVIRTD_ARGS=.*--listen' /etc/sysconfig/libvirtd 1>/dev/null 2>&1
    if test $? = 0
    then
        # Then lets keep honouring --listen and *not* use
        # systemd socket activation, because switching things
        # might confuse mgmt tool like puppet/ansible that
        # expect the old style libvirtd
        /bin/systemctl mask libvirtd.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-ro.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-admin.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tls.socket >/dev/null 2>&1 || :
        /bin/systemctl mask libvirtd-tcp.socket >/dev/null 2>&1 || :
    else
        # Old libvirtd owns the sockets and will delete them on
        # shutdown. Can't use a try-restart as libvirtd will simply
        # own the sockets again when it comes back up. Thus we must
        # do this particular ordering, so that we get libvirtd
        # running with socket activation in use
        /bin/systemctl is-active libvirtd.service 1>/dev/null 2>&1
        if test $? = 0
        then
            /bin/systemctl stop libvirtd.service >/dev/null 2>&1 || :

            /bin/systemctl try-restart libvirtd.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-ro.socket >/dev/null 2>&1 || :
            /bin/systemctl try-restart libvirtd-admin.socket >/dev/null 2>&1 || :

            /bin/systemctl start libvirtd.service >/dev/null 2>&1 || :
        fi
    fi
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%post daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%postun daemon-driver-network
%if %{with_firewalld_zone}
    %firewalld_reload
%endif

%post daemon-config-network
if test $1 -eq 1 && test ! -f %{_sysconfdir}/libvirt/qemu/networks/default.xml ; then
    # see if the network used by default network creates a conflict,
    # and try to resolve it
    # NB: 192.168.122.0/24 is used in the default.xml template file;
    # do not modify any of those values here without also modifying
    # them in the template.
    orig_sub=122
    sub=${orig_sub}
    nl='
'
    routes="${nl}$(ip route show | cut -d' ' -f1)${nl}"
    case ${routes} in
      *"${nl}192.168.${orig_sub}.0/24${nl}"*)
        # there was a match, so we need to look for an unused subnet
        for new_sub in $(seq 124 254); do
          case ${routes} in
          *"${nl}192.168.${new_sub}.0/24${nl}"*)
            ;;
          *)
            sub=$new_sub
            break;
            ;;
          esac
        done
        ;;
      *)
        ;;
    esac

    UUID=`/usr/bin/uuidgen`
    sed -e "s/${orig_sub}/${sub}/g" \
        -e "s,</name>,</name>\n  <uuid>$UUID</uuid>," \
         < %{_datadir}/libvirt/networks/default.xml \
         > %{_sysconfdir}/libvirt/qemu/networks/default.xml
    ln -s ../default.xml %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
    # libvirt saves this file with mode 0600
    chmod 0600 %{_sysconfdir}/libvirt/qemu/networks/default.xml

    # Make sure libvirt picks up the new network defininiton
    mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
    touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-network
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :

%if %{with_vzct}
%post daemon-vzct
/usr/sbin/modprobe vzevent
/bin/systemctl start vz.service >/dev/null 2>&1 ||:
%endif

%post daemon-config-nwfilter
restart_daemon=0
for dfile in %{_datadir}/libvirt/nwfilter/*.xml; do
  sfile=%{_sysconfdir}/libvirt/nwfilter/`basename $dfile`
  if [ ! -f "$sfile" ]; then
    cp "$dfile" "$sfile"
    # libvirt saves these files with mode 600
    chmod 600 "$sfile"
    restart_daemon=1
  fi
done
# Make sure libvirt picks up the new nwfilter defininitons
if [ $restart_daemon -eq 1 ]; then
  mkdir -p %{_localstatedir}/lib/rpm-state/libvirt || :
  touch %{_localstatedir}/lib/rpm-state/libvirt/restart || :
fi

%posttrans daemon-config-nwfilter
if [ -f %{_localstatedir}/lib/rpm-state/libvirt/restart ]; then
    /bin/systemctl try-restart libvirtd.service >/dev/null 2>&1 || :
fi
rm -rf %{_localstatedir}/lib/rpm-state/libvirt || :


%if %{with_qemu}
%pre daemon-driver-qemu
# We want soft static allocation of well-known ids, as disk images
# are commonly shared across NFS mounts by id rather than name; see
# https://fedoraproject.org/wiki/Packaging:UsersAndGroups
getent group kvm >/dev/null || groupadd -f -g 36 -r kvm
getent group qemu >/dev/null || groupadd -f -g 107 -r qemu
if ! getent passwd qemu >/dev/null; then
  if ! getent passwd 107 >/dev/null; then
    useradd -r -u 107 -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  else
    useradd -r -g qemu -G kvm -d / -s /sbin/nologin -c "qemu user" qemu
  fi
fi
exit 0
%endif

%preun client

%systemd_preun libvirt-guests.service

%post client
%systemd_post libvirt-guests.service

%postun client
%systemd_postun libvirt-guests.service

%if %{with_lxc}
%pre login-shell
getent group virtlogin >/dev/null || groupadd -r virtlogin
exit 0
%endif

%files

%files docs
%doc AUTHORS ChangeLog NEWS.rst README README.rst
%doc %{_vpath_builddir}/libvirt-docs/*

%files daemon

%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/

%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd.socket
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlockd-admin.socket
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/sysconfig/virtproxyd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlogd
%config(noreplace) %{_sysconfdir}/sysconfig/virtlockd
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%config(noreplace) %{_prefix}/lib/sysctl.d/60-libvirtd.conf

%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%dir %{_datadir}/libvirt/

%ghost %dir %{_rundir}/libvirt/

%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/images/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/filesystems/
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/boot/
%dir %attr(0711, root, root) %{_localstatedir}/cache/libvirt/


%dir %attr(0755, root, root) %{_libdir}/libvirt/
%dir %attr(0755, root, root) %{_libdir}/libvirt/connection-driver/
%dir %attr(0755, root, root) %{_libdir}/libvirt/lock-driver
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/lockd.so

%{_datadir}/augeas/lenses/libvirtd.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd.aug
%{_datadir}/augeas/lenses/virtlogd.aug
%{_datadir}/augeas/lenses/tests/test_virtlogd.aug
%{_datadir}/augeas/lenses/virtlockd.aug
%{_datadir}/augeas/lenses/tests/test_virtlockd.aug
%{_datadir}/augeas/lenses/virtproxyd.aug
%{_datadir}/augeas/lenses/tests/test_virtproxyd.aug
%{_datadir}/augeas/lenses/libvirt_lockd.aug
%if %{with_qemu}
%{_datadir}/augeas/lenses/tests/test_libvirt_lockd.aug
%endif

%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules

%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/

%attr(0755, root, root) %{_libexecdir}/libvirt_iohelper

%attr(0755, root, root) %{_sbindir}/libvirtd
%attr(0755, root, root) %{_sbindir}/virtproxyd
%attr(0755, root, root) %{_sbindir}/virtlogd
%attr(0755, root, root) %{_sbindir}/virtlockd

%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virtlogd.8*
%{_mandir}/man8/virtlockd.8*
%{_mandir}/man7/virkey*.7*

%files daemon-config-network
%dir %{_datadir}/libvirt/networks/
%{_datadir}/libvirt/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/default.xml
%ghost %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml

%files daemon-config-nwfilter
%dir %{_datadir}/libvirt/nwfilter/
%{_datadir}/libvirt/nwfilter/*.xml
%ghost %{_sysconfdir}/libvirt/nwfilter/*.xml

%files daemon-driver-interface
%config(noreplace) %{_sysconfdir}/sysconfig/virtinterfaced
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%{_datadir}/augeas/lenses/virtinterfaced.aug
%{_datadir}/augeas/lenses/tests/test_virtinterfaced.aug
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced-admin.socket
%attr(0755, root, root) %{_sbindir}/virtinterfaced
%{_libdir}/%{name}/connection-driver/libvirt_driver_interface.so

%files daemon-driver-network
%config(noreplace) %{_sysconfdir}/sysconfig/virtnetworkd
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%{_datadir}/augeas/lenses/virtnetworkd.aug
%{_datadir}/augeas/lenses/tests/test_virtnetworkd.aug
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnetworkd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/networks/autostart
%ghost %dir %{_rundir}/libvirt/network/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/network/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/dnsmasq/
%attr(0755, root, root) %{_libexecdir}/libvirt_leaseshelper
%{_libdir}/%{name}/connection-driver/libvirt_driver_network.so

%if %{with_firewalld_zone}
%{_prefix}/lib/firewalld/zones/libvirt.xml
%endif

%files daemon-driver-nodedev
%config(noreplace) %{_sysconfdir}/sysconfig/virtnodedevd
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%{_datadir}/augeas/lenses/virtnodedevd.aug
%{_datadir}/augeas/lenses/tests/test_virtnodedevd.aug
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnodedevd
%{_libdir}/%{name}/connection-driver/libvirt_driver_nodedev.so

%files daemon-driver-nwfilter
%config(noreplace) %{_sysconfdir}/sysconfig/virtnwfilterd
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%{_datadir}/augeas/lenses/virtnwfilterd.aug
%{_datadir}/augeas/lenses/tests/test_virtnwfilterd.aug
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtnwfilterd
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/nwfilter/
%ghost %dir %{_rundir}/libvirt/network/
%{_libdir}/%{name}/connection-driver/libvirt_driver_nwfilter.so

%if %{with_secret}
%files daemon-driver-secret
%config(noreplace) %{_sysconfdir}/sysconfig/virtsecretd
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%{_datadir}/augeas/lenses/virtsecretd.aug
%{_datadir}/augeas/lenses/tests/test_virtsecretd.aug
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtsecretd
%{_libdir}/%{name}/connection-driver/libvirt_driver_secret.so
%endif

%files daemon-driver-storage

%files daemon-driver-storage-core
%config(noreplace) %{_sysconfdir}/sysconfig/virtstoraged
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%{_datadir}/augeas/lenses/virtstoraged.aug
%{_datadir}/augeas/lenses/tests/test_virtstoraged.aug
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged-admin.socket
%attr(0755, root, root) %{_sbindir}/virtstoraged
%if %{with_storage_misc}
%attr(0755, root, root) %{_libexecdir}/libvirt_parthelper
%endif
%{_libdir}/%{name}/connection-driver/libvirt_driver_storage.so
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_fs.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_fs.so

%if %{with_storage_misc}
%files daemon-driver-storage-disk
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_disk.so

%files daemon-driver-storage-logical
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_logical.so

%files daemon-driver-storage-scsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_scsi.so

%files daemon-driver-storage-iscsi
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi.so

%files daemon-driver-storage-mpath
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_mpath.so
%endif

%if %{with_storage_iscsi_direct}
%files daemon-driver-storage-iscsi-direct
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_iscsi-direct.so
%endif

%if %{with_storage_gluster}
%files daemon-driver-storage-gluster
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_gluster.so
%{_libdir}/%{name}/storage-file/libvirt_storage_file_gluster.so
%endif

%if %{with_storage_rbd}
%files daemon-driver-storage-rbd
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_rbd.so
%endif

%if %{with_storage_sheepdog}
%files daemon-driver-storage-sheepdog
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_sheepdog.so
%endif

%if %{with_storage_zfs}
%files daemon-driver-storage-zfs
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_zfs.so
%endif

%if %{with_storage_vstorage}
%files daemon-driver-storage-vstorage
%{_libdir}/%{name}/storage-backend/libvirt_storage_backend_vstorage.so
%endif

%if %{with_qemu}
%files daemon-driver-qemu
%config(noreplace) %{_sysconfdir}/sysconfig/virtqemud
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%{_datadir}/augeas/lenses/virtqemud.aug
%{_datadir}/augeas/lenses/tests/test_virtqemud.aug
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud-admin.socket
%attr(0755, root, root) %{_sbindir}/virtqemud
%dir %attr(0700, root, root) %{_sysconfdir}/libvirt/qemu/
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/qemu/
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%if 0%{?_aci_build:1}
    %exclude %{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%else
    %dir %attr(0700, root, root) %{_sysconfdir}/libvirt/hooks/qemu.d/
    %{_sysconfdir}/libvirt/hooks/qemu.d/50-virtuozzo.py
%endif
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.qemu
%ghost %dir %{_rundir}/libvirt/qemu/
%{_datadir}/augeas/lenses/libvirtd_qemu.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_qemu.aug
%{_libdir}/%{name}/connection-driver/libvirt_driver_qemu.so
%dir %attr(0711, root, root) %{_localstatedir}/lib/libvirt/swtpm/
%dir %attr(0711, root, root) %{_localstatedir}/log/swtpm/libvirt/qemu/
%{_bindir}/virt-qemu-run
%{_mandir}/man1/virt-qemu-run.1*
%endif

%if %{with_lxc}
%files daemon-driver-lxc
%config(noreplace) %{_sysconfdir}/sysconfig/virtlxcd
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%{_datadir}/augeas/lenses/virtlxcd.aug
%{_datadir}/augeas/lenses/tests/test_virtlxcd.aug
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtlxcd
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/lxc/
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.lxc
%ghost %dir %{_rundir}/libvirt/lxc/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/lxc/
%{_datadir}/augeas/lenses/libvirtd_lxc.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_lxc.aug
%attr(0755, root, root) %{_libexecdir}/libvirt_lxc
%{_libdir}/%{name}/connection-driver/libvirt_driver_lxc.so
%endif

%if %{with_libxl}
%files daemon-driver-libxl
%config(noreplace) %{_sysconfdir}/sysconfig/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%{_datadir}/augeas/lenses/virtxend.aug
%{_datadir}/augeas/lenses/tests/test_virtxend.aug
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend-admin.socket
%attr(0755, root, root) %{_sbindir}/virtxend
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.libxl
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%{_datadir}/augeas/lenses/libvirtd_libxl.aug
%{_datadir}/augeas/lenses/tests/test_libvirtd_libxl.aug
%dir %attr(0700, root, root) %{_localstatedir}/log/libvirt/libxl/
%ghost %dir %{_rundir}/libvirt/libxl/
%dir %attr(0700, root, root) %{_localstatedir}/lib/libvirt/libxl/
%{_libdir}/%{name}/connection-driver/libvirt_driver_libxl.so
%endif

%if %{with_vbox}
%files daemon-driver-vbox
%config(noreplace) %{_sysconfdir}/sysconfig/virtvboxd
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%{_datadir}/augeas/lenses/virtvboxd.aug
%{_datadir}/augeas/lenses/tests/test_virtvboxd.aug
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvboxd
%{_libdir}/%{name}/connection-driver/libvirt_driver_vbox.so
%endif

%if %{with_vz}
%files daemon-driver-vz
%{_libdir}/%{name}/connection-driver/libvirt_driver_vz.so
%config(noreplace) %{_sysconfdir}/sysconfig/virtvzd
%config(noreplace) %{_sysconfdir}/libvirt/virtvzd.conf
%{_datadir}/augeas/lenses/virtvzd.aug
%{_datadir}/augeas/lenses/tests/test_virtvzd.aug
%{_unitdir}/virtvzd.service
%{_unitdir}/virtvzd.socket
%{_unitdir}/virtvzd-ro.socket
%{_unitdir}/virtvzd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvzd
%endif

%if %{with_vzct}
%files daemon-driver-vzct
%defattr(-, root, root)
%{_libdir}/%{name}/connection-driver/libvirt_driver_vzct.so
%config(noreplace) %{_sysconfdir}/sysconfig/virtvzctd
%config(noreplace) %{_sysconfdir}/libvirt/virtvzctd.conf
%{_datadir}/augeas/lenses/virtvzctd.aug
%{_datadir}/augeas/lenses/tests/test_virtvzctd.aug
%{_unitdir}/virtvzctd.service
%{_unitdir}/virtvzctd.socket
%{_unitdir}/virtvzctd-ro.socket
%{_unitdir}/virtvzctd-admin.socket
%attr(0755, root, root) %{_sbindir}/virtvzctd
%endif

%if %{with_qemu_tcg}
%files daemon-qemu
%endif

%if %{with_qemu_kvm}
%files daemon-kvm
%endif

%if %{with_lxc}
%files daemon-lxc
%endif

%if %{with_libxl}
%files daemon-xen
%endif

%if %{with_vbox}
%files daemon-vbox
%endif

%if %{with_vz}
%files daemon-vz
%endif

%if %{with_vzct}
%files daemon-vzct
%defattr(-, root, root)
%endif

%if %{with_sanlock}
%files lock-sanlock
    %if %{with_qemu}
%config(noreplace) %{_sysconfdir}/libvirt/qemu-sanlock.conf
    %endif
    %if %{with_libxl}
%config(noreplace) %{_sysconfdir}/libvirt/libxl-sanlock.conf
    %endif
%attr(0755, root, root) %{_libdir}/libvirt/lock-driver/sanlock.so
%{_datadir}/augeas/lenses/libvirt_sanlock.aug
%{_datadir}/augeas/lenses/tests/test_libvirt_sanlock.aug
%dir %attr(0770, root, sanlock) %{_localstatedir}/lib/libvirt/sanlock
%{_sbindir}/virt-sanlock-cleanup
%{_mandir}/man8/virt-sanlock-cleanup.8*
%attr(0755, root, root) %{_libexecdir}/libvirt_sanlock_helper
%endif

%files client
%{_mandir}/man1/virsh.1*
%{_mandir}/man1/virt-xml-validate.1*
%{_mandir}/man1/virt-pki-validate.1*
%{_mandir}/man1/virt-host-validate.1*
%{_bindir}/virsh
%{_bindir}/virt-xml-validate
%{_bindir}/virt-pki-validate
%{_bindir}/virt-host-validate

%{_datadir}/systemtap/tapset/libvirt_probes*.stp
%{_datadir}/systemtap/tapset/libvirt_functions.stp
%if %{with_qemu}
%{_datadir}/systemtap/tapset/libvirt_qemu_probes*.stp
%endif

%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virsh
%endif


%{_unitdir}/libvirt-guests.service
%config(noreplace) %{_sysconfdir}/sysconfig/libvirt-guests
%attr(0755, root, root) %{_libexecdir}/libvirt-guests.sh

%files libs -f %{_vpath_builddir}/%{name}.lang
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%{_libdir}/libvirt.so.*
%{_libdir}/libvirt-qemu.so.*
%{_libdir}/libvirt-lxc.so.*
%{_libdir}/libvirt-admin.so.*
%dir %{_datadir}/libvirt/
%dir %{_datadir}/libvirt/schemas/
%dir %attr(0755, root, root) %{_localstatedir}/lib/libvirt/

%{_datadir}/libvirt/schemas/domainblockexport.rng
%{_datadir}/libvirt/schemas/domainblocksnapshot.rng
%{_datadir}/libvirt/schemas/basictypes.rng
%{_datadir}/libvirt/schemas/capability.rng
%{_datadir}/libvirt/schemas/cputypes.rng
%{_datadir}/libvirt/schemas/domain.rng
%{_datadir}/libvirt/schemas/domainbackup.rng
%{_datadir}/libvirt/schemas/domaincaps.rng
%{_datadir}/libvirt/schemas/domaincheckpoint.rng
%{_datadir}/libvirt/schemas/domaincommon.rng
%{_datadir}/libvirt/schemas/domainsnapshot.rng
%{_datadir}/libvirt/schemas/interface.rng
%{_datadir}/libvirt/schemas/network.rng
%{_datadir}/libvirt/schemas/networkcommon.rng
%{_datadir}/libvirt/schemas/networkport.rng
%{_datadir}/libvirt/schemas/nodedev.rng
%{_datadir}/libvirt/schemas/nwfilter.rng
%{_datadir}/libvirt/schemas/nwfilter_params.rng
%{_datadir}/libvirt/schemas/nwfilterbinding.rng
%{_datadir}/libvirt/schemas/secret.rng
%{_datadir}/libvirt/schemas/storagecommon.rng
%{_datadir}/libvirt/schemas/storagepool.rng
%{_datadir}/libvirt/schemas/storagepoolcaps.rng
%{_datadir}/libvirt/schemas/storagevol.rng

%{_datadir}/libvirt/cpu_map/*.xml

%{_datadir}/libvirt/test-screenshot.png

%files admin
%{_mandir}/man1/virt-admin.1*
%{_bindir}/virt-admin
%if %{with_bash_completion}
%{_datadir}/bash-completion/completions/virt-admin
%endif

%if %{with_bash_completion}
%files bash-completion
%{_datadir}/bash-completion/completions/vsh
%endif

%if %{with_wireshark}
%files wireshark
%{wireshark_plugindir}/libvirt.so
%endif

%files nss
%{_libdir}/libnss_libvirt.so.2
%{_libdir}/libnss_libvirt_guest.so.2

%if %{with_lxc}
%files login-shell
%attr(4750, root, virtlogin) %{_bindir}/virt-login-shell
%{_libexecdir}/virt-login-shell-helper
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%{_mandir}/man1/virt-login-shell.1*
%endif

%files devel
%{_libdir}/libvirt.so
%{_libdir}/libvirt-admin.so
%{_libdir}/libvirt-qemu.so
%{_libdir}/libvirt-lxc.so
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/libvirt-domain-backup.h
%{_includedir}/libvirt/virterror.h
%{_includedir}/libvirt/libvirt.h
%{_includedir}/libvirt/libvirt-admin.h
%{_includedir}/libvirt/libvirt-common.h
%{_includedir}/libvirt/libvirt-domain.h
%{_includedir}/libvirt/libvirt-domain-checkpoint.h
%{_includedir}/libvirt/libvirt-domain-snapshot.h
%{_includedir}/libvirt/libvirt-event.h
%{_includedir}/libvirt/libvirt-host.h
%{_includedir}/libvirt/libvirt-interface.h
%{_includedir}/libvirt/libvirt-network.h
%{_includedir}/libvirt/libvirt-nodedev.h
%{_includedir}/libvirt/libvirt-nwfilter.h
%{_includedir}/libvirt/libvirt-secret.h
%{_includedir}/libvirt/libvirt-storage.h
%{_includedir}/libvirt/libvirt-stream.h
%{_includedir}/libvirt/libvirt-qemu.h
%{_includedir}/libvirt/libvirt-lxc.h
%{_libdir}/pkgconfig/libvirt.pc
%{_libdir}/pkgconfig/libvirt-admin.pc
%{_libdir}/pkgconfig/libvirt-qemu.pc
%{_libdir}/pkgconfig/libvirt-lxc.pc

%dir %{_datadir}/libvirt/api/
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml


%changelog
* Thu Jul 22 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.16
- qemu: fix refreshing of restored VM #PSBM-132173 [upstream]

* Thu Jul 22 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.15
- FIXUP: qemu: use def arg in qemuDomainTmpSnapshotFindDisks
- FIXUP: qemu: factor out qemuDomainTmpSnapshotIsPresentInactive
- FIXUP: allow non-disk changes on defineXML with tmp snapshot #VSTOR-45247

* Thu Jul 22 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.14
- FIXUP: qemu: support setting net params thru prl_nettool #PSBM-129743
- qemu: support changing net params #PSBM-129743
- FIXUP: qemu: setting q35 in hook
- FIXUP: setting misc win features
- FIXUP: enhance error message macros
- vzct 2: support volumes in define/undefine/stats #PSBM-128811
- vzct 2: support volumes on start/stop #PSBM-128811
- FIXUP: vzct 2: intoroduce vzctDomainDefCopy
- vzct 2: store disk uuids in snapshot metadata
- conf: virDomainSnapshotDefParse allow NULL @current
- vzct 2: support volumes for snapshot API #PSBM-128811
- FIXUP: vzct 2: prepare cookie to add more parts
- vzct 2: add destination pool info to migration cookie
- vzct 2: migration: check storage pool alignment on src and dest
- vzct 2: support volumes on migration #PSBM-128811
- vzct 2: skip actions on libvzctl config after migration completed
- Save state of guest tools autoupdate in domain metadata #PSBM-129617

* Tue Jul 20 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.13
- qemu: introduce qemuDomainCreateImage
- FIXUP: vstorage migration: main patch #PSBM-106202
- FIXUP: api/qemu: add move nvram API
- FIXUP: vstorage migration
- FIXUP: moving bitmaps on snapshot

* Mon Jul 19 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.12
- PSBM-130505 enable hv-evmcs/hv-stimer-direct in domain xml for Windows guests with nested virtualization. PSBM-130504  enable hv-tlbflush, hv-ipi, hv-frequencies in domain xml for Windows guests

* Thu Jul 15 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.11
- FIXUP: conf: add format attribute to domain/os/nvram element

* Mon Jul 12 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.10
- FIXUP:  vzct 2: add basic structure and listing #PSBM-131697

* Fri Jul 09 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.9
- FIXUP: qemu: extract private exec commands #PSBM-129743
- conf: add 'vz-dhcp' parameter to xml #PSBM-129743
- qemu: support setting net params thru prl_nettool #PSBM-129743
- qemu: keep 'netConfigApplied' in status file #PSBM-129743
- qemu: validate that route is default gateway #PSBM-129743

* Thu Jul 08 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.8
- FIXUP: api/qemu: introduce hv-vss freeze/thaw #PSBM-131374

* Wed Jul 07 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.7
- FIXUP: mark explicit backing more generically #VSTOR-43957
- FIXUP: fix resetting explicit backing whithout persistent conf
- vstorage migration: support explicit backing
- FIXUP: allow migration with explicit backing
- FIXUP: remove virDomainDefMarkExplicitBacking symbol

* Tue Jul 06 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.6
- vzct: support rename #PSBM-131350

* Fri Jul 02 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.5
- qemu: add hook on define #PSBM-130792
- qemu: add virtuozzo specific hook on define
- qemu vz hook: set machine type q35

* Fri Jul 02 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.4
- FIXUP: qemu: wait indefinetly when acquiring job condition in event handlers

* Thu Jul 01 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.3
- FIXUP: nwfilter: add vz specific filters #PSBM-131286
- FIXUP: example: add ipv6 filters examples

* Thu Jul 01 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.2
- conf: remove static from virDomainDefSetMetadata
- FIXUP: vzct: Support disk resize for active CT
- vzct: support getting/setting metadata #PSBM-131257

* Thu Jul 01 2021 Nikolay Shirokovskiy <nshyrokovskiy@gmail.com> - vz-6.6.0-13.2.vz8.1
- src: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- libxl: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- qemu: adopt to VIR_DRV_SUPPORTS_FEATURE return -1
- src: don't hide error in VIR_DRV_SUPPORTS_FEATURE
- qemu: build fix for 910b94df
- src: fix resource leak introduced in d4439a6b8
- vz: fixes after renaming Parallels to Virtuozzo in sdk
- backport fixup: remote: implement virDomainGetGuestInfo
- make check: fix when lxc is turned off
- iohelper: truncate large chunks on write #PSBM-70840
- Added new flag VIR_DOMAIN_CREATE_USER
- conf: tune connection parameters for Virtuozzo #PSBM-92128
- Set LimitCORE=infinity in libvirtd.service
- conf: add 'format' attribute to domain/os/nvram element
- qemu: don't pause vm when creating internal snapshot
- vz: use /etc/machine-id as host uuid
- qemu: log: log monitor events by default
- relax network adapter config checking (bug #PSBM-54596 fix)
- qemu: v2 fix reboot scenario (bugs #PSBM-41956 #PSBM-54756 fix)
- vz: set virtio as default network model
- qemu: fix crash on getting block stats for empty cdrom
- vz: rework the way we get perfomance counters
- vz: use cached statistics for a predefined period
- vz: don't subscribe to perfomance counters
- vz: cleanup: delete unused constant definition
- vz: don't create driver object during daemon initialization
- conf/qemu: add hv-scsi model to scsi controllers
- vz: add domain name info in error message
- qemu: simplify graphics port releasing
- upgrade: support local p2p migration
- object: add shared lock option to lockable
- upgrade: initial implementation
- upgrade: don't show events from not face process
- upgrade: start target domain with source id
- cgroup: use id+generation for machine cgroup name if last is not 0
- upgrade: fix id clashes for domain private paths etc
- conf: accept path in virDomainSaveXML
- upgrade: store generation in status file
- dom list: refactor: reuse code in find functions
- upgrade: return face domain from domlist
- migration: support --release-ram
- migration: add --postcopy-start to start postcopy immediately
- upgrade: virtlogd: handle output for one path from 2 qemu
- upgrade: pass live config to target
- upgrade: don't generate seclabel again on upgrade
- upgrade: handle auto generated char dev unix paths
- upgrade: vnc: do not regenerate graphics for target process
- upgrade: vnc: factor out building vnc opts
- upgrade: vnc: make vnc upgrade possible
- upgrade: vnc: keep vnc state across upgrade
- upgrade: tap: use multiqueue to make upgrade possible
- upgrade: tap: don't regenerate name on upgrade
- upgrade: network iface: keep actual net
- upgrade: snapshots: support snapshots
- upgrade: don't assign dev aliases on upgrade
- qemu: drop acquiring job condition on removing vm from list
- qemu: fix one more race on undefining and create
- upgrade: restart pending jobs after upgrade
- upgrade: fix domain lookup in old face removing phase
- upgrade: make correct reconnection of upgrade
- upgrade: set used ports only for face
- upgrade: support for server backends for serial chardevs
- qemu.conf: set upper limit for vnc/spice ports to 6900
- upgrade: don't reject upgrade if hostname is localhost
- qemu: wait indefinetly when acquiring job condition in event handlers
- upgrade: close agent channel befor postcopy with release ram
- upgrade: use unique name for pidfiles across upgrades
- qemu: remove time limit on waiting qemu disappearence on EOF
- qemu: add vmbus-bridge device if hv-scsi present
- qemu: agent: stop io loop effectively on eof or error
- upgrade: fix crash if vm newdef is empty
- libvirtd: tune OOMScoreAdjust
- qemu: revert fb2cd32c
- daemon: finish threads on close
- qemu: monitor: check monitor not closed on send
- qemu: implement state driver shutdown function
- vz: remove domain uuid check on migration #PSBM-43767
- qemu: support hv-net interface models
- nwfilter: fix deadlock on firewalld restart/reload
- vz: allow to start vz driver without host cache info
- qemu: snapshot: revert upstream 9e2465834 #PSBM-76749
- api qemu: add block pull compress option #PSBM-73618
- qemu: include nvram into offline snapshots
- qemu: fail making internal snapshots with non qcow2 nvram
- util: virFDStreamConnectUNIX: add missing error report
- util: add 30s connection timeout to virFDStreamConnectUNIX
- qemu: use job to make domain responsive on qemuDomainOpenChannel
- qemu: wait qemu death indefinetely on domain stop #PSBM-70541
- pull: api: add API for pull (external) backups
- pull: api: add driver based implementation
- pull: remote: add pull backup API implementation
- pull: qemu: monitor: add commands for backup
- pull: conf: add block snapshot format/parse
- pull: virsh: add block snapshot create/delete
- qemu: store guest visible disk size from qemu monitor block info
- qemu: add option to handle inactive blockjobs to cancel op
- util: hash: add misc functions
- pull: conf: add block snaphots to status file
- pull: qemu: block snapshots basic implementation
- pull: qemu: support disks quiesce
- pull: qemu: add block snapshots listing
- pull: qemu: support block snapshot dumpxml
- pull: qemu: monitor: add cmd to delete nbd export
- pull: conf: add export conf def/parsing
- pull: qemu: implement export start/stop
- pull: qemu: don't delete snapshot while disks are exported
- util: hash: remove const from value in kv pair type
- pull: add autodelete option for creating block snapshots #VSTOR-22687
- pull: stop exporting snapshot on snapshot autodelete
- pull: add backcompat capabilities
- pull: qemu: monitor: add bitmap commands
- pull: pull: add dirty bitmap on creating snapshot
- pull: add command to remove checkpoint
- pull: qemu: remove checkpoint on autodelete
- pull: qemu: load bitmaps on domain start
- pull: qemu: monitor: add command to export bitmap
- pull: export bitmap
- pull: migrate checkpoints
- pull: qemu: validate snapshot name
- pull: qemu: add exportable paused start
- pull: add TLS to block export
- pull: add relaxng
- pull: add autoport on export
- qemu: add unmap stats to all domain stats
- api,qemu: add latency histogram
- hubapi: remote: implement listing domains
- hubapi: remote: support domain- API calls
- hubapi: remote: support domain lookup functions
- hubapi: remote: support {create,define}xml API
- hubapi: remote: support domain events
- hubapi: remote: support virConnectGetCapabilities
- hubapi: remote: return vz connection type if vz is in hub
- hubapi: remote: return vz connection type if vzct is in hub
- hubapi: find appropriate connection for domain xml #VZOS-1704
- vz: add option to resize filesystems thur virDomainBlockResize
- vz: support virDomainGetBlockInfo in driver
- api/qemu: introduce hv-vss freeze/thaw
- pull: disable risky cases with RW NBD exports
- qemu: fix attach/detach char devices to use guest device id
- conf: remove none console target type check from  virDomainDefAddConsoleCompat
- conf: remove none console target type check from virDomainDefFormatInternal
- conf: remove none console target type check from virDomainSkipBackcompatConsole
- qemu: update compat console on attach first serial device
- qemu: support updating backend of serial device
- pull: qemu: add option to export last checkpoint
- portallocator: print warn on releasing not used port
- netlink: remove watch before closing fd
- qemu: monitor: set error flag even in OOM conditions
- utils: export virCopyError
- qemu: fix domain object wait to handle monitor errors
- qemu: fix races in beingDestroyed usage
- lib: provide error message in new blockjob event
- qemu: agent: incapsulate vm reference management
- qemu: agent: remove unconvinient destroy callback
- qemu: agent: factor out code to open channel
- qemu: agent: remove useless signalling
- qemu: agent: do not take moninor ref in IO callback
- qemu: agent: remove qemuAgentNotifyCloseLocked
- qemu: agent: don't retry first sync message if monitor closed
- qemu: agent: better error message for disconnected agent
- qemu: agent: give same message on monitor errors
- qemu: agent: move monitor error check to better place
- qemu: domain: add name arg to qemuFindAgentConfig
- qemu: agent: prepare serial event handler for aux channel
- rpc: support multiple streams on client side
- rpc: fix to support multiple streams
- rpc: close stream on receive errors
- rpc: pass original stream recv/send error
- qemu: add exec with true streams
- tools: stop event loop before closing connection
- virsh: don't print \n footer for x-exec
- pull: fix visible NULL entries in block snapshot hash
- misc: remove some invalid G_GNUC_WARN_UNUSED_RESULT
- nwfilter: use vfork to fasten spawn of {ip,eb]tables commands
- pci: more verbose error in virPCIGetDeviceAddressFromSysfsLink
- daemon: purge logs for domains removed more than month ago
- remote: fix SIGSEGV on closing client connection
- pull: don't destroy vm if it has block snapshots or exports
- qemu: destroy domain on monitor EOF anyway
- pull: log merge/rename bitmap operations
- api/qemu: add move nvram API
- qemu: add option to update disk copy_on_read live #VSTOR-10895
- qemu: add qcow2 cache size policy
- tools: move virshGetEscapeChar to utils
- syms: add virStringListCopy to private syms
- virsh: support in, err, out as regular files
- qemu: support interactive exec #PSBM-91739
- qemu: remove sanity check in qemuMonitorJSONDiskNameLookupOne
- exec: provide tty params on exec when possible
- rpc: allow comments in prototol description
- remote: leave stub comment for 16/virDomainGetOSInfoX
- libvirt: add new virDomainCommandXSetParams API
- exec: handle client window size change when interactive
- qemu: add hci value (128MiB) to qcow2 disk cache policy
- upgrade: handle firewall rules #PSBM-90137
- qemu: caps: invalidate kvm capable qemu binaries on every restart #PSBM-88418
- cgroup: blacklist criu temporary mounts #PSBM-90471
- qemu: imply qcow2 format for backing store if not set
- rpc: client: fix race on stream error and stream creation
- exec: virsh: support redirection to special chardevs #PSBM-91601
- exec: restore std streams' flags on become foreground #PSBM-91602 #PSBM-93755
- rpc: client: stream: notify streams of closing connection
- Revert: log: actually do substring matches with fnmatch #PSBM-92872
- pull: clean autodelete snapshots on daemon restart
- qemu: agent: add code -2 when guest exec pid  not found
- qemu: don't wait job in cleanup thread
- exec: kill orphans on client disconnect #PSBM-91329 #VSTOR-17959
- exec: kill orphans on migration destination #PSBM-91329 #VSTOR-17959
- qemu: seccomp: don't turn it on by default #PSBM-93004
- qemu: ignore disabled arch-facilities in configs #PSBM-92991
- qemu: support explicit disk backing in input #VSTOR-21806 #VSTOR-21934
- logging: remove watch before closing fd in virLogHandlerLogFileFree #PSBM-93003
- qemu: don't log error for disk sources not supporting getting offline stats (nbd)
- qemu: don't log error when monitor EOF is expected #PSBM-93003
- qemu: agent: don't log error when monitor EOF is expected
- qemu: agent aux: don't log error when monitor EOF is expected
- qemu: qemuBlockDiskDetectNodes: get name if one is known
- backup: copy bitmaps to top image on snapshot
- virDomainObjListAddObjLocked: Don't expect vm->def to be set
- virDomainObjListAddLocked: Set vm->def only in success path
- virDomainObjListAdd: Leave def assigning as an exercise for caller
- virDomainObjListAdd: Remove unused flag
- qemu: Grab modify job for changing domain XML
- qemu_domain: Allow qemuDomainObjListAdd to keep job upon return
- qemu: release job on cleanup path
- qemu: snapshot revert: reuse common cleanup code
- qemu: support snapshots done with Vz downstream patches
- schema: snapshot: add persistent domain config
- docs: add persistent config to snapshot xml description
- conf: snapshot: check domain name on redefine
- conf: snapshot: support persistent config on redefine
- qemu: add option to close cdrom tray #PSBM-95870
- conf: remove features unknown to qemu (related to #PSBM-96228)
- agent: increase default timeout from 5s to 30s #PSBM-97240
- qemu: introduce qemuDomainChrSerialTargetModel
- conf: add debugcon chardev guest interface
- qemu: make irq optional when formatting the ISA address
- qemu: implement debugcon chardev
- qemu: autoadd iobase to debugcon chardev
- api/qemu: add pause/resume for blockjobs
- qemu: agent: log total tx/rx for streams
- debug: print 'thr a a bt' in log when taking some mutex takes much time
- qemu: monitor: throttle logging BLOCK_IO_ERROR events #VSTOR-26657
- qemu: ignore delayed EOF events from previous VM incarnations #ABR-243123
- qemu: don't fail pausing block job if it is missing #VSTOR-21176
- qemu: migration: implement shared workaround #VSTOR-11398
- conf: handle empty string in interface target name #PSBM-97765
- conf: add replug option for usb hostdev
- qemu: track hostdev delete intention
- qemu: support host usb device unplug
- qemu: support usb hostdev plugging back
- qemu: handle host usb device add/del udev events
- qemu: handle libvirtd restart after host usb device unplug
- qemu: handle race on device deletion and usb host device plugging
- qemu: hotplug: update device list on device deleted event
- qemu: handle host usb device plug/unplug when libvirtd is down
- qemu: don't mess with non mandatory hostdevs on reattaching
- qemu: handle detaching of unplugged hostdev
- conf: parse hostdev missing flag
- backup: don't keep bitmaps in base image on snapshots #VSTOR-23605
- backup: copy bitmaps down on active block commit #VSTOR-23605
- qemu: support new qemu without nbd-server-add-bitmap command #VSTOR-27428
- fix for "virDomainObjListAdd: Leave def assigning as an exercise for caller" #PSBM-98834
- qemu: handle storage/virtlogd hanging #VSTOR-27947
- qemu: add option to process offloaded legacy blockjob event ealier #PSBM-121858
- qemu: reconnect: precreate legacy blockjobs
- qemu: remove extra block job finalize on reconnect
- qemu: remove stale cleanup in qemuProcessRefreshLegacyBlockjob
- qemu: add note for outdated legacy block job events
- qemu: use autoptr in qemuProcessRefreshLegacyBlockjobs
- qemu: refresh backing chain after block job reconnection
- qemu: move code that depends on backing chain appropriately
- qemu: fix race on legacy block completion and quering stats
- qemu: sync backing chain update and completed blockjob #VSTOR-28575 #VSTOR-34322
- qemu: support 'preserve' option for 'on_poweroff'
- qemu: add reconnect params for nbd network disks #VSTOR-28845
- netdaemon: fix deadlock on stopping libvirtd when VM is starting #VSTOR-29392
- qemu: kill partially started domain immediately on reconnect #VSTOR-29393
- qemu: migration: log keep alive message during migration #PSBM-99571
- qemu: disable snapshot explicitly when block snapshot is in progress #VSTOR-29840
- make: add flags to configure sanitizer
- asan: workaround sanitizer issues with clone(2)
- asan: configure to coredump on signals
- hubapi: workaround virURIFormat degradation in vz8
- qemu: adopt nodename detection to backup filter node
- qemu: adopt latency impl to new qemu #PSBM-97535
- qemu: turn on keep alive for nbd disk migration #PSBM-97768
- docker: First implementation of libvirt Docker driver #PSBM-102978
- conf: add more options to save config filename
- conf: allow NULL callback in virDomainObjListRename
- conf: support extra id in domain list
- vzct 2: add basic structure and listing
- virsystemd: workaround race on systemd-machined idle shutdown #PSBM-102137
- rpc: add timeout on connection #VSTOR-32643
- docker: add lookup API impl #PSBM-102978
- docker: implementation control methods for domain #PSBM-103311
- docker: extend types of HTTP request #PSBM-103311
- docker: correct POST HTTP request #PSBM-103381
- docker: add special label with libvirt uuid in container config #PSBM-103381
- conf: support light vcpus and unlimitied number
- vzct 2: support dumpxml
- docker: add 'template' source type #PSBM-103381
- vzct 2: implement define
- vzct 2: implement start/stop
- docker: implementation of XML methods for libvirt driver #PSBM-103381
- docker: cleanup code for hypervisor driver #PSBM-104003
- hasfix: docker: look up by hash-id with leading zero #PSBM-104003
- docker: implementation of stats methods #PSBM-104003
- hasfix: docker: look up by name #PSBM-104003
- docker: cleanup code #PSBM-104003
- vzct 2: support vnc #PSBM-104068
- vzct 2: support cloud init cdrom #PSBM-104067
- vzct 2: add vzctDomainHasManagedSaveImage stub
- vzct 2: support iolimits #PSBM-104069
- vzct 2: add misc API
- docker: implementation of connectGetAllDomainStats method #PSBM-104003
- docker: cleanup code #PSBM-104537
- docker: changing of type of some objects in XML model #PSBM-104537
- vzct 2: make disk names stable #PSBM-104105
- hasfix: docker: simplification of existing code #PSBM-104537
- vzct 2: support stats API #PSBM-104070
- docker: implementation of network driver #PSBM-104537
- qemu: bring back capabilities from update 14 #PSBM-104797
- docker: Added support for mounting volumes or FSs #PSBM-104538
- qemu: use explicit backing mode only if there is nbd in backing #PSBM-104929
- qemu: optimize qemuOpenFileAs for reads #VSTOR-34701
- Add qemu hook suitable to handle device hotplug/hotunplug #PSBM-104793
- util: add virFileRead function
- conf: moment: remember if name is autogenerated
- vzct 2: support snapshots
- docker: Offline migration of windows container #PSBM-104866
- hasfix: Changes for using define instead of several identical string #PSBM-104866
- docker: Added rename method for driver
- xml: add venet0 network interface type
- vzct 2: support venet0 network interface #PSBM-105548
- qemu: ignore allow_disk_format_probing #PSBM-105558
- upgrade: don't mess with security labels #PSBM-105674
- qemu: pass rememberOwner during update #PSBM-105674
- docker: Add some configuration features for driver #PSBM-106011
- qemu: auto load vhost-vsock module #PSBM-106171
- qemu: make latency work with legacy interface #PSBM-106129
- virsh: handle snapshots with domain state unknown
- util: add means to detect vstorage filesystem
- security: exclude vstorage from labelling #PSBM-105985
- vzct 2: don't try virDomainLookupByID
- qemu: caps: use more precise condition when to use CAP_DAC_OVERRIDE #PSBM-106271
- doc: adopt README.md for Virtuozzo
- docker: first implementation of winrs transport to windows host #PSBM-106275
- docker: basic implementation of storage driver for Windows host #PSBM-106275
- Add new type of storage pool for Windows Storage Spaces (WSS) #PSBM-106275
- docker: full implementation of storage driver for Windows #PSBM-106275
- docker: add method for cloning volume #PSBM-106275
- docker: using common CA certificate for docker and winrm connection #PSBM-106275
- docker: reuse winrm coonnection #PSBM-106278
- docker: forbid access to primordial storage pools #PSBM-106278
- virsh: don't shout if virDomainGetJobInfo is not supported
- vzct 2: save disks uuid in config/status files
- vzct 2: intoduce migration
- conf: add auto mininal memory guarantee mode
- vzct 2: support memory guarantees #PSBM-106482
- docker: unification of source code #PSBM-106989
- docker: common auth certificate for docker and winrm #PSBM-106989
- hasfix: docker: use more correct powershell expressions
- vzct 2: mark supported xml parts in domain/snapshot docs #PSBM-106576
- hasfix: docker: use correct timeouts and subnet value #PSBM-106778
- docker: add support for static IP address #PSBM-106778
- qemu: add vcmmd support #PSBM-106483
- hasfix: using vars for compacting code #PSBM-106778
- qemu: agent: disable blocking calls to agent #PSBM-107669
- vzct 2: add jobs support for everything except migration
- vzct 2: support jobs during migration #PSBM-107444
- vzct 2: drop job on client disconnection during migration
- Changes for support DNS configuration #PSBM-106778
- docker: support DNS configuration #PSBM-106778
- hasfix: Changes for support DNS configuration #PSBM-106778
- docker: rename CA certificate file to ca.pem
- qemu: fix concurrency crash bug in force snapshot revert #PSBM-107833
- vzct 2: add lifecycle events #PSBM-107730
- vzct 2: support getting stats for migration #PSBM-107763
- vzct 2: support aborting domain job API #PSBM-107446
- Fixes for support creation of docker container #PSBM-107933
- logging: read all bytes on EOF in event handler
- logging: fix endless loop on EOF
- docker: Support CPU limits #PSBM-107960
- docker: support wss storage pool for connection capabilibies #PSBM-108203
- docker: support wss volume resizing #PSBM-108203
- vstorage migration: execute src migration cleanup in cleanup thread
- qemu: fix qemuMigrationSrcCleanup to use qemuMigrationJobFinish
- qemu: monitor: bring add/remove fd commands back
- qemu: monitor: add qemuMonitorQueryFdsets function
- qemu: don't leave descriptors in fdsets after process startup #PSBM-108299
- qemu: support file chardev append option on hotplug/change
- qemu: support logfile option on chardev hotplug/change
- qemu: migration: add cookie parts for vstorage chardevs
- logging: close backing file on eof on drain
- qemu: monitor: add option to override backend in qemuMonitorChangeCharDev
- qemu: migration: support changing chardev backend with virtlogd
- logging: handle race on drain and closing in event loop
- logging: allow NULL to inode and offset out args on drain
- qemu: migration: detect shared vstorage chardevs
- vstorage: support migrating with chardevs on vstorage #PSBM-106373
- qemu: add vstorage chardev tmpfile names to status file
- qemu: sync chardevs unplugged status on reconnect
- qemu: cleanup up vstorage chardevs after libvirtd crash
- qemu: drain file chardevs on domain process stop
- Support resources change for libvirt docker driver #PSBM-120736
- vstorage migration: introduce virDomainMigrateVstorageCommit
- vstorage migration: add vstorage snapshot commit phase
- vstorage migration: add vstorage disks info to cookie
- vstorage migration: add vstorage nvram info to cookie
- qemu: add nvram block job support
- qemu: add vstorage snapshot utility functions
- vstorage migration: add vstorage snapshot commit
- vstorage migration: main patch #PSBM-106202
- vstorage migration: support p2p
- vstorage: load bitmaps from base image for tmp snapshot #PSBM-123771
- vstorage migration: track valid temporary snapshot
- vstorage migration: resolve valid tmp snapshot on domain start
- qemu: move restoring after failure to cleanup in qemuDomainDefineXMLFlags
- vstorage migration: disable API that can clash with tmp snapshot
- vstorage migration: keep snapshot info in status
- vstorage migration: add dst cleanup after disconnection
- vstorage migration: determine valid snapshot on crash/disconnections
- qemu: migration: fix missing owner on disconnection cleanup
- qemu: cleanup tmp snapshot #PSBM-106875
- logging: allow max_len=0 to disable log rollover #PSBM-121257
- qemu: support nvram block job on reconnect
- vstorage migration: handle ready state on reconnect for tmp snapshot blockjob
- qemu: add filename to qemuMonitorGetBlockInfo
- vstorage migration: handle completed tmp snapshot commit on reconnect #PSBM-121261
- example: fix typo and formatting
- example: add ipv6 filters examples
- doc: document new filters and not documented ones
- nwfilter: add vz specific filters #PSBM-121477
- docker: add compatibility of validation with current xml scheme #PSBM-121897
- vstorage migration: keep nvram tmp snapshot in status
- vstorage migration: adopt qemuDomainGetStatsOneBlock to tmp snapshot
- vstorage migration: fix active block stats with tmp snapshot #PSBM-121042
- vstorage migration: fix inactive block stats with tmp snapshot #PSBM-121042
- docker: fix condition for list of storage pools #PSBM-120911
- vstorage migration: handle short time EBUSY on commit #PSBM-122012
- qemu: qemuDomainRenameCallback: fix sending false undefined event
- qemu: rename: send events only on success
- qemu: rename: return instead of goto if no cleanup required
- qemu: remove duplicate code for removing remnant files
- qemu: rename: support renaming snapshots directory #PSBM-100720
- qemu: rename: support renaming checkpoints directory
- qemu: update name on reverting from snapshot
- qemu: rename: remove snapshot/checkpoint restriction
- qemu: remove possible garbage left from previous rename/undefine
- docker: Add support autostart feature #PSBM-122024
- docker: Refactoring for future changes #PSBM-122024
- docker: Get list for autostart domains #PSBM-122024
- docker: Set domain as not autostart by default #PSBM-122024
- docker: Add virDomainHasManagedSaveImage method and reboot default action #PSBM-122024
- api: add stub for virDomainBlockCheckpointXSwitch
- api: add VIR_DOMAIN_MEMORY_MIN_GUARANTEE_VZ_AUTO
- tools: support memtune --min-guarantee-auto-vz
- qemu: support min_gurantee in virDomain{Set,Get}MemoryParameters #PSBM-121895
- Fix for possibility to use inituser without initgroup #PSBM-122225
- docker: Fix adding of restart policy #PSBM-122225
- docker: Revert possibility to use cpushares=0 #PSBM-122225
- docker: Fix for correct work with process id #PSBM-122225
- docker: Style fix #PSBM-122225
- docker: Split dockerContainerUpdate to dockerContainerUpdate and dockerContainerUpdateById #PSBM-122225
- docker: Add compatibility with 'virtsh edit' command #PSBM-122225
- vzct 2: support autostarting domains #PSBM-121587
- docker: Don't use case-sensitive comparison #PSBM-122944
- docker: Optimization powershell scripts #PSBM-122944
- docker: Using sscanf with string memory allocation #PSBM-122944
- docker: Fix some error msgs #PSBM-122944
- docker: Add storagePoolLookupByVolume method #PSBM-122944
- docker: Add real refresh metadata for storage pool #PSBM-122944
- qemu: turn on postcopy to migrate bitmaps #PSBM-100171
- qemu: fix guest visible disk id if serial is long #VSTOR-38958
- docker: Refactoring code with default cert path #PSBM-123097
- qemu: fix managed pr-helper tear down on chaning device media #PSBM-123337
- docker: Check existence of image for domain definition and pulling image #PSBM-123097
- docker: Support network bandwidth limits for containers #PSBM-108327
- docker: Use negative value for removing network bandwidth limit #PSBM-108327
- docker: Will set negative value only if it needs #PSBM-108327
- forfix: docker: Set correct type of memory var #PSBM-108327
- docker: We cannot create second network with driver 'null' #PSBM-123794
- docker: Connection docker network to selected windows network adapter #PSBM-123794
- doc: document virsh commands for block snaphots/exports #PSBM-122231
- vz: fix after Parallels to Virtuozzo rename #PSBM-124533
- vstorage: remove build time checks for runtime binaries
- virsh: fix Vstorage support reporting
- exec: don't print errors to stderr #PSBM-124629
- vzct 2: implement exec API #PSBM-106206
- virsh: don't call virDomainGetGuestInfo for vzct interactive exec
- daemon: switch off autoshutdown #VSTOR-40335
- api: fix documentation typo
- misc: add bypass cache flag for block snapshot creation #PSBM-124764
- vzct: Support setting memory for active CT #PSBM-122489
- vzct: Support setting cpu num for active CT #PSBM-122517
- docs: document backup API #PSBM-124261
- vzct: Support setting memory guarantee for active CT #PSBM-122518
- vzct: Support setting IO limits for active CT #PSBM-122519
- tools: treat 'in shutdown' etc as shutdown finished #VSTOR-37835
- qemu: don't error if cannot find disk by alias #PSBM-125811
- qemu: vcmmd support for setting balloon #PSBM-123145
- qemu: better cluster size for tmp deltas on vstorage migration #PSBM-123434
- util: add hanging process debugging #PSBM-126062
- vzct: Support disk resize for active CT #PSBM-122525
- qemu: detect block node names after attaching a disk #VSTOR-40911
- qemu/api: support min_guarantee as fraction of balloon #PSBM-126684
- security: don't restore labels for readonly and shared images on errors
- qemu: fix noisy error for domain with image on readonly FS
- misc: add blockjob type for block snapshot job #PSBM-126433
- qemu: monitor: add qemuMonitorBlockDirtyBitmapRemoveBusy
- util: add virTimeBackOffWaitUnlocked
- backup: qemu: retry bitmap deletion while it is used by nbd #PSBM-126896
- qemu: add qemuMonitorJSONBlockdevDelBusy
- backup: qemu: retry fleece node deletion while it is used by nbd
- vstorage migration: cleanup precreated src tmp deltas #PSBM-123432
- upgrade: drain chardev's pipes #PSBM-108071
- remote: remove unused daemonConfigLoadData
- util: move virConf definition to header
- util: make conf a linked list of configs
- util: add virConfReadDir to read dir of configs
- util: add virConfCheckDuplicates to check for duplicate entries
- remote: remove filename from config error reporting
- remote: read config from libvirtd.d/ too #PSBM-127469
- qemu: read config from qemu.d/ too #PSBM-127469
- security: handle chown EACCES on readonly cifs mount #PSBM-127546
- vzct: add ip address to venet0 schema
- vzct: dump ip info for interfaces #PSBM-106470
- vzct: support setting net interface ips on define
- upgrade: support ethernet net type #PSBM-127606
- qemu: acquire job to handle agent disconnection #PSBM-127753
- nwfilter: don't add symmetric record for policy rule #PSBM-126688
- qemu: notify vcmmd of node/vcpu pinning #PSBM-126679
- qemu: fix restoring label if usb hostdev is detached from host
- qemu: handle usb hostdev on qemu update #PSBM-97288
- qemu: handle timeout on unplugging device on qemu update
- storage: open code storageBackendRedoPloopUpdate
- storage: fix refreshing ploop volumes #PSBM-128810
- forfix: docker: build fix on rebase 5.6.0->6.6.0
- qemu: don't access vm without lock
- qemu: request flat block graph output when possible
- FIXUP: pull: conf: add export conf def/parsing
- TMP: temporary fixes to unblock most of cases
- FIXME: update README
- vzct: support cpumask configuration #PSBM-107822
- vzct: support numatune nodeset configuration #PSBM-107822
- vstorage pools: detect vstorage
- vstorage pools: use external metadata on pool refresh #PSBM-129099
- vstorage pools: use external metadata on volume refresh
- vstorage pools: save metadata on creating volume
- vstorage pools: update metadata on resizing volume
- vstorage volume: delete metadata on deleting volume
- vstorage pools: cleanup outdated metadata
- FIXUP: vstorage pools: use external metadata on volume refresh
- qemu: capabilities: Add capability for the 'copy-mode' arg of 'drive-mirror' command #PSBM-97507
- qemu: use write-blocking copy-mode for mirror commands #PSBM-97507
- FIXUP: qemu: update drive-mirror and blockdev-mirror tests #PSBM-97507
- FIXUP: qemu: don't access vcmmd in session driver #PSBM-130586
- qemu: don't prohibit of cdrom/floppy hot attach/detach #VSTOR-44342
- FIXUP: fix privileged vcmmd patch to build without vcmmd
- vzct: support user alias for devices #PSBM-130985
- FIXUP: qemu: handle host usb device add/del udev events
- security: fix compiler warning
- FIXUP: vzct: support user alias for devices
- MERGE: schema: snapshot: add persistent domain config

* Thu Mar 25 2021 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-13.2.el8
- util: avoid glib event loop workaround where possible (rhbz#1942010)
- util: Move glib event loop workaround to glibcompat (rhbz#1942010)
- glib: Use safe glib event workaround in other event loops (rhbz#1942010)
- src: ensure GSource background unref happens in correct event loop (rhbz#1942010)

* Mon Mar  1 2021 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-13.1.el8
- qemu: don't set interface MTU when managed='no' (rhbz#1924681)

* Thu Jan 21 2021 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-13
- qemu: Fix memstat for (non-)transitional memballoon (rhbz#1918364)

* Thu Jan 14 2021 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-12
- util: validate pcie_cap_pos != 0 in virDeviceHasPCIExpressLink() (rhbz#1901685)

* Wed Dec 16 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-11
- docs: Document SELinux caveats when migrating over UNIX sockets (rhbz#1638889)
- qemu: Tweak debug message for qemuMigrationSrcPerformPeer2Peer3 (rhbz#1638889)
- qemu: Fix possible segfault when migrating disks (rhbz#1638889)
- docs: Slightly alter disks-uri description in virsh man (rhbz#1638889)
- qemu: Extra check for NBD URI being specified (rhbz#1638889)

* Mon Dec 14 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-10
- qemu: use g_autoptr for a virPCIDevice (rhbz#1901685)
- util: simplify calling of virPCIDeviceDetectFunctionLevelReset() (rhbz#1901685)
- util: simplify call to virPCIDeviceDetectPowerManagementReset() (rhbz#1901685)
- util: make read error of PCI config file more detailed (rhbz#1901685)
- util: change call sequence for virPCIDeviceFindCapabilityOffset() (rhbz#1901685)
- util: make virPCIDeviceIsPCIExpress() more intelligent (rhbz#1901685)
- qemu: remove redundant check for file length when determining PCIe vs. PCI (rhbz#1901685)

* Fri Dec 11 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-9
- checkpoint: Mention that VIR_DOMAIN_CHECKPOINT_XML_SIZE may require running vm (rhbz#1874846)
- man: virsh: Mention that '--size' for 'checkpoint-dumpxml' may require running vm (rhbz#1874846)
- error: Introduce VIR_ERR_CHECKPOINT_INCONSISTENT error code (rhbz#1874846)
- qemu: backup: Use VIR_ERR_CHECKPOINT_INCONSISTENT when starting a backup (rhbz#1874846)
- checkpoint: Introduce VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE flag (rhbz#1874846)
- virsh: checkpoint-create: Add support for VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE (rhbz#1874846)
- conf: checkpoint: Split virDomainCheckpointRedefinePrep into two functions (rhbz#1874846)
- qemu: checkpoint: Implement VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE (rhbz#1874846)
- qemu: backup: Add partial validation of incremental backup checkpoint (rhbz#1874846)
- Fix name prefix of VIR_DOMAIN_CHECKPOINT_REDEFINE_VALIDATE (rhbz#1874846)
- virDomainCheckpointDefParse: Don't extract unused domain type (rhbz#1901830)
- virDomainCheckpointDefParse: Use 'unsigned int' for flags (rhbz#1901830)
- virDomainCheckpointRedefineCommit: Don't check ABI of definition in checkpoint (rhbz#1901830)
- conf: checkpoint: Prepare internals for missing domain definition (rhbz#1901830)
- conf: checkpoint: Don't require <domain> when redefining checkpoints (rhbz#1901830)
- qemuDomainCheckpointLoad: Don't align disks when restoring config from disk (rhbz#1901830)
- conf: Rename virCPUDefUpdateFeatureInternal (rhbz#1798004)
- conf: Use enum in virCPUDefAddFeatureInternal (rhbz#1798004)
- conf: Add virCPUDefAddFeatureIfMissing (rhbz#1798004)
- cpu: Run arch specific code for virCPUUpdate for all custom CPUs (rhbz#1798004)
- cpu_x86: Change the flow in virCPUx86Update (rhbz#1798004)
- cpu_x86: Add support for marking features as removed from a CPU model (rhbz#1798004)
- cpu_x86: Make sure removed features are always mentioned in CPU def (rhbz#1798004)
- cpu_map: Drop 'monitor' from modern x86 CPU models (rhbz#1798004)

* Wed Nov  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-8
- vircommand.c: write child pidfile before process tuning in virExec() (rhbz#1882093)
- util: Avoid double free in virProcessSetAffinity (rhbz#1819801)
- util: keep track of full GSource object not source ID number (rhbz#1894045)
- util: avoid crash due to race in glib event loop code (rhbz#1894045)
- qemu: Use g_autofree in qemuMigrationSrcConnect (rhbz#1638889)
- qemu: Rework qemuMigrationSrcConnect (rhbz#1638889)
- virsh: Reuse existing variable when parsing migrate --disks-port (rhbz#1638889)
- qemu: Rework starting NBD server for migration (rhbz#1638889)
- tests: Add simple test for virDomainMigrateCheckNotLocal (rhbz#1638889)
- qemu: Allow NBD migration over UNIX socket (rhbz#1638889)
- peer2peer migration: allow connecting to local sockets (rhbz#1638889)
- qemu: Allow migration over UNIX socket (rhbz#1638889)
- docs: migration: Fix syntax (rhbz#1638889)
- qemu: Don't try to start NBD server twice (rhbz#1638889)

* Mon Oct 12 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-7
- rpc: gendispatch: handle empty flags (CVE-2020-25637)
- rpc: add support for filtering @acls by uint params (CVE-2020-25637)
- rpc: require write acl for guest agent in virDomainInterfaceAddresses (CVE-2020-25637)
- qemu: agent: set ifname to NULL after freeing (CVE-2020-25637)
- Add testdata for AMD EPYC 7502 (rhbz#1861703)
- cpu_map: Defined and enable EPYC-Rome model (rhbz#1861703)
- cputest: Update QEMU data for Ryzen 9 3900X (rhbz#1861703)
- cpu_map: Remove monitor feature from EPYC-Rome (rhbz#1861703)

* Wed Sep 16 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-6
- virDomainHostdevSubsysSCSIiSCSIClear: Inline contents into only caller (rhbz#1876467)
- virDomainStorageNetworkParseHosts: Switch to a more modern XML parsing approach (rhbz#1876467)
- virDomainHostdevSubsysSCSIHostDefParseXML: Switch to a more modern XML parsing approach (rhbz#1876467)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Add hostdev with useralias (rhbz#1876467)
- conf: Add virStorageSource member for SCSI host device config data (rhbz#1876467)
- tests: qemustatusxml2xmldata: Rename 'disk-secinfo-upgrade' case to 'upgrade' (rhbz#1876467)
- tests: qemustatusxml2xmldata: Add local SCSI hostdev to 'upgrade' case (rhbz#1876467)
- qemu: domain: Fill in (i)SCSI backend nodename if it is not present in status XML (rhbz#1876467)
- qemuBuildHostdevSCSI(A|De)tachPrepare: Use virStorageSource in def for SCSI hostdevs (rhbz#1876467)
- qemuBlockStorageSourceAttachData: remove 'storageNodeNameCopy' (rhbz#1876467)
- qemu: domain: Extract preparation of hostdev specific data to a separate function (rhbz#1876467)
- qemuDomainSecretHostdevPrepare: remove (rhbz#1876467)
- qemuDomainPrepareHostdev: Allocate backend nodenames in the prepare function (rhbz#1876467)
- qemuDomainPrepareHostdev: base hostdev secret object names on backend alias (rhbz#1876467)
- qemuDomainPrepareHostdev: Don't base backend nodename on device alias (rhbz#1876467)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Use longer user-alias for SCSI hostdev (rhbz#1876467)
- qemustatusxml2xml: backup-pull: Test private data formatting/parsing (rhbz#1870488)
- qemu: backup: Remove note that TLS should be implemented (rhbz#1870488)
- qemu: backup: Write TLS cert and secret object aliases into status XML (rhbz#1870488)
- qemuxml2argvtest: hostdev-scsi-virtio-scsi: Add <readonly/> to one of the iSCSI hostdevs (rhbz#1868856)
- qemuBuildHostdevSCSIAttachPrepare: Propagate 'readonly' flag also for iSCSI (rhbz#1868856)

* Mon Sep 14 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-5
- qemu: Do not error out when setting affinity failed (rhbz#1819801)
- qemu: Fix comment in qemuProcessSetupPid (rhbz#1819801)
- Do not report error when setting affinity is allowed to fail (rhbz#1819801)
- qemu: Allow setting affinity to fail and don't report error (rhbz#1819801)
- qemu: snapshot: Collect 'query-named-block-nodes' prior to memory migration (rhbz#1862472)
- check for NULL before calling g_regex_unref (rhbz#1876907)
- virsh: cmdScreenshot: fix cbdata passing to virshStreamSink (rhbz#1875195)
- qemu: Do not silently allow non-available timers on non-x86 systems (rhbz#1754887)
- qemuFirmwareFillDomain: Fill NVRAM template on migration too (rhbz#1852910)
- virnuma: Report error when NUMA -> CPUs translation fails (rhbz#1724866)
- virnuma: Use numa_nodes_ptr when checking available NUMA nodes (rhbz#1876956)
- conf: properly clear out autogenerated macvtap names when formatting/parsing (rhbz#1872611)
- util: replace macvtap name reservation bitmap with a simple counter (rhbz#1837395)
- util: assign tap device names using a monotonically increasing integer (rhbz#1837395)
- util: virNetDevTapCreate: initialize fd to -1 (rhbz#1837395)

* Mon Aug 31 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-4
- vircgroupv2devices: fix counting entries in BPF map (rhbz#1833321)
- qemu: fix crash in qemuDomainSetBlkioParameters without cgroups (rhbz#1808293)
- RNG: Allow interleaving of /domain/cpu/numa/cell children (rhbz#1786303)

* Mon Aug 31 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-3
- virdevmapper: Don't cache device-mapper major (rhbz#1867527)
- virdevmapper: Handle kernel without device-mapper support (rhbz#1867527)
- virdevmapper: Ignore all errors when opening /dev/mapper/control (rhbz#1867527)
- numa_conf: Properly check for caches in virDomainNumaDefValidate() (rhbz#1786303)
- virfdstream: Use g_autofree in virFDStreamThreadDoRead() (rhbz#1852528)
- virFDStreamMsgQueuePush: Clear pointer to passed message (rhbz#1852528)
- virfdstream: Use autoptr for virFDStreamMsg (rhbz#1852528)
- virfdstream: Use g_new0() instead of VIR_ALLOC() (rhbz#1852528)
- virfdstream: Use VIR_AUTOCLOSE() (rhbz#1852528)
- virfdstream: Drop some needless labels (rhbz#1852528)
- libvirt-storage: Document volume upload/download stream format (rhbz#1852528)
- virsh: Pass virshStreamCallbackDataPtr to virshStreamSink() and virshStreamSkip() (rhbz#1852528)
- virsh: Track if vol-upload or vol-download work over a block device (rhbz#1852528)
- virshStreamSkip: Emulate skip for block devices (rhbz#1852528)
- virfdstream: Allow sparse stream vol-download (rhbz#1852528)
- virshStreamInData: Handle block devices (rhbz#1852528)
- virfdstream: Emulate skip for block devices (rhbz#1852528)
- virnuma: Don't work around numa_node_to_cpus() for non-existent nodes (rhbz#1860231)

* Wed Aug  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-2
- util: Fix logic in virFileSetCOW (rhbz#1866157)

* Tue Aug  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.6.0-1
- Rebased to libvirt-6.6.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1854372, rhbz#1602328, rhbz#1745059, rhbz#1786303, rhbz#1799010
    rhbz#1814573, rhbz#1821694, rhbz#1822631, rhbz#1829829, rhbz#1840053
    rhbz#1851016, rhbz#1852311, rhbz#1852741, rhbz#1854684, rhbz#1857204
    rhbz#1857735, rhbz#1857967, rhbz#1858260, rhbz#1860875

* Thu Jul  9 2020 Jiri Denemark <jdenemar@redhat.com> - 6.5.0-1
- Rebased to libvirt-6.5.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1432902, rhbz#1634829, rhbz#1640869, rhbz#1739221, rhbz#1823639
    rhbz#1826543, rhbz#1829543, rhbz#1829544, rhbz#1829545, rhbz#1837990
    rhbz#1838975, rhbz#1840307, rhbz#1845012, rhbz#1847234, rhbz#1847259
    rhbz#1847791, rhbz#1849516

* Tue Jun  2 2020 Jiri Denemark <jdenemar@redhat.com> - 6.4.0-1
- Rebased to libvirt-6.4.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1235511, rhbz#1769598, rhbz#1839926, rhbz#1778819, rhbz#1783355
    rhbz#1813306, rhbz#1820040, rhbz#1822878, rhbz#1825785, rhbz#1829550
    rhbz#1832710

* Tue May  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.3.0-1
- Rebased to libvirt-6.3.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1823309, rhbz#1229255, rhbz#1499880, rhbz#1557902, rhbz#1761678
    rhbz#1772838, rhbz#1791522, rhbz#1793705, rhbz#1811906, rhbz#1812100
    rhbz#1812827, rhbz#1813310, rhbz#1820376, rhbz#1821988, rhbz#1822538
    rhbz#1824368, rhbz#1826652, rhbz#1826746

* Fri Apr  3 2020 Jiri Denemark <jdenemar@redhat.com> - 6.2.0-1
- Rebased to libvirt-6.2.0 (rhbz#1809677)
- The rebase also fixes the following bugs:
    rhbz#1460920, rhbz#1591411, rhbz#1727263, rhbz#1750219, rhbz#1781913
    rhbz#1785091, rhbz#1791236, rhbz#1813852, rhbz#1817831, rhbz#1466177
    rhbz#1515677, rhbz#1592273, rhbz#1611061, rhbz#1639596, rhbz#1724928
    rhbz#1784040, rhbz#1793036, rhbz#1810857, rhbz#1812531, rhbz#1813306
    rhbz#1814481, rhbz#1814486, rhbz#1814975, rhbz#1816037, rhbz#1817381
    rhbz#1817955, rhbz#1818030

* Fri Mar 20 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-14
- qemu: Don't crash when getting targets for a multipath (rhbz#1814947)
- virSecretLookupDefCopy: Remove return value (rhbz#1814923)
- virStorageEncryptionSecretCopy: Properly copy internals (rhbz#1814923)
- vmx: shortcut earlier few 'ignore' cases in virVMXParseDisk() (rhbz#1808610)
- vmx: make 'fileName' optional for CD-ROMs (rhbz#1808610)

* Wed Mar 18 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-13
- qemu: Create multipath targets for PRs (rhbz#1814157)

* Tue Mar 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-12
- qemuBlockBitmapsHandleCommitStart: Fix allocation of string list (rhbz#1799013)
- qemuBlockBitmapsHandleCommitFinish: Use proper variable to iterate (rhbz#1799013)
- qemublocktest: Add tests for re-enabling of bitmaps after commit (rhbz#1799013)

* Tue Mar 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-11
- virbuftest: remove extra G_GNUC_UNUSED markers (rhbz#1808499)
- virbuftest: use g_autofree (rhbz#1808499)
- virbuftest: remove unnecessary labels (rhbz#1808499)
- virbuftest: declare testBufAddStrData earlier (rhbz#1808499)
- virbuftest: use field names when initalizing test info (rhbz#1808499)
- util: add virBufferTrimChars (rhbz#1808499)
- conf: do not generate machine names ending with a dash (rhbz#1808499)
- conf: Don't generate machine names with a dot (rhbz#1808499)
- qemuAgentFSInfoFormatParams: Remove pointless returned value (rhbz#1812965)
- qemuDomainGetGuestInfo: Don't try to free a negative number of entries (rhbz#1812965)
- qemuDomainBlockPivot: Move check prior to executing the pivot steps (rhbz#1803092)
- qemuDomainBlockCopyCommon: Record updated flags to block job (rhbz#1803092)
- qemu: capabilities: Introduce QEMU_CAPS_BLOCKDEV_SNAPSHOT_ALLOW_WRITE_ONLY (rhbz#1803092)
- qemu: blockcopy: Allow late opening of the backing chain of a shallow copy (rhbz#1803092)
- qemuBlockStorageSourceDetachPrepare: Get rid of cleanup section (rhbz#1804750)
- qemu: Don't take double pointer in qemuDomainSecretInfoFree (rhbz#1804750)
- qemuMigrationParamsResetTLS: Adapt to modern memory management (rhbz#1804750)
- qemuMigrationParamsResetTLS: Fix comment (rhbz#1804750)
- qemuDomainSecretInfo: Register autoptr cleanup function (rhbz#1804750)
- qemuDomainSecretAESSetup: Automatically free non-secret locals (rhbz#1804750)
- qemuDomainSecretAESSetup: Allocate and return 'secinfo' here (rhbz#1804750)
- qemuDomainSecretAESSetup: Split out lookup of secret data (rhbz#1804750)
- Remove qemuDomainSecretInfoNew (rhbz#1804750)
- qemu: Introduce another helper for creating alias for a 'secret' object (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Fix naming of alias variables (rhbz#1804750)
- qemuDomainDeviceDiskDefPostParseRestoreSecAlias: Hardcode restored aliases (rhbz#1804750)
- qemu: Split out initialization of secrets for 'iscsi' hostdevs (rhbz#1804750)
- qemuDomainSecretAESSetupFromSecret: Use 'qemuAliasForSecret' (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Change aliases for disk secrets (rhbz#1804750)
- qemuDomainGetSecretAESAlias: Replace outstanding uses with qemuAliasForSecret (rhbz#1804750)
- conf: Add support for modifying ssl validation for https/ftps disks (rhbz#1804750)
- conf: Add support for cookies for HTTP based disks (rhbz#1804750)
- conf: Add support for setting timeout and readahead size for network disks (rhbz#1804750)
- qemuDomainValidateStorageSource: Validate new network storage parameters (rhbz#1804750)
- qemuxml2argvtest: Add test case for disks with http(s) source (rhbz#1804750)
- qemu: block: Implement ssl verification configuration (rhbz#1804750)
- qemu: domain: Store data for 'secret' object representing http cookies (rhbz#1804750)
- qemuDomainSecretStorageSourcePrepare: Setup secret for http cookies (rhbz#1804750)
- qemu: Handle hotplug and commandline for secret objects for http cookies (rhbz#1804750)
- qemu: block: Add support for HTTP cookies (rhbz#1804750)
- qemu: block: Implement readahead and timeout properties for 'curl' driver (rhbz#1804750)
- virstoragefile: Add JSON parser for 'sslverify', 'readahead', 'cookies' and 'timeout' (rhbz#1804750)
- virStorageSourceParseBackingJSONUri: Handle undocumented value 'off' for sslverify (rhbz#1804750)
- qemublocktest: Load QMP schema earlier (rhbz#1804750)
- qemublocktest: Extract schema root for blockdev-add validation (rhbz#1804750)
- qemublocktest: XMLjsonXML: Test formatting/parsing of modern JSON (rhbz#1804750)
- qemublocktest: Add JSON->JSON test cases for block device backends (rhbz#1804750)
- qemu: Pass through arguments of 'ssh' block driver used by libguestfs (rhbz#1804750)
- qemu: capabilities: Add QEMU_CAPS_BLOCKDEV_REOPEN (rhbz#1799013)
- qemu: monitor: Add handler for blockdev-reopen (rhbz#1799013)
- qemu: block: implement helpers for blockdev-reopen (rhbz#1799013)
- qemuCheckpointDiscardBitmaps: Reopen images for bitmap modifications (rhbz#1799013)
- qemuCheckpointDiscardBitmaps: Use correct field for checkpoint bitmap name (rhbz#1799013)
- qemuDomainBlockCommit: Move checks depending on capabilities after liveness check (rhbz#1799013)
- qemu: domain: Extract formatting of 'commit' blockjob data into a function (rhbz#1799013)
- qemu: domain: Extract parsing of 'commit' blockjob data into a function (rhbz#1799013)
- qemu: blockjob: Store list of bitmaps disabled prior to commit (rhbz#1799013)
- qemublocktest: Fix and optimize fake image chain (rhbz#1799013)
- qemu: block: Implement helpers for dealing with bitmaps during block commit (rhbz#1799013)
- qemublocktest: Add tests for handling of bitmaps during block-commit (rhbz#1799013)
- qemublocktest: Add more tests for block-commit bitmap handling with snapshots (rhbz#1799013)
- qemublocktest: Add tests of broken bitmap chain handling during block-commit (rhbz#1799013)
- qemuBlockJobDiskNewCommit: Propagate 'disabledBitmapsBase' (rhbz#1799013)
- qemuDomainBlockCommit: Handle bitmaps on start of commit (rhbz#1799013)
- qemuDomainBlockPivot: Handle merging of bitmaps when pivoting an active block-commit (rhbz#1799013)
- qemu: blockjob: Handle bitmaps after finish of normal block-commit (rhbz#1799013)
- qemu: blockjob: Re-enable bitmaps after failed block-commit (rhbz#1799013)
- qemuDomainGetGuestInfo: don't assign NULL hostname (rhbz#1812965)
- rhel: Enable usage of x-blockdev-reopen (rhbz#1799013)

* Tue Mar 10 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-10
- security: Introduce VIR_SECURITY_DOMAIN_IMAGE_PARENT_CHAIN_TOP flag (rhbz#1803551)
- qemu: Tell secdrivers which images are top parent (rhbz#1803551)
- virDomainDiskTranslateSourcePool: Check for disk type correctly (rhbz#1811728)

* Fri Mar  6 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-9
- conf: use virXMLFormatElement in virDomainFSDefFormat (rhbz#1694166)
- qemu: use def instead of vm->def in qemuExtDevicesStart (rhbz#1694166)
- qemu: eliminate ret in qemuExtDevicesStart (rhbz#1694166)
- docs: render class="literal" with monospace font (rhbz#1694166)
- docs: reduce excessive spacing in ToC for RST files (rhbz#1694166)
- virDomainFSDefFree: Unref private data (rhbz#1694166)
- schema: wrap fsDriver in a choice group (rhbz#1694166)
- qemuExtDevicesStart: pass logManager (rhbz#1694166)
- qemu: pass virDomainObjPtr to qemuExtDevicesSetupCgroup (rhbz#1694166)
- qemuxml2xmltest: set driver as privileged (rhbz#1694166)
- qemu: add QEMU_CAPS_DEVICE_VHOST_USER_FS (rhbz#1694166)
- docs: add virtiofs kbase (rhbz#1694166)
- conf: qemu: add virtiofs fsdriver type (rhbz#1694166)
- conf: add virtiofs-related elements and attributes (rhbz#1694166)
- qemu: add virtiofsd_debug to qemu.conf (rhbz#1694166)
- qemu: validate virtiofs filesystems (rhbz#1694166)
- qemu: forbid migration with vhost-user-fs device (rhbz#1694166)
- qemu: add code for handling virtiofsd (rhbz#1694166)
- qemu: put virtiofsd in the emulator cgroup (rhbz#1694166)
- qemu: use the vhost-user schemas to find binary (rhbz#1694166)
- qemu: build vhost-user-fs device command line (rhbz#1694166)
- RHEL: virscsi: Check device type before getting it's /dev node name (rhbz#1808390)
- RHEL: virscsi: Support TAPEs in virSCSIDeviceGetDevName() (rhbz#1808390)
- RHEL: virscsi: Introduce and use virSCSIDeviceGetUnprivSGIOSysfsPath() (rhbz#1808390)
- RHEL: virutil: Accept non-block devices in virGetDeviceID() (rhbz#1808390)
- RHEL: qemuSetUnprivSGIO: Actually use calculated @sysfs_path to set unpriv_sgio (rhbz#1808390)
- RHEL: qemuCheckUnprivSGIO: use @sysfs_path to get unpriv_sgio (rhbz#1808400)

* Thu Mar  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-8
- util: storagefile: Drop image format probing by file suffix (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Remove impossible error report (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Shuffle around assignment of backing chain depth (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Expect NULL src->path (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Use virHashHasEntry instead of fake pointers (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Extract storage access (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Remove 'cleanup' label (rhbz#1798148)
- tests: virstorage: Fix backing file format of created image (rhbz#1798148)
- virStorageSourceUpdateCapacity: Drop 'probe' argument (rhbz#1798148)
- util: storage: Store backing store format in virStorageSource (rhbz#1798148)
- virStorageSourceNewFromBacking: Also transfer the format (rhbz#1798148)
- virStorageBackendGlusterRefreshVol: Refactor handling of backing store (rhbz#1798148)
- virStorageFileGetMetadataFromBuf: Remove 'backingFormat' argument (rhbz#1798148)
- virStorageFileGetMetadataFromFD: Remove unused 'backingFormat' argument (rhbz#1798148)
- qemu: domain: Convert detected 'iso' image format into 'raw' (rhbz#1798148)
- virStorageFileGetMetadataRecurse: Allow format probing under special circumstances (rhbz#1798148)
- kbase: backing_chains: Clarify some aspects of image probing (rhbz#1798148)
- kbase: backing_chains: Add steps how to securely probe image format (rhbz#1798148)

* Tue Feb 25 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-7
- docs: fix a typo (rhbz#1805742)
- virDomainNetDefClear: Free @persistent name (rhbz#1805742)
- virSecurityManagerMetadataLock: Store locked paths (rhbz#1804672)
- security: Don't remember seclabel for paths we haven't locked successfully (rhbz#1804672)
- security: Don't fail if locking a file on NFS mount fails (rhbz#1804672)

* Fri Feb 21 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-6
- qemuBlockStorageSourceGetBackendProps: Report errors on all switch cases (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Sanitize handling of string list (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: use g_new0 instead of VIR_ALLOC_N (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Remove 'cleanup' label (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Remove ternary operator (rhbz#1804603)
- virDomainDiskAddISCSIPoolSourceHost: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateSourcePoolAuth: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateISCSIDirect: Take virStorageSourcePtr instead of virDomainDiskDefPtr (rhbz#1804603)
- virDomainDiskTranslateSourcePool: split code to setup one storage source (rhbz#1804603)
- virDomainDiskTranslateSourcePool: Translate 'volume' disks in whole backing chain (rhbz#1804603)
- qemuMonitorJSONBlockdevAdd: Refactor cleanup (rhbz#1798366)
- qemuMonitorJSONBlockdevDel: Refactor cleanup (rhbz#1798366)
- qemuMonitorBlockdevAdd: Take double pointer argument (rhbz#1798366)
- qemu: hotplug: Fix handling of the 'copy-on-read' layer with blockdev (rhbz#1798366)
- virStorageSourceParseBackingJSON: Pass around original backing file string (rhbz#1791788)
- virStorageSourceParseBackingJSON: Move deflattening of json: URIs out of recursion (rhbz#1791788)
- virStorageSourceJSONDriverParser: annotate 'format' drivers (rhbz#1791788)
- virStorageSourceParseBackingJSON: Allow 'json:' pseudo URIs without 'file' wrapper (rhbz#1791788)
- virStorageSourceParseBackingJSON: Prevent arbitrary nesting with format drivers (rhbz#1791788)
- tests: virstorage: Add test cases for "json:" pseudo-URI without 'file' wrapper (rhbz#1791788)
- qemu: domain: Refactor formatting of node names into status XML (rhbz#1791788)
- docs: formatdomain: Close <source> on one of disk examples (rhbz#1791788)
- tests: virstorage: Add test data for json specified raw image with offset/size (rhbz#1791788)
- util: virstoragefile: Add data structure for storing storage source slices (rhbz#1791788)
- qemuBlockStorageSourceGetFormatRawProps: format 'offset' and 'size' for slice (rhbz#1791788)
- qemuDomainValidateStorageSource: Reject unsupported slices (rhbz#1791788)
- qemu: block: forbid creation of storage sources with <slice> (rhbz#1791788)
- docs: Document the new <slices> sub-element of disk's <source> (rhbz#1791788)
- conf: Implement support for <slices> of disk source (rhbz#1791788)
- qemu: domain: Store nodenames of slice in status XML (rhbz#1791788)
- qemu: block: Properly format storage slice into backing store strings (rhbz#1791788)
- tests: qemublock: Add cases for creating image overlays on top of disks with <slice> (rhbz#1791788)
- qemu: Add support for slices of type 'storage' (rhbz#1791788)
- tests: qemu: Add test data for the new <slice> element (rhbz#1791788)
- virStorageSourceParseBackingJSONRaw: Parse 'offset' and 'size' attributes (rhbz#1791788)
- qemuDomainGetStatsIOThread: Don't leak array with 0 iothreads (rhbz#1804548)
- qemuxml2xmltest: Add case for host-model vendor_id (rhbz#1804549)
- cpu_conf: Format vendor_id for host-model CPUs (rhbz#1804549)
- qemu: rename qemuAgentGetFSInfoInternalDisk() (rhbz#1759566)
- qemu: store complete agent filesystem information (rhbz#1759566)
- qemu: Don't store disk alias in qemuAgentDiskInfo (rhbz#1759566)
- qemu: don't access vmdef within qemu_agent.c (rhbz#1759566)
- qemu: remove qemuDomainObjBegin/EndJobWithAgent() (rhbz#1759566)

* Mon Feb 17 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-5
- qemu: do not revert to NULL bandwidth (rhbz#1800505)
- qemu: preserve error on bandwidth rollback (rhbz#1800505)
- tests: Add capabilities for QEMU 5.0.0 on aarch64 (rhbz#1762634)
- qemu: Use switch statement in qemuBuildCpuCommandLine() (rhbz#1762634)
- qemu: Add the QEMU_CAPS_CPU_KVM_NO_ADJVTIME capability (rhbz#1762634)
- conf: Introduce VIR_DOMAIN_TIMER_NAME_ARMVTIMER (rhbz#1762634)
- qemu: Validate configuration for the armvtimer timer (rhbz#1762634)
- qemu: Format the armvtimer timer on the command line (rhbz#1762634)
- tests: Add test case for the armvtimer timer (rhbz#1762634)
- docs: List the armvtimer timer among all others (rhbz#1762634)
- qemu_domain: Modify access to a NVMe disk iff needed (rhbz#1519005)

* Wed Feb  5 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-4
- qemu: blockcopy: Actually unplug unused images when mirror job fails to start (rhbz#1792195)
- qemu: domain: Extract code to determine topmost nodename to qemuDomainDiskGetTopNodename (rhbz#1792195)
- qemu: Fix value of 'device' argument for blockdev-mirror (rhbz#1792195)
- qemu: Fix value of 'device' argument for block-commit (rhbz#1792195)
- conf: backup: Allow configuration of names exported via NBD (rhbz#1207659)
- qemu: backup: Implement support for backup disk export name configuration (rhbz#1207659)
- qemu: backup: Implement support for backup disk bitmap name configuration (rhbz#1207659)
- util: hash: Improve debugability of "Duplicate key" error message (rhbz#1207659)
- tests: hash: Test case for adding duplicate hash entry (rhbz#1207659)
- qemu: block: Don't skip creation of 'luks' formatted images (rhbz#1371022)
- qemu: monitor: Improve error message when QEMU reply is too large (rhbz#1524278)
- qemu: snapshot: Always rewrite backingStore data when reusing existing images (rhbz#1524278)
- qemu: snapshot: Prevent too-nested domain XML when doing inactive snapshot (rhbz#1524278)
- qemu: checkpoint: Store whether deleted checkpoint is current in a variable (rhbz#1207659)
- qemu: checkpoint: split out checkpoint deletion bitmaps (rhbz#1207659)
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointDiscardBitmaps (rhbz#1207659)
- qemu: checkpoint: rename disk->chkdisk in qemuCheckpointAddActions (rhbz#1207659)
- qemu: checkpoint: Use disk definition directly when creating checkpoint (rhbz#1207659)
- qemu: checkpoint: tolerate missing disks on checkpoint deletion (rhbz#1207659)
- qemu: domain: Remove unused qemuDomainDiskNodeFormatLookup (rhbz#1207659)
- qemu: checkpoint: Introduce helper to find checkpoint disk definition in parents (rhbz#1207659)
- qemu: checkpoint: Extract calculation of bitmap merging for checkpoint deletion (rhbz#1207659)
- qemu: snapshot: go through cleanup on error (rhbz#1524278)
- util: hash: Use g_new0 for allocating hash internals (rhbz#1793263)
- conf: domain: Remove checking of return value of virHashCreateFull (rhbz#1793263)
- Remove checking of return value of virHashNew (rhbz#1793263)
- qemuMigrationCookieAddNBD: Exit early if there are no disks (rhbz#1793263)
- qemuMigrationCookieNBD: Extract embedded struct (rhbz#1793263)
- qemuMigrationCookieAddNBD: Use glib memory allocators (rhbz#1793263)
- qemuMigrationCookieAddNBD: Move monitor call out of the loop (rhbz#1793263)
- qemuMigrationCookieAddNBD: Use virHashNew and automatic freeing of virHashTablePtr (rhbz#1793263)
- qemuMigrationCookieAddNBD: Remove 'ret' variable and 'cleanup' label (rhbz#1793263)
- qemuMigrationCookieAddNBD: Fix filling of 'capacity' when blockdev is used (rhbz#1793263)
- tests: qemublock: Add test for checkpoint deletion bitmap merge (rhbz#1207659)
- tests: qemublock: Add few more test cases for checkpoint deletion (rhbz#1207659)
- tests: qemublock: Add synthetic snapshot+checkpoint test data (rhbz#1207659)
- qemu: checkpoint: Introduce support for deleting checkpoints accross snapshots (rhbz#1207659)
- tests: qemublock: Add checkpoint deletion test for deep backing chain (rhbz#1207659)
- tests: qemublock: Add checkpoint deletion tests for some special cases (rhbz#1207659)
- qemu: checkpoint: Track and relabel images for bitmap merging (rhbz#1207659)
- qemu: block: Extract calls of qemuBlockGetNamedNodeData into a helper function (rhbz#1207659)
- util: json: Introduce virJSONValueArrayConcat (rhbz#1207659)
- virJSONValueNewArray: Use g_new0 to allocate and remove NULL checks from callers (rhbz#1207659)
- virhash: Fix the expectations of virHashKeyEqual implementations (rhbz#1207659)
- virHashAddOrUpdateEntry: Simplify allocation of new entry (rhbz#1207659)
- qemu: blockjob: Store 'jobflags' with block job data (rhbz#1207659)
- qemu: blockjob: Store 'flags' for all the block job types (rhbz#1207659)
- qemu: block: Add validator for bitmap chains accross backing chains (rhbz#1207659)
- tests: qemublocktest: Add another synthetic test case for broken bitmaps (rhbz#1207659)
- qemu: block: Introduce function to calculate bitmap handling for block-copy (rhbz#1207659)
- tests: qemublock: Add tests for qemuBlockBitmapsHandleBlockcopy (rhbz#1207659)
- qemuDomainBlockPivot: Copy bitmaps backing checkpoints for virDomainBlockCopy (rhbz#1207659)
- docs: domaincaps: Mention VIR_DOMAIN_UNDEFINE_CHECKPOINTS_METADATA (rhbz#1207659)

* Tue Feb  4 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-3
- cpu.c: Check properly for virCapabilitiesGetNodeInfo() retval (rhbz#1794691)
- qemu_conf: Avoid dereferencing NULL in virQEMUDriverGetHost{NUMACaps, CPU} (rhbz#1794691)
- qemu_capabilities: Rework domain caps cache (rhbz#1794691)
- conf: add support for specifying CPU "dies" parameter (rhbz#1785211, rhbz#1785207)
- conf: remove unused virCapabilitiesSetHostCPU method (rhbz#1785211, rhbz#1785207)
- qemu: add support for specifying CPU "dies" topology parameter (rhbz#1785207)
- hostcpu: add support for reporting die_id in NUMA topology (rhbz#1785211)
- tests: add host CPU data files for validating die_id (rhbz#1785211, rhbz#1785207)
- qemu: add capabilities flag for failover feature (rhbz#1693587)
- conf: parse/format <teaming> subelement of <interface> (rhbz#1693587)
- qemu: support interface <teaming> functionality (rhbz#1693587)
- qemu: allow migration with assigned PCI hostdev if <teaming> is set (rhbz#1693587)
- qemu: add wait-unplug to qemu migration status enum (rhbz#1693587)
- docs: document <interface> subelement <teaming> (rhbz#1693587)

* Tue Jan 21 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-2
- qemuDomainSaveImageStartVM: Use VIR_AUTOCLOSE for @intermediatefd (rhbz#1718707)
- qemuDomainSaveImageStartVM: Use g_autoptr() for virCommand (rhbz#1718707)
- qemu: Use g_autoptr() for qemuDomainSaveCookie (rhbz#1718707)
- qemu: Stop domain on failed restore (rhbz#1718707)
- qemu: Don't emit SUSPENDED_POSTCOPY event on destination (rhbz#1791458)
- util: storagefile: Properly set transport type when parsing NBD strings (rhbz#1791614)
- tests: virstorage: Add tests for NBD URI style syntax over UNIX (rhbz#1791614)
- qemu: end the agent job in qemuDomainSetTimeAgent (rhbz#1792723)

* Wed Jan 15 2020 Jiri Denemark <jdenemar@redhat.com> - 6.0.0-1
- Rebased to libvirt-6.0.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#1711789, rhbz#1717396, rhbz#1778058, rhbz#1008350, rhbz#1610207
    rhbz#1746981, rhbz#1776949, rhbz#1780154, rhbz#1781079, rhbz#1783411
    rhbz#1784345, rhbz#1788850, rhbz#1788898, rhbz#1789310, rhbz#1790733

* Tue Dec 17 2019 Jiri Denemark <jdenemar@redhat.com> - 5.10.0-2
- qemu: driver: Use appropriate job name when setting blockjob speed (rhbz#1780497)

* Tue Dec  3 2019 Jiri Denemark <jdenemar@redhat.com> - 5.10.0-1
- Rebased to libvirt-5.10.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#760547, rhbz#1171569, rhbz#1371022, rhbz#1375855, rhbz#1405537
    rhbz#1451398, rhbz#1465810, rhbz#1518998, rhbz#1518999, rhbz#1582202
    rhbz#1598162, rhbz#1609654, rhbz#1614740, rhbz#1623877, rhbz#1662024
    rhbz#1668139, rhbz#1705426, rhbz#1718255, rhbz#1741121, rhbz#1774375
    rhbz#1777094, rhbz#1777230, rhbz#1778014, rhbz#1778570

* Thu Nov 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-4
- libvirt-<module>: Check caller-provided buffers to be NULL with size > 0 (rhbz#1772842)

* Wed Nov 20 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-3
- cpu_map: Ship arm_features.xml (rhbz#1707897)

* Thu Nov 14 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-2
- tests: Update capabilities for QEMU 4.2.0 on aarch64 (rhbz#1707897)
- qemu: Rename virQEMUCapsObjectPropsMaxX86CPU (rhbz#1707897)
- qemu: Introduce QEMU_CAPS_ARM_MAX_CPU (rhbz#1707897)
- qemu: Query max-arm-cpu properties (rhbz#1707897)
- qemu: Update query-cpu-model-expansion check (rhbz#1707897)
- qemu: Perform full expansion on ARM (rhbz#1707897)
- cpu_map: Introduce ARM CPU features (rhbz#1707897)
- cpu: Validate ARM CPU features (rhbz#1707897)
- qemu: Validate ARM CPU features (rhbz#1707897)
- tests: Introduce tests for ARM CPU features (rhbz#1707897)

* Wed Nov 13 2019 Jiri Denemark <jdenemar@redhat.com> - 5.9.0-1
- Rebased to libvirt-5.9.0 (rhbz#1772045)
- The rebase also fixes the following bugs:
    rhbz#1515831, rhbz#1704761, rhbz#1704763, rhbz#1704764, rhbz#1704779
    rhbz#1705514, rhbz#1705516, rhbz#1705517, rhbz#1705519, rhbz#1705520
    rhbz#1733044, rhbz#1733092, rhbz#1524278, rhbz#1662588, rhbz#1720612
    rhbz#1733163, rhbz#1743177, rhbz#1744924, rhbz#1745815, rhbz#1746274
    rhbz#1746617, rhbz#1747826, rhbz#1751461, rhbz#1751580, rhbz#1619625
    rhbz#1755803

* Mon Oct 21 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-7
- qemu_blockjob: Remove secdriver metadata for whole backing chain on job completion (rhbz#1741456)
- qemu_driver: Fix comment of qemuStateCleanup() (rhbz#1755303)
- driver: Introduce virDriverShouldAutostart() (rhbz#1755303)
- lib: autostart objects exactly once (rhbz#1755303)
- Revert "src: Document autostart for session demon" (rhbz#1755303)
- security: Pass @migrated to virSecurityManagerSetAllLabel (rhbz#1740024)
- security: Rename virSecurityManagerGetDriver() to virSecurityManagerGetVirtDriver() (rhbz#1740024)
- security: Introduce virSecurityManagerGetDriver() (rhbz#1740024)
- security_stack: Turn list of nested drivers into a doubly linked list (rhbz#1740024)
- security_stack: Perform rollback if one of stacked drivers fails (rhbz#1740024)
- util: new function virNetDevMacVLanIsMacvtap() (rhbz#1723367)
- util: make a couple virNetDevMacVlan*() functions public (rhbz#1723367)
- qemu: reorganize qemuInterfaceEthernetConnect() (rhbz#1723367)
- conf: use virXMLFormatElement for interface <target> (rhbz#1723367)
- conf: new "managed" attribute for target dev of <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged target tap dev for <interface type='ethernet'> (rhbz#1723367)
- qemu: support unmanaged macvtap devices with <interface type='ethernet'> (rhbz#1723367)

* Thu Sep 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-6
- remote: fix registration of TLS socket (rhbz#1752837)

* Mon Sep 16 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-5
- vircgroupv2: fix setting cpu.max period (rhbz#1749247)

* Wed Sep  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-4
- src: security: Replace bitwise OR with logical OR (rhbz#1740024)
- security_util: Use more VIR_AUTOFREE() (rhbz#1740024)
- security_util: Document virSecurityMoveRememberedLabel (rhbz#1740024)
- security: Don't increase XATTRs refcounter on failure (rhbz#1740024)
- util: Introduce virhostuptime (rhbz#1741140)
- security_util: Remove stale XATTRs (rhbz#1741140)
- security_util: verify xattrs only if ref is present (rhbz#1741140)
- virSecuritySELinuxSetFileconImpl: Drop @optional argument (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconOptional() (rhbz#1740506)
- security_selinux: Drop @optional from _virSecuritySELinuxContextItem (rhbz#1740506)
- security_selinux: Drop virSecuritySELinuxSetFileconHelper (rhbz#1740506)
- security_selinux: Play nicely with network FS that only emulates SELinux (rhbz#1740506)
- qemu_blockjob: Print image path on failed security metadata move too (rhbz#1741456)
- qemu_blockjob: Remove secdriver metadata more frequently (rhbz#1741456)
- vircgroupv2: fix abort in VIR_AUTOFREE (rhbz#1747482)

* Fri Aug 30 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-3
- vircgroupv2: fix parsing multiple values in single file (rhbz#1734353)
- vircgroupv2: fix virCgroupV2GetCpuCfsQuota for "max" value (rhbz#1735740)
- network: fix ability to use openvswitch with vlans (rhbz#1739554)
- remote: use Wants instead of Requires for libvirtd sockets (rhbz#1741403)
- remote: move timeout arg into sysconf file (rhbz#1741403)
- remote: forbid the --listen arg when systemd socket activation (rhbz#1741403)
- rpm: don't enable socket activation in upgrade if --listen present (rhbz#1741403)
- qemuBuildHotpluggableCPUProps: use VIR_RETURN_PTR (rhbz#1741658)
- qemu: Extract and store vCPU properties as qemu returned them (rhbz#1741658)
- qemu: command: Use all vCPU properties when creating args for vCPU hotplug (rhbz#1741658)
- qemu: alias: Generate 'qomName' of disk with useraliases (rhbz#1741838)

* Mon Aug 19 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-2
- Revert "tpm: Check TPM XML device configuration changes after edit" (rhbz#1739338)
- qemu: Clarify error message in qemuMigrationSrcIsSafe (rhbz#1660575)
- qemu: Check for drop-cache capability (rhbz#1660575)
- qemu: Allow migration with disk cache on (rhbz#1660575)
- qemu: Pass qemuCaps to qemuDomainDefCopy (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainDefFormatBufInternal (rhbz#1741796)
- qemu: Pass qemuCaps to qemuDomainSaveImageOpen (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationAnyPrepareDef (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseString (rhbz#1741796)
- qemu: Pass qemuCaps to qemuMigrationCookieXMLParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefCopy (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefPostParse (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDefParseNode (rhbz#1741796)
- qemu: Pass correct qemuCaps to virDomainDeviceDefPostParse (rhbz#1741796)
- qemu: Fix crash on incoming migration (rhbz#1741796)
- network: fix crash during cleanup from failure to allocate port (rhbz#1741390)
- network: replace virSaveLastError() with virErrorPreserveLast() (rhbz#1741390)
- access: fix incorrect addition to virAccessPermNetwork (rhbz#1741428)
- util: allow tap-based guest interfaces to have MAC address prefix 0xFE (rhbz#1743349)

* Tue Aug  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.6.0-1
- Rebased to libvirt-5.6.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1643404, rhbz#1721375, rhbz#1724065, rhbz#1726609, rhbz#1726643
    rhbz#1727013, rhbz#1727866, rhbz#1729022, rhbz#1731332

* Fri Jul 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-2
- vircgroup: fix cgroups v2 controllers detection (rhbz#1513930)
- vircgroupv2: store enabled controllers (rhbz#1513930)

* Wed Jul  3 2019 Jiri Denemark <jdenemar@redhat.com> - 5.5.0-1
- Rebased to libvirt-5.5.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1426162, rhbz#1513930, rhbz#1598657, rhbz#1717768, rhbz#1720517
    rhbz#1720519, rhbz#1720522, rhbz#1720524, rhbz#1722360, rhbz#1723633

* Thu Jun 27 2019 Pavel Hrdina <phrdina@redhat.com> - 5.4.0-2
- RHEL: spec: Disable gluster on i686 (rhbz#1724445)
- rpc: virnetlibsshsession: update deprecated functions (rhbz#1724678)

* Tue Jun  4 2019 Jiri Denemark <jdenemar@redhat.com> - 5.4.0-1
- Rebased to libvirt-5.4.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1580229, rhbz#1628475, rhbz#1702758, rhbz#1707708, rhbz#1716260
    rhbz#1716261, rhbz#1716262, rhbz#1716263

* Tue May  7 2019 Jiri Denemark <jdenemar@redhat.com> - 5.3.0-1
- Rebased to libvirt-5.3.0 (rhbz#1705225)
- The rebase also fixes the following bugs:
    rhbz#1578741, rhbz#1602418, rhbz#1680304, rhbz#1690240, rhbz#1292102
    rhbz#1623389, rhbz#1658504, rhbz#1689165, rhbz#1689815, rhbz#1692926
    rhbz#1217444, rhbz#1564270, rhbz#1580229, rhbz#1697676

* Fri Mar 15 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-7
- qemu: Set job statsType for external memory snapshot (rhbz#1688774)

* Wed Mar  6 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-6
- qemu: Don't set migration caps when changing postcopy bandwidth (rhbz#1336709)

* Fri Mar  1 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-5
- qemu: fix i6300esb watchdog hotplug on Q35 (rhbz#1666559)

* Tue Feb 26 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-4
- RHEL: util: fix typo in iptables --delete command (rhbz#1679119)

* Mon Feb 18 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-3
- vshtabletest: indent strings with expected output (rhbz#1676354)
- vsh-table: allow empty columns (rhbz#1676354)
- virsh: introduce ninfos variable in cmdDomFSInfo (rhbz#1676354)
- virsh: rename ret to rc in cmdDomFSInfo (rhbz#1676354)
- virsh: do not access uninitialized memory in cmdDomFSInfo (rhbz#1676354)
- virsh: introduce 'ret' in cmdDomFSInfo (rhbz#1676354)
- virsh: do not report error on zero filesystems in cmdDomFSInfo (rhbz#1676354)
- virsh: use virBufferTrim in cmdDomFSInfo (rhbz#1676354)
- virsh: allow empty targets in cmdDomFSInfo (rhbz#1676354)
- util: fix memory leak in virFirewallDInterfaceSetZone() (rhbz#1672340)
- internal: introduce a family of NULLSTR macros (rhbz#1662849)
- virsh: fix snapshot list --parent (rhbz#1662849)
- network: explicitly allow icmp/icmpv6 in libvirt zonefile (rhbz#1672340)

* Fri Feb  8 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-2
- RHEL: qemu: Fix crash trying to use iSCSI hostdev (rhbz#1669966)
- docs: Drop /dev/net/tun from the list of shared devices (rhbz#1671791)
- qemu: conf: Remove /dev/sev from the default cgroup device acl list (rhbz#1671791)
- qemu: cgroup: Expose /dev/sev/ only to domains that require SEV (rhbz#1671791)
- qemu: domain: Add /dev/sev into the domain mount namespace selectively (rhbz#1671791)
- security: dac: Relabel /dev/sev in the namespace (rhbz#1671791)
- qemu: caps: Use CAP_DAC_OVERRIDE for probing to avoid permission issues (rhbz#1671791)
- qemu: caps: Don't try to ask for CAP_DAC_OVERRIDE if non-root (rhbz#1671791)
- qemu: command: Don't skip 'readonly' and throttling info for empty drive (rhbz#1672259)
- Revert "RHEL: network: regain guest network connectivity after firewalld switch to nftables" (rhbz#1672340)
- configure: change HAVE_FIREWALLD to WITH_FIREWALLD (rhbz#1672340)
- util: move all firewalld-specific stuff into its own files (rhbz#1672340)
- util: new virFirewallD APIs + docs (rhbz#1672340)
- configure: selectively install a firewalld 'libvirt' zone (rhbz#1672340)
- network: set firewalld zone of bridges to "libvirt" zone when appropriate (rhbz#1672340)
- network: allow configuring firewalld zone for virtual network bridge device (rhbz#1672340)
- util: remove test code accidentally committed to virFirewallDZoneExists (rhbz#1672340)
- qemu: Use C99 initializers for qemuMigrationParamsTPMap (rhbz#1336709)
- qemu: Add optional unit to qemuMigrationParamsTPMapItem (rhbz#1336709)
- qemu: Rework qemuDomainMigrateSetMaxSpeed (rhbz#1336709)
- qemu: Make migration params usable outside migration (rhbz#1336709)
- Public API for post-copy migration bandwidth (rhbz#1336709)
- qemu: Implement VIR_MIGRATE_PARAM_BANDWIDTH_POSTCOPY (rhbz#1336709)
- qemu: Implement VIR_DOMAIN_MIGRATE_MAX_SPEED_POSTCOPY flag (rhbz#1336709)
- virsh: Add support for setting post-copy migration bandwidth (rhbz#1336709)

* Fri Jan 25 2019 Jiri Denemark <jdenemar@redhat.com> - 5.0.0-1
- Rebased to libvirt-5.0.0 (rhbz#1666130)
- The rebase also fixes the following bugs:
    rhbz#1597869, rhbz#1644567
- tests: qemuxml2argv: Add test case for empty CDROM with cache mode (rhbz#1668027)
- qemu: command: Don't format image properties for empty -drive (rhbz#1668027)

* Thu Dec  6 2018 Jiri Denemark <jdenemar@redhat.com> - 4.10.0-1
- Rebased to libvirt-4.10.0

* Tue Nov 20 2018 Jiri Denemark <jdenemar@redhat.com> - 4.9.0-1
- Rebased to libvirt-4.9.0
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Fri Nov  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-14
- storage: Remove secretPath from _virStorageBackendQemuImgInfo (rhbz#1645459)
- storage: Allow for inputvol to have any format for encryption (rhbz#1645459)
- storage: Allow inputvol to be encrypted (rhbz#1645459)
- access: Modify the VIR_ERR_ACCESS_DENIED to include driverName (rhbz#1631608)
- docs: Enhance polkit documentation to describe secondary connection (rhbz#1631608)
- qemu: Don't ignore resume events (rhbz#1634758, rhbz#1643338)

* Thu Nov  1 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-13
- Revert "spec: Temporarily drop gluster support" (rhbz#1599339)

* Wed Oct 17 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-12
- RHEL: Require firewalld-filesystem for firewalld rpm macros (rhbz#1639932)

* Tue Oct 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-11
- virfile: fix cast-align error (rhbz#1634782)
- virfiletest: Fix test name prefix for virFileInData test (rhbz#1634782)
- virfiletst: Test virFileIsSharedFS (rhbz#1634782)
- virFileIsSharedFSType: Detect direct mount points (rhbz#1634782)
- virfile: Rework virFileIsSharedFixFUSE (rhbz#1634782)
- RHEL: network: regain guest network connectivity after firewalld switch to nftables (rhbz#1638864)

* Mon Oct  8 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-10
- conf: Fix check for chardev source path (rhbz#1609723)
- tests: Reuse qemucapabilities data for qemucaps2xml (rhbz#1629862)
- tests: Add more tests to qemucaps2xml (rhbz#1629862)
- qemu: Drop QEMU_CAPS_ENABLE_KVM (rhbz#1629862)
- qemu: Avoid probing non-native binaries all the time (rhbz#1629862)
- qemu: Clarify QEMU_CAPS_KVM (rhbz#1629862)
- qemu: Don't check for /dev/kvm presence (rhbz#1629862)
- tests: Follow up on qemucaps2xmldata rename (rhbz#1629862)
- security: dac: also label listen UNIX sockets (rhbz#1634775)
- spec: Set correct TLS priority (rhbz#1632269)
- spec: Build ceph and gluster support everywhere (rhbz#1599546)
- virsh: Require explicit --domain for domxml-to-native (rhbz#1634769)
- virFileIsSharedFSType: Check for fuse.glusterfs too (rhbz#1634782)
- qemu: fix up permissions for pre-created UNIX sockets (rhbz#1634775)
- cpu_map: Add features for Icelake CPUs (rhbz#1527657, rhbz#1526625)
- cpu_map: Add Icelake CPU models (rhbz#1526625)
- qemu: Properly report VIR_DOMAIN_EVENT_RESUMED_FROM_SNAPSHOT (rhbz#1634758)
- qemu: Report more appropriate running reasons (rhbz#1634758)
- qemu: Pass running reason to RESUME event handler (rhbz#1634758)
- qemu: Map running reason to resume event detail (rhbz#1634758)
- qemu: Avoid duplicate resume events and state changes (rhbz#1634758)
- conf: qemu: add support for Hyper-V frequency MSRs (rhbz#1589702)
- conf: qemu: add support for Hyper-V reenlightenment notifications (rhbz#1589702)
- conf: qemu: add support for Hyper-V PV TLB flush (rhbz#1589702)

* Wed Sep  5 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-9
- RHEL: Fix virConnectGetMaxVcpus output (rhbz#1582222)
- storage: Add --shrink to qemu-img command when shrinking vol (rhbz#1622534)
- access: Fix nwfilter-binding ACL access API name generation (rhbz#1622540)
- conf: Add validation of input devices (rhbz#1591240)
- tests: qemu: Remove disk from graphics-vnc-tls (rhbz#1598167)
- tests: qemu: test more versions for graphics-vnc-tls (rhbz#1598167)
- qemu: vnc: switch to tls-creds-x509 (rhbz#1598167)
- qemu: mdev: Use vfio-pci 'display' property only with vfio-pci mdevs (rhbz#1624740)
- virDomainDefCompatibleDevice: Relax alias change check (rhbz#1603133)
- virDomainDetachDeviceFlags: Clarify update semantics (rhbz#1603133)
- virDomainNetDefCheckABIStability: Check for MTU change too (rhbz#1623158)
- RHEL: spec: Require python3-devel on RHEL-8 (rhbz#1518446)
- qemu: monitor: Remove qemuMonitorJSONExtractCPUArchInfo wrapper (rhbz#1598829)
- qemu: monitor: Use 'target' instead of 'arch' in reply of 'query-cpus-fast' (rhbz#1598829)

* Tue Aug 21 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-8
- tests: Add missing thread_siblings_list files (rhbz#1608479)
- util: Rewrite virHostCPUCountThreadSiblings() (rhbz#1608479)
- utils: Remove arbitrary limit on socket_id/core_id (rhbz#1608479)
- tests: Add linux-high-ids test (rhbz#1608479)
- qemu: hotplug: Fix asynchronous unplug of 'shmem' (rhbz#1618680)
- tests: rename hugepages to hugepages-default (rhbz#1615461)
- tests: extract hugepages-numa-default-dimm out of hugepages-numa (rhbz#1615461)
- tests: rename hugepages-numa into hugepages-numa-default (rhbz#1615461)
- tests: remove unnecessary XML elements from hugepages-numa-default (rhbz#1615461)
- tests: extract pages-discard out of hugepages-pages (rhbz#1615461)
- tests: rename hugepages-pages into hugepages-numa-nodeset (rhbz#1615461)
- tests: rename hugepages-pages2 into hugepages-numa-default-2M (rhbz#1615461)
- tests: extract pages-discard-hugepages out of hugepages-pages3 (rhbz#1615461)
- tests: rename hugepages-pages3 into hugepages-numa-nodeset-part (rhbz#1615461)
- tests: rename hugepages-pages4 into hugepages-numa-nodeset-nonexist (rhbz#1615461)
- tests: rename hugepages-pages5 into hugepages-default-2M (rhbz#1615461)
- tests: rename hugepages-pages6 into hugepages-default-system-size (rhbz#1615461)
- tests: rename hugepages-pages7 into pages-dimm-discard (rhbz#1615461)
- tests: rename hugepages-pages8 into hugepages-nodeset-nonexist (rhbz#1615461)
- tests: introduce hugepages-default-1G-nodeset-2M (rhbz#1615461)
- tests: introduce hugepages-nodeset (rhbz#1615461)
- conf: Move hugepage XML validation check out of qemu_command (rhbz#1615461)
- conf: Move hugepages validation out of XML parser (rhbz#1615461)
- conf: Introduce virDomainDefPostParseMemtune (rhbz#1615461)
- tests: sev: Test launch-security with specific QEMU version (rhbz#1619150)
- qemu: Fix probing of AMD SEV support (rhbz#1619150)
- qemu: caps: Format SEV platform data into qemuCaps cache (rhbz#1619150)
- conf: Parse guestfwd channel device info again (rhbz#1610072)

* Thu Aug 16 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-7
- qemu_migration: Avoid writing to freed memory (rhbz#1615854)

* Thu Aug  2 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-6
- qemu: Exempt video model 'none' from getting a PCI address on Q35
- conf: Fix a error msg typo in virDomainVideoDefValidate

* Tue Jul 31 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-5
- esx storage: Fix typo lsilogic -> lsiLogic
- networkGetDHCPLeases: Don't always report error if unable to read leases file
- nwfilter: Resolve SEGV for NWFilter Snoop processing
- qemu: Remove unused bypassSecurityDriver from qemuOpenFileAs
- qemuDomainSaveMemory: Don't enforce dynamicOwnership
- domain_nwfilter: Return early if net has no name in virDomainConfNWFilterTeardownImpl
- examples: Add clean-traffic-gateway into nwfilters

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-4
- qemu: hotplug: don't overwrite error message in qemuDomainAttachNetDevice
- qemu: hotplug: report error when changing rom enabled attr for net iface
- qemu: Fix setting global_period cputune element
- tests: qemucaps: Add test data for upcoming qemu 3.0.0
- qemu: capabilities: Add capability for werror/rerror for 'usb-device' frontend
- qemu: command: Move graphics iteration to its own function
- qemu: address: Handle all the video devices within a single loop
- conf: Introduce virDomainVideoDefClear helper
- conf: Introduce virDomainDefPostParseVideo helper
- qemu: validate: Enforce compile time switch type checking for videos
- tests: Add capabilities data for QEMU 2.11 x86_64
- tests: Update capabilities data for QEMU 3.0.0 x86_64
- qemu: qemuBuildHostdevCommandLine: Use a helper variable mdevsrc
- qemu: caps: Introduce a capability for egl-headless
- qemu: Introduce a new graphics display type 'headless'
- qemu: caps: Add vfio-pci.display capability
- conf: Introduce virDomainGraphicsDefHasOpenGL helper
- conf: Replace 'error' with 'cleanup' in virDomainHostdevDefParseXMLSubsys
- conf: Introduce new <hostdev> attribute 'display'
- qemu: command: Enable formatting vfio-pci.display option onto cmdline
- docs: Rephrase the mediated devices hostdev section a bit
- conf: Introduce new video type 'none'
- virt-xml-validate: Add schema for nwfilterbinding
- tools: Fix typo generating adapter_wwpn field
- src: Fix memory leak in virNWFilterBindingDispose

* Mon Jul 23 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-3
- qemu: hotplug: Do not try to add secret object for TLS if it does not exist
- qemu: monitor: Make qemuMonitorAddObject more robust against programming errors
- spec: Explicitly require matching libvirt-libs
- virDomainConfNWFilterInstantiate: initialize @xml to avoid random crash
- qemuProcessStartPRDaemonHook: Try to set NS iff domain was started with one
- qemuDomainValidateStorageSource: Relax PR validation
- virStoragePRDefFormat: Suppress path formatting for migratable XML
- qemu: Wire up PR_MANAGER_STATUS_CHANGED event
- qemu_monitor: Introduce qemuMonitorJSONGetPRManagerInfo
- qemu: Fetch pr-helper process info on reconnect
- qemu: Fix ATTRIBUTE_NONNULL for qemuMonitorAddObject
- virsh.pod: Fix a command name typo in nwfilter-binding-undefine
- docs: schema: Add missing <alias> to vsock device
- virnetdevtap: Don't crash on !ifname in virNetDevTapInterfaceStats
- tests: fix TLS handshake failure with TLS 1.3

* Mon Jul  9 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-2
- qemu: Add capability for the HTM pSeries feature
- conf: Parse and format the HTM pSeries feature
- qemu: Format the HTM pSeries feature
- qemu: hotplug: Don't access srcPriv when it's not allocated
- qemuDomainNestedJobAllowed: Allow QEMU_JOB_NONE
- src: Mention DEVICE_REMOVAL_FAILED event in virDomainDetachDeviceAlias docs
- virsh.pod: Drop --persistent for detach-device-alias
- qemu: don't use chardev FD passing with standalone args
- qemu: remove chardevStdioLogd param from vhostuser code path
- qemu: consolidate parameters of qemuBuildChrChardevStr into flags
- qemu: don't use chardev FD passing for vhostuser backend
- qemu: fix UNIX socket chardevs operating in client mode
- qemuDomainDeviceDefValidateNetwork: Check for range only if IP prefix set
- spec: Temporarily drop gluster support

* Tue Jul  3 2018 Jiri Denemark <jdenemar@redhat.com> - 4.5.0-1
- Rebased to libvirt-4.5.0

* Fri May 25 2018 Jiri Denemark <jdenemar@redhat.com> - 4.3.0-1
- Rebased to libvirt-4.3.0

* Wed Mar 21 2018 Daniel P. Berrangé <berrange@redhat.com> - 4.1.0-2
- Fix systemd macro argument with line continuations (rhbz#1558648)

* Mon Mar  5 2018 Daniel Berrange <berrange@redhat.com> - 4.1.0-1
- Rebase to version 4.1.0

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Fri Jan 19 2018 Daniel P. Berrange <berrange@redhat.com> - 4.0.0-1
- Rebase to version 4.0.0

* Wed Dec 20 2017 Cole Robinson <crobinso@redhat.com> - 3.10.0-2
- Rebuild for xen 4.10

* Tue Dec  5 2017 Daniel P. Berrange <berrange@redhat.com> - 3.10.0-1
- Rebase to version 3.10.0

* Fri Nov  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.9.0-1
- Rebase to version 3.9.0

* Wed Oct  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.8.0-1
- Rebase to version 3.8.0

* Mon Sep  4 2017 Daniel P. Berrange <berrange@redhat.com> - 3.7.0-1
- Rebase to version 3.7.0

* Wed Aug  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.6.0-1
- Rebase to version 3.6.0

* Sun Jul 30 2017 Florian Weimer <fweimer@redhat.com> - 3.5.0-4
- Rebuild with binutils fix for ppc64le (#1475636)

* Tue Jul 25 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-3
- Disabled RBD on i386, arm, ppc64 (rhbz #1474743)

* Mon Jul 17 2017 Cole Robinson <crobinso@redhat.com> - 3.5.0-2
- Rebuild for xen 4.9

* Thu Jul  6 2017 Daniel P. Berrange <berrange@redhat.com> - 3.5.0-1
- Rebase to version 3.5.0

* Fri Jun  2 2017 Daniel P. Berrange <berrange@redhat.com> - 3.4.0-1
- Rebase to version 3.4.0

* Mon May  8 2017 Daniel P. Berrange <berrange@redhat.com> - 3.3.0-1
- Rebase to version 3.3.0

* Mon Apr  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.2.0-1
- Rebase to version 3.2.0

* Fri Mar  3 2017 Daniel P. Berrange <berrange@redhat.com> - 3.1.0-1
- Rebase to version 3.1.0

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 3.0.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Jan 19 2017 Daniel P. Berrange <berrange@redhat.com> - 3.0.0-1
- Rebase to version 3.0.0
